#include "mikromedia_7_objects.h"
#include "mikromedia_7_resources.h"
#include "built_in.h"


// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOF_ODR.B14;
sbit TFT_RS at GPIOF_ODR.B15;
sbit TFT_CS at GPIOF_ODR.B13;
sbit TFT_RD at GPIOF_ODR.B12;
sbit TFT_WR at GPIOF_ODR.B11;
sbit TFT_BLED at GPIOF_ODR.B10;
// End TFT module connections


// Global variables
unsigned int Xcoord, Ycoord;
char PenDown;
typedef unsigned long TPointer;
TPointer PressedObject;
int PressedObjectType;
unsigned int caption_length, caption_height;
unsigned int display_width, display_height;

int _object_count;
unsigned short object_pressed;
TButton *local_button;
TButton *exec_button;
int button_order;
TButton_Round *local_round_button;
TButton_Round *exec_round_button;
int round_button_order;
TCButton_Round *local_round_cbutton;
TCButton_Round *exec_round_cbutton;
int round_cbutton_order;
TLabel *local_label;
TLabel *exec_label;
int label_order;
TImage *local_image;
TImage *exec_image;
int image_order;
TCircle *local_circle;
TCircle *exec_circle;
int circle_order;
TBox *local_box;
TBox *exec_box;
int box_order;
TBox_Round *local_round_box;
TBox_Round *exec_round_box;
int box_round_order;
TCheckBox *local_checkbox;
TCheckBox *exec_checkbox;
int checkbox_order;
TRadioButton *local_radio_button;
TRadioButton *exec_radio_button;
int radio_button_order;


void Write_to_Data_Lines(unsigned char _hi, unsigned char _lo) {
  unsigned int temp;
  temp = GPIOE_ODR;
  temp &= 0x00FF;
  GPIOE_ODR = temp | (_hi << 8);
  temp = GPIOG_ODR;
  temp &= 0xFF00;
  GPIOG_ODR = temp | _lo;
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  Write_to_Data_Lines(0, index);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  Write_to_Data_Lines(0, cmd);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  Write_to_Data_Lines(Hi(_data), Lo(_data));
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

static void InitializeTouchPanel() {
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_SSD1963_7Inch_800x480(800, 480);

  TFT_Set_DBC_SSD1963(255);

  PenDown = 0;
  PressedObject = 0;
  PressedObjectType = -1;
}

void Calibrate() {
  TFT_Fill_Screen(CL_BLACK);
  TFT_Set_Font(TFT_defaultFont, CL_WHITE, FO_HORIZONTAL);
  TFT_Write_Text("Touch points on the screen as they", 285, 225);
  TFT_Write_Text("appear to calibrate touchscreen.", 295, 255);
  STMPE610_ClearInterruptFlagsAndFIFO();
  TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
  TFT_Circle(0, 0, 3);
  STMPE610_CalibratePoint(STMPE610_FIRST_CORNER);
  Delay_ms(500);
  TFT_Set_Brush(1, CL_BLACK, 0, 0, 0, 0);
  TFT_Circle(0, 0, 3);
  STMPE610_ClearInterruptFlagsAndFIFO();
  TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
  TFT_Circle(0, TFT_DISP_HEIGHT-1, 3);
  STMPE610_CalibratePoint(STMPE610_SECOND_CORNER);
  Delay_ms(500);
  TFT_Set_Brush(1, CL_BLACK, 0, 0, 0, 0);
  TFT_Circle(0, TFT_DISP_HEIGHT-1, 3);
  STMPE610_ClearInterruptFlagsAndFIFO();
  TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
  TFT_Circle(TFT_DISP_WIDTH-1, TFT_DISP_HEIGHT-1, 3);
  STMPE610_CalibratePoint(STMPE610_THIRD_CORNER);
  Delay_ms(500);
  TFT_Set_Brush(1, CL_BLACK, 0, 0, 0, 0);
  TFT_Circle(TFT_DISP_WIDTH-1, TFT_DISP_HEIGHT-1, 3);
  STMPE610_ClearInterruptFlagsAndFIFO();
  TFT_Set_Brush(1, CL_WHITE, 0, 0, 0, 0);
  TFT_Circle(TFT_DISP_WIDTH-1, 0, 3);
  STMPE610_CalibratePoint(STMPE610_FOURTH_CORNER);
  TFT_Set_Brush(1, CL_BLACK, 0, 0, 0, 0);
  TFT_Circle(TFT_DISP_WIDTH-1, 0, 3);
  Delay_ms(500);
}


/////////////////////////
  TScreen*  CurrentScreen;

  TScreen                Home;
  TImage               Image1;
  TImage               Image3;
  TLabel                 Label5;
char Label5_Caption[12] = "mikromedia7";

  TLabel                 Label7;
char Label7_Caption[14] = "Accelerometer";

  TLabel                 Label8;
char Label8_Caption[10] = "RGB Light";

  TImage               Image6;
  TLabel                 Label14;
char Label14_Caption[6] = "Clock";

  TImage               Image10;
  TLabel                 Label19;
char Label19_Caption[9] = "12:56 AM";

  TImage               Image9;
  TLabel                 Label20;
char Label20_Caption[8] = "Sensors";

  TImage               Image16;
  TLabel                 Label25;
char Label25_Caption[11] = "MP3 Player";

  TImage               Image24;
  TLabel                 Label30;
char Label30_Caption[6] = "Paint";

  TImage               Image18;
  TLabel                 Label34;
char Label34_Caption[11] = "Slide Show";

  TImage               TicTacToe;
  TLabel                 Label40;
char Label40_Caption[12] = "Tic Tac Toe";

  TImage               BatteryStatus;
  TImage               Image19;
  TImage               Image22;
  TLabel                 Label43;
char Label43_Caption[5] = "WiFi";

  TLabel                 Label45;
char Label45_Caption[4] = "CAN";

  TLabel                 * const code Screen1_Labels[12]=
         {
         &Label5,              
         &Label7,              
         &Label8,              
         &Label14,             
         &Label19,             
         &Label20,             
         &Label25,             
         &Label30,             
         &Label34,             
         &Label40,             
         &Label43,             
         &Label45              
         };
  TImage                 * const code Screen1_Images[12]=
         {
         &Image1,              
         &Image3,              
         &Image6,              
         &Image10,             
         &Image9,              
         &Image16,             
         &Image24,             
         &Image18,             
         &TicTacToe,           
         &BatteryStatus,       
         &Image19,             
         &Image22              
         };

  TScreen                Accelerometer;
  TBox                   Box23;
  TBox                   Box1;
  TImage               Image2;
  TLabel                 Label1;
char Label1_Caption[20] = "Accelerometer Graph";

  TLabel                 Label2;
char Label2_Caption[4] = "X: ";

  TLabel                 Label3;
char Label3_Caption[4] = "Y: ";

  TLabel                 Label4;
char Label4_Caption[4] = "Z: ";

  TLabel                 * const code Screen2_Labels[4]=
         {
         &Label1,              
         &Label2,              
         &Label3,              
         &Label4               
         };
  TImage                 * const code Screen2_Images[1]=
         {
         &Image2               
         };
  TBox                   * const code Screen2_Boxes[2]=
         {
         &Box23,               
         &Box1                 
         };

  TScreen                RGBLight;
  TBox                   Box22;
  TLabel                 Label9;
char Label9_Caption[10] = "RGB Light";

  TImage               Image5;
  TLabel                 Label10;
char Label10_Caption[13] = "Pick a Color";

  TCircle                Circle1;
  TLabel                 Label11;
char Label11_Caption[4] = "R: ";

  TLabel                 Label12;
char Label12_Caption[4] = "G: ";

  TLabel                 Label13;
char Label13_Caption[4] = "B: ";

  TBox                   RGB_Active_area;
  TLabel                 * const code Screen3_Labels[5]=
         {
         &Label9,              
         &Label10,             
         &Label11,             
         &Label12,             
         &Label13              
         };
  TImage                 * const code Screen3_Images[1]=
         {
         &Image5               
         };
  TCircle                * const code Screen3_Circles[1]=
         {
         &Circle1              
         };
  TBox                   * const code Screen3_Boxes[2]=
         {
         &Box22,               
         &RGB_Active_area      
         };

  TScreen                Clock;
  TBox                   Box16;
  TBox                   Box15;
  TBox                   Box13;
  TBox                   Box12;
  TLabel                 Label15;
char Label15_Caption[2] = ":";

  TBox                   Box2;
  TBox                   Box3;
  TLabel                 Label16;
char Label16_Caption[6] = "Clock";

  TImage               ClockBack;
  TLabel                 Label17;
char Label17_Caption[5] = "Sync";

  TLabel                 Label18;
char Label18_Caption[5] = "Done";

  TImage               SyncIcon;
  TImage               Image8;
  TBox                   Box4;
  TBox                   Box5;
  TImage               Image7;
  TLabel                 Label42;
char Label42_Caption[51] = " ";

  TImage               Image17;
  TBox                   Box14;
  TLabel                 * const code Screen4_Labels[5]=
         {
         &Label15,             
         &Label16,             
         &Label17,             
         &Label18,             
         &Label42              
         };
  TImage                 * const code Screen4_Images[5]=
         {
         &ClockBack,           
         &SyncIcon,            
         &Image8,              
         &Image7,              
         &Image17              
         };
  TBox                   * const code Screen4_Boxes[9]=
         {
         &Box16,               
         &Box15,               
         &Box13,               
         &Box12,               
         &Box2,                
         &Box3,                
         &Box4,                
         &Box5,                
         &Box14                
         };

  TScreen                Sensors;
  TBox                   Box21;
  TBox                   Diagram5_Box1;
  TImage               TempIcon;
  TImage               LightIcon;
  TLabel                 Diagram5_Label1;
char Diagram5_Label1_Caption[12] = "Temperature";

  TLabel                 Diagram5_Label2;
char Diagram5_Label2_Caption[12] = "26.5C";

  TLabel                 Diagram5_Label3;
char Diagram5_Label3_Caption[15] = "Light Intesity";

  TLabel                 Diagram5_Label4;
char Diagram5_Label4_Caption[9] = "96.5%";

  TLabel                 Diagram5_Label5;
char Diagram5_Label5_Caption[12] = "78.5F";

  TImage               BackIconSensors;
  TLabel                 Diagram5_Label6;
char Diagram5_Label6_Caption[8] = "Sensors";

  TLabel                 Label21;
char Label21_Caption[2] = "/";

  TLabel                 * const code Screen5_Labels[7]=
         {
         &Diagram5_Label1,     
         &Diagram5_Label2,     
         &Diagram5_Label3,     
         &Diagram5_Label4,     
         &Diagram5_Label5,     
         &Diagram5_Label6,     
         &Label21              
         };
  TImage                 * const code Screen5_Images[3]=
         {
         &TempIcon,            
         &LightIcon,           
         &BackIconSensors      
         };
  TBox                   * const code Screen5_Boxes[2]=
         {
         &Box21,               
         &Diagram5_Box1        
         };

  TScreen                MP3_SD;
  TBox                   Box20;
  TLabel                 Label22;
char Label22_Caption[11] = "MP3 Player";

  TLabel                 Label23;
char Label23_Caption[20] = "Insert microSD card";

  TImage               Image11;
  TImage               Image12;
  TImage               Image13;
  TImage               Image14;
  TImage               mp3_back_icon;
  TLabel                 * const code Screen6_Labels[2]=
         {
         &Label22,             
         &Label23              
         };
  TImage                 * const code Screen6_Images[5]=
         {
         &Image11,             
         &Image12,             
         &Image13,             
         &Image14,             
         &mp3_back_icon        
         };
  TBox                   * const code Screen6_Boxes[1]=
         {
         &Box20                
         };

  TScreen                MP3_SongList;
  TBox                   Box19;
  TBox                   Box6;
  TLabel                 Label24;
char Label24_Caption[11] = "MP3 Player";

  TImage               mp3_back_icon2;
  TLabel                 Label26;
char Label26_Caption[22] = "Choose a song to play";

  TImage               folder_icon;
  TImage               file_icon;
  TImage               Image30;
  TLabel                 * const code Screen7_Labels[2]=
         {
         &Label24,             
         &Label26              
         };
  TImage                 * const code Screen7_Images[4]=
         {
         &mp3_back_icon2,      
         &folder_icon,         
         &file_icon,           
         &Image30              
         };
  TBox                   * const code Screen7_Boxes[2]=
         {
         &Box19,               
         &Box6                 
         };

  TScreen                MP3_Player;
  TBox                   Box17;
  TLabel                 Label27;
char Label27_Caption[11] = "MP3 Player";

  TImage               Icon_back_mp3;
  TBox                   VolmeBar;
  TImage               Image15;
  TBox                   ProgressBar;
  TLabel                 Label28;
char Label28_Caption[15] = "Song01";

  TImage               previous_icon;
  TImage               pause_icon;
  TImage               Play_icon;
  TImage               stop_icon;
  TImage               next_icon;
  TImage               songlist_icon;
  TLabel                 Label6;
char Label6_Caption[6] = "00:00";

  TImage               Image31;
  TLabel                 * const code Screen8_Labels[3]=
         {
         &Label27,             
         &Label28,             
         &Label6               
         };
  TImage                 * const code Screen8_Images[9]=
         {
         &Icon_back_mp3,       
         &Image15,             
         &previous_icon,       
         &pause_icon,          
         &Play_icon,           
         &stop_icon,           
         &next_icon,           
         &songlist_icon,       
         &Image31              
         };
  TBox                   * const code Screen8_Boxes[3]=
         {
         &Box17,               
         &VolmeBar,            
         &ProgressBar          
         };

  TScreen                Paint;
  TBox                   Box18;
  TImage               Image4;
  TImage               NewScreen;
  TImage               Image25;
  TImage               Pen;
  TImage               Image27;
  TImage               Eraser;
  TImage               Image29;
  TBox                   DrawingArea;
  TImage               icon_paint_back;
  TLabel                 Label29;
char Label29_Caption[6] = "Paint";

  TBox                   Color01;
  TBox                   Color02;
  TBox                   Color03;
  TBox                   Color04;
  TBox                   Color05;
  TBox                   Color06;
  TBox                   Color07;
  TBox                   Color08;
  TBox                   Color09;
  TBox                   Color10;
  TBox                   Color11;
  TBox                   Color12;
  TBox                   Color13;
  TBox                   Color14;
  TBox                   Color15;
  TBox                   Color16;
  TBox                   Color17;
  TBox                   Color18;
  TBox                   Color19;
  TBox                   Color20;
  TBox                   Color21;
  TBox                   Color22;
  TBox                   Color23;
  TBox                   Color24;
  TBox                   Color25;
  TBox                   Color26;
  TBox                   Color27;
  TBox                   Color28;
  TBox                   Color29;
  TBox                   Color30;
  TImage               BackGroundColor;
  TBox                   Pen1;
  TBox                   Pen2;
  TBox                   Pen3;
  TLabel                 * const code Screen9_Labels[1]=
         {
         &Label29              
         };
  TImage                 * const code Screen9_Images[9]=
         {
         &Image4,              
         &NewScreen,           
         &Image25,             
         &Pen,                 
         &Image27,             
         &Eraser,              
         &Image29,             
         &icon_paint_back,     
         &BackGroundColor      
         };
  TBox                   * const code Screen9_Boxes[35]=
         {
         &Box18,               
         &DrawingArea,         
         &Color01,             
         &Color02,             
         &Color03,             
         &Color04,             
         &Color05,             
         &Color06,             
         &Color07,             
         &Color08,             
         &Color09,             
         &Color10,             
         &Color11,             
         &Color12,             
         &Color13,             
         &Color14,             
         &Color15,             
         &Color16,             
         &Color17,             
         &Color18,             
         &Color19,             
         &Color20,             
         &Color21,             
         &Color22,             
         &Color23,             
         &Color24,             
         &Color25,             
         &Color26,             
         &Color27,             
         &Color28,             
         &Color29,             
         &Color30,             
         &Pen1,                
         &Pen2,                
         &Pen3                 
         };

  TScreen                SlideShow;
  TBox                   Box7;
  TBox                   icon_previous_box;
  TBox                   Icon_next_box;
  TLabel                 Label31;
char Label31_Caption[11] = "Slide Show";

  TImage               back_slide_show;
  TLabel                 Label32;
char Label32_Caption[14] = "Slide up/down";

  TLabel                 Label33;
char Label33_Caption[5] = "of 6";

  TImage               icon_previous;
  TImage               Icon_next;
  TLabel                 Label35;
char Label35_Caption[6] = "  ";

  TBox                   Slide_Active_area;
  TLabel                 * const code Screen10_Labels[4]=
         {
         &Label31,             
         &Label32,             
         &Label33,             
         &Label35              
         };
  TImage                 * const code Screen10_Images[3]=
         {
         &back_slide_show,     
         &icon_previous,       
         &Icon_next            
         };
  TBox                   * const code Screen10_Boxes[4]=
         {
         &Box7,                
         &icon_previous_box,   
         &Icon_next_box,       
         &Slide_Active_area    
         };

  TScreen                Tic_Tac_Toe;
  TBox                   Box10;
  TBox                   Box11;
  TBox                   Box9;
  TButton               Button9;
char Button9_Caption[1] = "";

  TButton               Button8;
char Button8_Caption[1] = "";

  TButton               Button7;
char Button7_Caption[1] = "";

  TButton               Button6;
char Button6_Caption[1] = "";

  TButton               Button5;
char Button5_Caption[1] = "";

  TButton               Button4;
char Button4_Caption[1] = "";

  TButton               Button3;
char Button3_Caption[1] = "";

  TButton               Button2;
char Button2_Caption[1] = "";

  TButton               Button1;
char Button1_Caption[1] = "";

  TBox                   Box8;
  TLabel                 Label36;
char Label36_Caption[17] = "Tic-Tac-Toe Game";

  TImage               Image20;
  TLabel                 Label37;
char Label37_Caption[9] = "New Game";

  TImage               Image21;
  TLabel                 Label38;
char Label38_Caption[11] = " ";

  TLabel                 Label39;
char Label39_Caption[12] = "Time: 00:00";

  TLabel                 XO1;
char XO1_Caption[2] = " ";

  TLabel                 XO2;
char XO2_Caption[2] = " ";

  TLabel                 XO3;
char XO3_Caption[2] = " ";

  TLabel                 XO4;
char XO4_Caption[2] = " ";

  TLabel                 XO5;
char XO5_Caption[2] = " ";

  TLabel                 XO6;
char XO6_Caption[2] = " ";

  TLabel                 XO7;
char XO7_Caption[2] = " ";

  TLabel                 XO8;
char XO8_Caption[2] = " ";

  TLabel                 XO9;
char XO9_Caption[2] = " ";

  TCheckBox                 CheckBox1;
char CheckBox1_Caption[1] = "";

  TLabel                 Label41;
char Label41_Caption[12] = "Remote Play";

  TButton                * const code Screen11_Buttons[9]=
         {
         &Button9,             
         &Button8,             
         &Button7,             
         &Button6,             
         &Button5,             
         &Button4,             
         &Button3,             
         &Button2,             
         &Button1              
         };
  TLabel                 * const code Screen11_Labels[14]=
         {
         &Label36,             
         &Label37,             
         &Label38,             
         &Label39,             
         &XO1,                 
         &XO2,                 
         &XO3,                 
         &XO4,                 
         &XO5,                 
         &XO6,                 
         &XO7,                 
         &XO8,                 
         &XO9,                 
         &Label41              
         };
  TImage                 * const code Screen11_Images[2]=
         {
         &Image20,             
         &Image21              
         };
  TBox                   * const code Screen11_Boxes[4]=
         {
         &Box10,               
         &Box11,               
         &Box9,                
         &Box8                 
         };
  TCheckBox              * const code Screen11_CheckBoxes[1]=
         {
         &CheckBox1            
         };

  TScreen                WiFi;
  TBox                   Box24;
  TLabel                 Label44;
char Label44_Caption[5] = "WiFi";

  TImage               Image23;
  TLabel                 * const code Screen12_Labels[1]=
         {
         &Label44              
         };
  TImage                 * const code Screen12_Images[1]=
         {
         &Image23              
         };
  TBox                   * const code Screen12_Boxes[1]=
         {
         &Box24                
         };

  TScreen                CAN;
  TBox                   Box25;
  TLabel                 Label46;
char Label46_Caption[4] = "CAN";

  TImage               Image26;
  TRadioButton                 RadioButton1;
char RadioButton1_Caption[1] = "";

  TRadioButton                 RadioButton2;
char RadioButton2_Caption[1] = "";

  TRadioButton                 RadioButton3;
char RadioButton3_Caption[1] = "";

  TRadioButton                 RadioButton4;
char RadioButton4_Caption[1] = "";

  TRadioButton                 RadioButton5;
char RadioButton5_Caption[1] = "";

  TRadioButton                 RadioButton6;
char RadioButton6_Caption[1] = "";

  TRadioButton                 RadioButton7;
char RadioButton7_Caption[1] = "";

  TRadioButton                 RadioButton8;
char RadioButton8_Caption[1] = "";

  TLabel                 Label47;
char Label47_Caption[13] = "Press Button";

  TLabel                 Label48;
char Label48_Caption[5] = "LEDs";

  TCircle                Circle2;
  TCircle                Circle3;
  TCircle                Circle4;
  TCircle                Circle5;
  TCircle                Circle6;
  TCircle                Circle7;
  TCircle                Circle8;
  TCircle                Circle9;
  TLabel                 * const code Screen13_Labels[3]=
         {
         &Label46,             
         &Label47,             
         &Label48              
         };
  TImage                 * const code Screen13_Images[1]=
         {
         &Image26              
         };
  TCircle                * const code Screen13_Circles[8]=
         {
         &Circle2,             
         &Circle3,             
         &Circle4,             
         &Circle5,             
         &Circle6,             
         &Circle7,             
         &Circle8,             
         &Circle9              
         };
  TBox                   * const code Screen13_Boxes[1]=
         {
         &Box25                
         };
  TRadioButton           * const code Screen13_RadioButtons[8]=
         {
         &RadioButton1,        
         &RadioButton2,        
         &RadioButton3,        
         &RadioButton4,        
         &RadioButton5,        
         &RadioButton6,        
         &RadioButton7,        
         &RadioButton8         
         };

  TScreen                Screen0;
  TCButton_Round          Diagram14_ButtonRound29 = 
         {
         &Screen0              , //   Diagram14_ButtonRound29.OwnerScreen
         0                     , //   Diagram14_ButtonRound29.Order           
         640                   , //   Diagram14_ButtonRound29.Left            
         320                   , //   Diagram14_ButtonRound29.Top              
         160                   , //   Diagram14_ButtonRound29.Width            
         160                   , //   Diagram14_ButtonRound29.Height        
         0                     , //   Diagram14_ButtonRound29.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound29.Pen_Color       
         1                     , //   Diagram14_ButtonRound29.Visible         
         0                     , //   Diagram14_ButtonRound29.Active           
         1                     , //   Diagram14_ButtonRound29.Transparent     
         &Diagram14_ButtonRound29_Caption, //   Diagram14_ButtonRound29.Caption        
         _taCenter             , //   Diagram14_ButtonRound29.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound29.FontName        
         0xF79E                , //   Diagram14_ButtonRound29.FontColor       
         0                     , //   Diagram14_ButtonRound29.Gradient        
         0                     , //   Diagram14_ButtonRound29.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound29.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound29.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound29.Color           
         5                     , //   Diagram14_ButtonRound29.CornerRadius           
         0                     , //   Diagram14_ButtonRound29.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound29.Press_Color     
         0                     , //   Diagram14_ButtonRound29.OnUpPtr
         0                     , //   Diagram14_ButtonRound29.OnDownPtr
         SaveCR                , //   Diagram14_ButtonRound29.OnClickPtr
         0                       //   Diagram14_ButtonRound29.OnPressPtr
         };
const char Diagram14_ButtonRound29_Caption[6] = "ENTER";

  TCButton_Round          Diagram14_ButtonRound28 = 
         {
         &Screen0              , //   Diagram14_ButtonRound28.OwnerScreen
         1                     , //   Diagram14_ButtonRound28.Order           
         640                   , //   Diagram14_ButtonRound28.Left            
         240                   , //   Diagram14_ButtonRound28.Top              
         160                   , //   Diagram14_ButtonRound28.Width            
         80                    , //   Diagram14_ButtonRound28.Height        
         0                     , //   Diagram14_ButtonRound28.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound28.Pen_Color       
         1                     , //   Diagram14_ButtonRound28.Visible         
         0                     , //   Diagram14_ButtonRound28.Active           
         1                     , //   Diagram14_ButtonRound28.Transparent     
         &Diagram14_ButtonRound28_Caption, //   Diagram14_ButtonRound28.Caption        
         _taCenter             , //   Diagram14_ButtonRound28.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound28.FontName        
         0xF79E                , //   Diagram14_ButtonRound28.FontColor       
         0                     , //   Diagram14_ButtonRound28.Gradient        
         0                     , //   Diagram14_ButtonRound28.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound28.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound28.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound28.Color           
         5                     , //   Diagram14_ButtonRound28.CornerRadius           
         0                     , //   Diagram14_ButtonRound28.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound28.Press_Color     
         0                     , //   Diagram14_ButtonRound28.OnUpPtr
         0                     , //   Diagram14_ButtonRound28.OnDownPtr
         SaveBCK               , //   Diagram14_ButtonRound28.OnClickPtr
         0                       //   Diagram14_ButtonRound28.OnPressPtr
         };
const char Diagram14_ButtonRound28_Caption[5] = "BACK";

  TCButton_Round          Diagram14_ButtonRound27 = 
         {
         &Screen0              , //   Diagram14_ButtonRound27.OwnerScreen
         2                     , //   Diagram14_ButtonRound27.Order           
         0                     , //   Diagram14_ButtonRound27.Left            
         320                   , //   Diagram14_ButtonRound27.Top              
         80                    , //   Diagram14_ButtonRound27.Width            
         80                    , //   Diagram14_ButtonRound27.Height        
         0                     , //   Diagram14_ButtonRound27.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound27.Pen_Color       
         1                     , //   Diagram14_ButtonRound27.Visible         
         0                     , //   Diagram14_ButtonRound27.Active           
         1                     , //   Diagram14_ButtonRound27.Transparent     
         &Diagram14_ButtonRound27_Caption, //   Diagram14_ButtonRound27.Caption        
         _taCenter             , //   Diagram14_ButtonRound27.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound27.FontName        
         0xF79E                , //   Diagram14_ButtonRound27.FontColor       
         0                     , //   Diagram14_ButtonRound27.Gradient        
         0                     , //   Diagram14_ButtonRound27.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound27.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound27.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound27.Color           
         5                     , //   Diagram14_ButtonRound27.CornerRadius           
         0                     , //   Diagram14_ButtonRound27.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound27.Press_Color     
         0                     , //   Diagram14_ButtonRound27.OnUpPtr
         0                     , //   Diagram14_ButtonRound27.OnDownPtr
         SaveL                 , //   Diagram14_ButtonRound27.OnClickPtr
         0                       //   Diagram14_ButtonRound27.OnPressPtr
         };
const char Diagram14_ButtonRound27_Caption[2] = "L";

  TCButton_Round          Diagram14_ButtonRound26 = 
         {
         &Screen0              , //   Diagram14_ButtonRound26.OwnerScreen
         3                     , //   Diagram14_ButtonRound26.Order           
         560                   , //   Diagram14_ButtonRound26.Left            
         240                   , //   Diagram14_ButtonRound26.Top              
         80                    , //   Diagram14_ButtonRound26.Width            
         80                    , //   Diagram14_ButtonRound26.Height        
         0                     , //   Diagram14_ButtonRound26.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound26.Pen_Color       
         1                     , //   Diagram14_ButtonRound26.Visible         
         0                     , //   Diagram14_ButtonRound26.Active           
         1                     , //   Diagram14_ButtonRound26.Transparent     
         &Diagram14_ButtonRound26_Caption, //   Diagram14_ButtonRound26.Caption        
         _taCenter             , //   Diagram14_ButtonRound26.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound26.FontName        
         0xF79E                , //   Diagram14_ButtonRound26.FontColor       
         0                     , //   Diagram14_ButtonRound26.Gradient        
         0                     , //   Diagram14_ButtonRound26.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound26.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound26.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound26.Color           
         5                     , //   Diagram14_ButtonRound26.CornerRadius           
         0                     , //   Diagram14_ButtonRound26.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound26.Press_Color     
         0                     , //   Diagram14_ButtonRound26.OnUpPtr
         0                     , //   Diagram14_ButtonRound26.OnDownPtr
         SaveK                 , //   Diagram14_ButtonRound26.OnClickPtr
         0                       //   Diagram14_ButtonRound26.OnPressPtr
         };
const char Diagram14_ButtonRound26_Caption[2] = "K";

  TCButton_Round          Diagram14_ButtonRound25 = 
         {
         &Screen0              , //   Diagram14_ButtonRound25.OwnerScreen
         4                     , //   Diagram14_ButtonRound25.Order           
         480                   , //   Diagram14_ButtonRound25.Left            
         240                   , //   Diagram14_ButtonRound25.Top              
         80                    , //   Diagram14_ButtonRound25.Width            
         80                    , //   Diagram14_ButtonRound25.Height        
         0                     , //   Diagram14_ButtonRound25.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound25.Pen_Color       
         1                     , //   Diagram14_ButtonRound25.Visible         
         0                     , //   Diagram14_ButtonRound25.Active           
         1                     , //   Diagram14_ButtonRound25.Transparent     
         &Diagram14_ButtonRound25_Caption, //   Diagram14_ButtonRound25.Caption        
         _taCenter             , //   Diagram14_ButtonRound25.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound25.FontName        
         0xF79E                , //   Diagram14_ButtonRound25.FontColor       
         0                     , //   Diagram14_ButtonRound25.Gradient        
         0                     , //   Diagram14_ButtonRound25.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound25.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound25.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound25.Color           
         5                     , //   Diagram14_ButtonRound25.CornerRadius           
         0                     , //   Diagram14_ButtonRound25.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound25.Press_Color     
         0                     , //   Diagram14_ButtonRound25.OnUpPtr
         0                     , //   Diagram14_ButtonRound25.OnDownPtr
         SaveJ                 , //   Diagram14_ButtonRound25.OnClickPtr
         0                       //   Diagram14_ButtonRound25.OnPressPtr
         };
const char Diagram14_ButtonRound25_Caption[2] = "J";

  TCButton_Round          Diagram14_ButtonRound24 = 
         {
         &Screen0              , //   Diagram14_ButtonRound24.OwnerScreen
         5                     , //   Diagram14_ButtonRound24.Order           
         400                   , //   Diagram14_ButtonRound24.Left            
         240                   , //   Diagram14_ButtonRound24.Top              
         80                    , //   Diagram14_ButtonRound24.Width            
         80                    , //   Diagram14_ButtonRound24.Height        
         0                     , //   Diagram14_ButtonRound24.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound24.Pen_Color       
         1                     , //   Diagram14_ButtonRound24.Visible         
         0                     , //   Diagram14_ButtonRound24.Active           
         1                     , //   Diagram14_ButtonRound24.Transparent     
         &Diagram14_ButtonRound24_Caption, //   Diagram14_ButtonRound24.Caption        
         _taCenter             , //   Diagram14_ButtonRound24.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound24.FontName        
         0xF79E                , //   Diagram14_ButtonRound24.FontColor       
         0                     , //   Diagram14_ButtonRound24.Gradient        
         0                     , //   Diagram14_ButtonRound24.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound24.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound24.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound24.Color           
         5                     , //   Diagram14_ButtonRound24.CornerRadius           
         0                     , //   Diagram14_ButtonRound24.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound24.Press_Color     
         0                     , //   Diagram14_ButtonRound24.OnUpPtr
         0                     , //   Diagram14_ButtonRound24.OnDownPtr
         SaveH                 , //   Diagram14_ButtonRound24.OnClickPtr
         0                       //   Diagram14_ButtonRound24.OnPressPtr
         };
const char Diagram14_ButtonRound24_Caption[2] = "H";

  TCButton_Round          Diagram14_ButtonRound23 = 
         {
         &Screen0              , //   Diagram14_ButtonRound23.OwnerScreen
         6                     , //   Diagram14_ButtonRound23.Order           
         320                   , //   Diagram14_ButtonRound23.Left            
         240                   , //   Diagram14_ButtonRound23.Top              
         80                    , //   Diagram14_ButtonRound23.Width            
         80                    , //   Diagram14_ButtonRound23.Height        
         0                     , //   Diagram14_ButtonRound23.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound23.Pen_Color       
         1                     , //   Diagram14_ButtonRound23.Visible         
         0                     , //   Diagram14_ButtonRound23.Active           
         1                     , //   Diagram14_ButtonRound23.Transparent     
         &Diagram14_ButtonRound23_Caption, //   Diagram14_ButtonRound23.Caption        
         _taCenter             , //   Diagram14_ButtonRound23.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound23.FontName        
         0xF79E                , //   Diagram14_ButtonRound23.FontColor       
         0                     , //   Diagram14_ButtonRound23.Gradient        
         0                     , //   Diagram14_ButtonRound23.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound23.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound23.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound23.Color           
         5                     , //   Diagram14_ButtonRound23.CornerRadius           
         0                     , //   Diagram14_ButtonRound23.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound23.Press_Color     
         0                     , //   Diagram14_ButtonRound23.OnUpPtr
         0                     , //   Diagram14_ButtonRound23.OnDownPtr
         SaveG                 , //   Diagram14_ButtonRound23.OnClickPtr
         0                       //   Diagram14_ButtonRound23.OnPressPtr
         };
const char Diagram14_ButtonRound23_Caption[2] = "G";

  TCButton_Round          Diagram14_ButtonRound22 = 
         {
         &Screen0              , //   Diagram14_ButtonRound22.OwnerScreen
         7                     , //   Diagram14_ButtonRound22.Order           
         240                   , //   Diagram14_ButtonRound22.Left            
         240                   , //   Diagram14_ButtonRound22.Top              
         80                    , //   Diagram14_ButtonRound22.Width            
         80                    , //   Diagram14_ButtonRound22.Height        
         0                     , //   Diagram14_ButtonRound22.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound22.Pen_Color       
         1                     , //   Diagram14_ButtonRound22.Visible         
         0                     , //   Diagram14_ButtonRound22.Active           
         1                     , //   Diagram14_ButtonRound22.Transparent     
         &Diagram14_ButtonRound22_Caption, //   Diagram14_ButtonRound22.Caption        
         _taCenter             , //   Diagram14_ButtonRound22.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound22.FontName        
         0xF79E                , //   Diagram14_ButtonRound22.FontColor       
         0                     , //   Diagram14_ButtonRound22.Gradient        
         0                     , //   Diagram14_ButtonRound22.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound22.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound22.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound22.Color           
         5                     , //   Diagram14_ButtonRound22.CornerRadius           
         0                     , //   Diagram14_ButtonRound22.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound22.Press_Color     
         0                     , //   Diagram14_ButtonRound22.OnUpPtr
         0                     , //   Diagram14_ButtonRound22.OnDownPtr
         SaveF                 , //   Diagram14_ButtonRound22.OnClickPtr
         0                       //   Diagram14_ButtonRound22.OnPressPtr
         };
const char Diagram14_ButtonRound22_Caption[2] = "F";

  TCButton_Round          Diagram14_ButtonRound21 = 
         {
         &Screen0              , //   Diagram14_ButtonRound21.OwnerScreen
         8                     , //   Diagram14_ButtonRound21.Order           
         0                     , //   Diagram14_ButtonRound21.Left            
         240                   , //   Diagram14_ButtonRound21.Top              
         80                    , //   Diagram14_ButtonRound21.Width            
         80                    , //   Diagram14_ButtonRound21.Height        
         0                     , //   Diagram14_ButtonRound21.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound21.Pen_Color       
         1                     , //   Diagram14_ButtonRound21.Visible         
         0                     , //   Diagram14_ButtonRound21.Active           
         1                     , //   Diagram14_ButtonRound21.Transparent     
         &Diagram14_ButtonRound21_Caption, //   Diagram14_ButtonRound21.Caption        
         _taCenter             , //   Diagram14_ButtonRound21.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound21.FontName        
         0xF79E                , //   Diagram14_ButtonRound21.FontColor       
         0                     , //   Diagram14_ButtonRound21.Gradient        
         0                     , //   Diagram14_ButtonRound21.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound21.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound21.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound21.Color           
         5                     , //   Diagram14_ButtonRound21.CornerRadius           
         0                     , //   Diagram14_ButtonRound21.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound21.Press_Color     
         0                     , //   Diagram14_ButtonRound21.OnUpPtr
         0                     , //   Diagram14_ButtonRound21.OnDownPtr
         SaveA                 , //   Diagram14_ButtonRound21.OnClickPtr
         0                       //   Diagram14_ButtonRound21.OnPressPtr
         };
const char Diagram14_ButtonRound21_Caption[2] = "A";

  TCButton_Round          Diagram14_ButtonRound20 = 
         {
         &Screen0              , //   Diagram14_ButtonRound20.OwnerScreen
         9                     , //   Diagram14_ButtonRound20.Order           
         160                   , //   Diagram14_ButtonRound20.Left            
         240                   , //   Diagram14_ButtonRound20.Top              
         80                    , //   Diagram14_ButtonRound20.Width            
         80                    , //   Diagram14_ButtonRound20.Height        
         0                     , //   Diagram14_ButtonRound20.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound20.Pen_Color       
         1                     , //   Diagram14_ButtonRound20.Visible         
         0                     , //   Diagram14_ButtonRound20.Active           
         1                     , //   Diagram14_ButtonRound20.Transparent     
         &Diagram14_ButtonRound20_Caption, //   Diagram14_ButtonRound20.Caption        
         _taCenter             , //   Diagram14_ButtonRound20.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound20.FontName        
         0xF79E                , //   Diagram14_ButtonRound20.FontColor       
         0                     , //   Diagram14_ButtonRound20.Gradient        
         0                     , //   Diagram14_ButtonRound20.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound20.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound20.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound20.Color           
         5                     , //   Diagram14_ButtonRound20.CornerRadius           
         0                     , //   Diagram14_ButtonRound20.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound20.Press_Color     
         0                     , //   Diagram14_ButtonRound20.OnUpPtr
         0                     , //   Diagram14_ButtonRound20.OnDownPtr
         SaveD                 , //   Diagram14_ButtonRound20.OnClickPtr
         0                       //   Diagram14_ButtonRound20.OnPressPtr
         };
const char Diagram14_ButtonRound20_Caption[2] = "D";

  TCButton_Round          Diagram14_ButtonRound19 = 
         {
         &Screen0              , //   Diagram14_ButtonRound19.OwnerScreen
         10                    , //   Diagram14_ButtonRound19.Order           
         80                    , //   Diagram14_ButtonRound19.Left            
         240                   , //   Diagram14_ButtonRound19.Top              
         80                    , //   Diagram14_ButtonRound19.Width            
         80                    , //   Diagram14_ButtonRound19.Height        
         0                     , //   Diagram14_ButtonRound19.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound19.Pen_Color       
         1                     , //   Diagram14_ButtonRound19.Visible         
         0                     , //   Diagram14_ButtonRound19.Active           
         1                     , //   Diagram14_ButtonRound19.Transparent     
         &Diagram14_ButtonRound19_Caption, //   Diagram14_ButtonRound19.Caption        
         _taCenter             , //   Diagram14_ButtonRound19.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound19.FontName        
         0xF79E                , //   Diagram14_ButtonRound19.FontColor       
         0                     , //   Diagram14_ButtonRound19.Gradient        
         0                     , //   Diagram14_ButtonRound19.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound19.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound19.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound19.Color           
         5                     , //   Diagram14_ButtonRound19.CornerRadius           
         0                     , //   Diagram14_ButtonRound19.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound19.Press_Color     
         0                     , //   Diagram14_ButtonRound19.OnUpPtr
         0                     , //   Diagram14_ButtonRound19.OnDownPtr
         SaveS                 , //   Diagram14_ButtonRound19.OnClickPtr
         0                       //   Diagram14_ButtonRound19.OnPressPtr
         };
const char Diagram14_ButtonRound19_Caption[2] = "S";

  TCButton_Round          Diagram14_ButtonRound18 = 
         {
         &Screen0              , //   Diagram14_ButtonRound18.OwnerScreen
         11                    , //   Diagram14_ButtonRound18.Order           
         560                   , //   Diagram14_ButtonRound18.Left            
         320                   , //   Diagram14_ButtonRound18.Top              
         80                    , //   Diagram14_ButtonRound18.Width            
         80                    , //   Diagram14_ButtonRound18.Height        
         0                     , //   Diagram14_ButtonRound18.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound18.Pen_Color       
         1                     , //   Diagram14_ButtonRound18.Visible         
         0                     , //   Diagram14_ButtonRound18.Active           
         1                     , //   Diagram14_ButtonRound18.Transparent     
         &Diagram14_ButtonRound18_Caption, //   Diagram14_ButtonRound18.Caption        
         _taCenter             , //   Diagram14_ButtonRound18.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound18.FontName        
         0xF79E                , //   Diagram14_ButtonRound18.FontColor       
         0                     , //   Diagram14_ButtonRound18.Gradient        
         0                     , //   Diagram14_ButtonRound18.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound18.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound18.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound18.Color           
         5                     , //   Diagram14_ButtonRound18.CornerRadius           
         0                     , //   Diagram14_ButtonRound18.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound18.Press_Color     
         0                     , //   Diagram14_ButtonRound18.OnUpPtr
         0                     , //   Diagram14_ButtonRound18.OnDownPtr
         SaveM                 , //   Diagram14_ButtonRound18.OnClickPtr
         0                       //   Diagram14_ButtonRound18.OnPressPtr
         };
const char Diagram14_ButtonRound18_Caption[2] = "M";

  TCButton_Round          Diagram14_ButtonRound17 = 
         {
         &Screen0              , //   Diagram14_ButtonRound17.OwnerScreen
         12                    , //   Diagram14_ButtonRound17.Order           
         480                   , //   Diagram14_ButtonRound17.Left            
         320                   , //   Diagram14_ButtonRound17.Top              
         80                    , //   Diagram14_ButtonRound17.Width            
         80                    , //   Diagram14_ButtonRound17.Height        
         0                     , //   Diagram14_ButtonRound17.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound17.Pen_Color       
         1                     , //   Diagram14_ButtonRound17.Visible         
         0                     , //   Diagram14_ButtonRound17.Active           
         1                     , //   Diagram14_ButtonRound17.Transparent     
         &Diagram14_ButtonRound17_Caption, //   Diagram14_ButtonRound17.Caption        
         _taCenter             , //   Diagram14_ButtonRound17.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound17.FontName        
         0xF79E                , //   Diagram14_ButtonRound17.FontColor       
         0                     , //   Diagram14_ButtonRound17.Gradient        
         0                     , //   Diagram14_ButtonRound17.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound17.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound17.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound17.Color           
         5                     , //   Diagram14_ButtonRound17.CornerRadius           
         0                     , //   Diagram14_ButtonRound17.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound17.Press_Color     
         0                     , //   Diagram14_ButtonRound17.OnUpPtr
         0                     , //   Diagram14_ButtonRound17.OnDownPtr
         SaveN                 , //   Diagram14_ButtonRound17.OnClickPtr
         0                       //   Diagram14_ButtonRound17.OnPressPtr
         };
const char Diagram14_ButtonRound17_Caption[2] = "N";

  TCButton_Round          Diagram14_ButtonRound16 = 
         {
         &Screen0              , //   Diagram14_ButtonRound16.OwnerScreen
         13                    , //   Diagram14_ButtonRound16.Order           
         400                   , //   Diagram14_ButtonRound16.Left            
         320                   , //   Diagram14_ButtonRound16.Top              
         80                    , //   Diagram14_ButtonRound16.Width            
         80                    , //   Diagram14_ButtonRound16.Height        
         0                     , //   Diagram14_ButtonRound16.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound16.Pen_Color       
         1                     , //   Diagram14_ButtonRound16.Visible         
         0                     , //   Diagram14_ButtonRound16.Active           
         1                     , //   Diagram14_ButtonRound16.Transparent     
         &Diagram14_ButtonRound16_Caption, //   Diagram14_ButtonRound16.Caption        
         _taCenter             , //   Diagram14_ButtonRound16.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound16.FontName        
         0xF79E                , //   Diagram14_ButtonRound16.FontColor       
         0                     , //   Diagram14_ButtonRound16.Gradient        
         0                     , //   Diagram14_ButtonRound16.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound16.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound16.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound16.Color           
         5                     , //   Diagram14_ButtonRound16.CornerRadius           
         0                     , //   Diagram14_ButtonRound16.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound16.Press_Color     
         0                     , //   Diagram14_ButtonRound16.OnUpPtr
         0                     , //   Diagram14_ButtonRound16.OnDownPtr
         SaveB                 , //   Diagram14_ButtonRound16.OnClickPtr
         0                       //   Diagram14_ButtonRound16.OnPressPtr
         };
const char Diagram14_ButtonRound16_Caption[2] = "B";

  TCButton_Round          Diagram14_ButtonRound15 = 
         {
         &Screen0              , //   Diagram14_ButtonRound15.OwnerScreen
         14                    , //   Diagram14_ButtonRound15.Order           
         320                   , //   Diagram14_ButtonRound15.Left            
         320                   , //   Diagram14_ButtonRound15.Top              
         80                    , //   Diagram14_ButtonRound15.Width            
         80                    , //   Diagram14_ButtonRound15.Height        
         0                     , //   Diagram14_ButtonRound15.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound15.Pen_Color       
         1                     , //   Diagram14_ButtonRound15.Visible         
         0                     , //   Diagram14_ButtonRound15.Active           
         1                     , //   Diagram14_ButtonRound15.Transparent     
         &Diagram14_ButtonRound15_Caption, //   Diagram14_ButtonRound15.Caption        
         _taCenter             , //   Diagram14_ButtonRound15.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound15.FontName        
         0xF79E                , //   Diagram14_ButtonRound15.FontColor       
         0                     , //   Diagram14_ButtonRound15.Gradient        
         0                     , //   Diagram14_ButtonRound15.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound15.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound15.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound15.Color           
         5                     , //   Diagram14_ButtonRound15.CornerRadius           
         0                     , //   Diagram14_ButtonRound15.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound15.Press_Color     
         0                     , //   Diagram14_ButtonRound15.OnUpPtr
         0                     , //   Diagram14_ButtonRound15.OnDownPtr
         SaveV                 , //   Diagram14_ButtonRound15.OnClickPtr
         0                       //   Diagram14_ButtonRound15.OnPressPtr
         };
const char Diagram14_ButtonRound15_Caption[2] = "V";

  TCButton_Round          Diagram14_ButtonRound14 = 
         {
         &Screen0              , //   Diagram14_ButtonRound14.OwnerScreen
         15                    , //   Diagram14_ButtonRound14.Order           
         80                    , //   Diagram14_ButtonRound14.Left            
         320                   , //   Diagram14_ButtonRound14.Top              
         80                    , //   Diagram14_ButtonRound14.Width            
         80                    , //   Diagram14_ButtonRound14.Height        
         0                     , //   Diagram14_ButtonRound14.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound14.Pen_Color       
         1                     , //   Diagram14_ButtonRound14.Visible         
         0                     , //   Diagram14_ButtonRound14.Active           
         1                     , //   Diagram14_ButtonRound14.Transparent     
         &Diagram14_ButtonRound14_Caption, //   Diagram14_ButtonRound14.Caption        
         _taCenter             , //   Diagram14_ButtonRound14.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound14.FontName        
         0xF79E                , //   Diagram14_ButtonRound14.FontColor       
         0                     , //   Diagram14_ButtonRound14.Gradient        
         0                     , //   Diagram14_ButtonRound14.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound14.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound14.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound14.Color           
         5                     , //   Diagram14_ButtonRound14.CornerRadius           
         0                     , //   Diagram14_ButtonRound14.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound14.Press_Color     
         0                     , //   Diagram14_ButtonRound14.OnUpPtr
         0                     , //   Diagram14_ButtonRound14.OnDownPtr
         SaveZ                 , //   Diagram14_ButtonRound14.OnClickPtr
         0                       //   Diagram14_ButtonRound14.OnPressPtr
         };
const char Diagram14_ButtonRound14_Caption[2] = "Z";

  TCButton_Round          Diagram14_ButtonRound13 = 
         {
         &Screen0              , //   Diagram14_ButtonRound13.OwnerScreen
         16                    , //   Diagram14_ButtonRound13.Order           
         240                   , //   Diagram14_ButtonRound13.Left            
         320                   , //   Diagram14_ButtonRound13.Top              
         80                    , //   Diagram14_ButtonRound13.Width            
         80                    , //   Diagram14_ButtonRound13.Height        
         0                     , //   Diagram14_ButtonRound13.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound13.Pen_Color       
         1                     , //   Diagram14_ButtonRound13.Visible         
         0                     , //   Diagram14_ButtonRound13.Active           
         1                     , //   Diagram14_ButtonRound13.Transparent     
         &Diagram14_ButtonRound13_Caption, //   Diagram14_ButtonRound13.Caption        
         _taCenter             , //   Diagram14_ButtonRound13.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound13.FontName        
         0xF79E                , //   Diagram14_ButtonRound13.FontColor       
         0                     , //   Diagram14_ButtonRound13.Gradient        
         0                     , //   Diagram14_ButtonRound13.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound13.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound13.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound13.Color           
         5                     , //   Diagram14_ButtonRound13.CornerRadius           
         0                     , //   Diagram14_ButtonRound13.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound13.Press_Color     
         0                     , //   Diagram14_ButtonRound13.OnUpPtr
         0                     , //   Diagram14_ButtonRound13.OnDownPtr
         SaveC                 , //   Diagram14_ButtonRound13.OnClickPtr
         0                       //   Diagram14_ButtonRound13.OnPressPtr
         };
const char Diagram14_ButtonRound13_Caption[2] = "C";

  TCButton_Round          Diagram14_ButtonRound12 = 
         {
         &Screen0              , //   Diagram14_ButtonRound12.OwnerScreen
         17                    , //   Diagram14_ButtonRound12.Order           
         160                   , //   Diagram14_ButtonRound12.Left            
         320                   , //   Diagram14_ButtonRound12.Top              
         80                    , //   Diagram14_ButtonRound12.Width            
         80                    , //   Diagram14_ButtonRound12.Height        
         0                     , //   Diagram14_ButtonRound12.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound12.Pen_Color       
         1                     , //   Diagram14_ButtonRound12.Visible         
         0                     , //   Diagram14_ButtonRound12.Active           
         1                     , //   Diagram14_ButtonRound12.Transparent     
         &Diagram14_ButtonRound12_Caption, //   Diagram14_ButtonRound12.Caption        
         _taCenter             , //   Diagram14_ButtonRound12.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound12.FontName        
         0xF79E                , //   Diagram14_ButtonRound12.FontColor       
         0                     , //   Diagram14_ButtonRound12.Gradient        
         0                     , //   Diagram14_ButtonRound12.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound12.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound12.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound12.Color           
         5                     , //   Diagram14_ButtonRound12.CornerRadius           
         0                     , //   Diagram14_ButtonRound12.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound12.Press_Color     
         0                     , //   Diagram14_ButtonRound12.OnUpPtr
         0                     , //   Diagram14_ButtonRound12.OnDownPtr
         SaveX                 , //   Diagram14_ButtonRound12.OnClickPtr
         0                       //   Diagram14_ButtonRound12.OnPressPtr
         };
const char Diagram14_ButtonRound12_Caption[2] = "X";

  TCButton_Round          Diagram14_ButtonRound11 = 
         {
         &Screen0              , //   Diagram14_ButtonRound11.OwnerScreen
         18                    , //   Diagram14_ButtonRound11.Order           
         640                   , //   Diagram14_ButtonRound11.Left            
         160                   , //   Diagram14_ButtonRound11.Top              
         80                    , //   Diagram14_ButtonRound11.Width            
         80                    , //   Diagram14_ButtonRound11.Height        
         0                     , //   Diagram14_ButtonRound11.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound11.Pen_Color       
         1                     , //   Diagram14_ButtonRound11.Visible         
         0                     , //   Diagram14_ButtonRound11.Active           
         1                     , //   Diagram14_ButtonRound11.Transparent     
         &Diagram14_ButtonRound11_Caption, //   Diagram14_ButtonRound11.Caption        
         _taCenter             , //   Diagram14_ButtonRound11.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound11.FontName        
         0xF79E                , //   Diagram14_ButtonRound11.FontColor       
         0                     , //   Diagram14_ButtonRound11.Gradient        
         0                     , //   Diagram14_ButtonRound11.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound11.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound11.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound11.Color           
         5                     , //   Diagram14_ButtonRound11.CornerRadius           
         0                     , //   Diagram14_ButtonRound11.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound11.Press_Color     
         0                     , //   Diagram14_ButtonRound11.OnUpPtr
         0                     , //   Diagram14_ButtonRound11.OnDownPtr
         SaveO                 , //   Diagram14_ButtonRound11.OnClickPtr
         0                       //   Diagram14_ButtonRound11.OnPressPtr
         };
const char Diagram14_ButtonRound11_Caption[2] = "O";

  TCButton_Round          Diagram14_ButtonRound10 = 
         {
         &Screen0              , //   Diagram14_ButtonRound10.OwnerScreen
         19                    , //   Diagram14_ButtonRound10.Order           
         720                   , //   Diagram14_ButtonRound10.Left            
         160                   , //   Diagram14_ButtonRound10.Top              
         80                    , //   Diagram14_ButtonRound10.Width            
         80                    , //   Diagram14_ButtonRound10.Height        
         0                     , //   Diagram14_ButtonRound10.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound10.Pen_Color       
         1                     , //   Diagram14_ButtonRound10.Visible         
         0                     , //   Diagram14_ButtonRound10.Active           
         1                     , //   Diagram14_ButtonRound10.Transparent     
         &Diagram14_ButtonRound10_Caption, //   Diagram14_ButtonRound10.Caption        
         _taCenter             , //   Diagram14_ButtonRound10.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound10.FontName        
         0xF79E                , //   Diagram14_ButtonRound10.FontColor       
         0                     , //   Diagram14_ButtonRound10.Gradient        
         0                     , //   Diagram14_ButtonRound10.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound10.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound10.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound10.Color           
         5                     , //   Diagram14_ButtonRound10.CornerRadius           
         0                     , //   Diagram14_ButtonRound10.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound10.Press_Color     
         0                     , //   Diagram14_ButtonRound10.OnUpPtr
         0                     , //   Diagram14_ButtonRound10.OnDownPtr
         SaveP                 , //   Diagram14_ButtonRound10.OnClickPtr
         0                       //   Diagram14_ButtonRound10.OnPressPtr
         };
const char Diagram14_ButtonRound10_Caption[2] = "P";

  TCButton_Round          Diagram14_ButtonRound9 = 
         {
         &Screen0              , //   Diagram14_ButtonRound9.OwnerScreen
         20                    , //   Diagram14_ButtonRound9.Order           
         560                   , //   Diagram14_ButtonRound9.Left            
         160                   , //   Diagram14_ButtonRound9.Top              
         80                    , //   Diagram14_ButtonRound9.Width            
         80                    , //   Diagram14_ButtonRound9.Height        
         0                     , //   Diagram14_ButtonRound9.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound9.Pen_Color       
         1                     , //   Diagram14_ButtonRound9.Visible         
         0                     , //   Diagram14_ButtonRound9.Active           
         1                     , //   Diagram14_ButtonRound9.Transparent     
         &Diagram14_ButtonRound9_Caption, //   Diagram14_ButtonRound9.Caption        
         _taCenter             , //   Diagram14_ButtonRound9.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound9.FontName        
         0xF79E                , //   Diagram14_ButtonRound9.FontColor       
         0                     , //   Diagram14_ButtonRound9.Gradient        
         0                     , //   Diagram14_ButtonRound9.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound9.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound9.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound9.Color           
         5                     , //   Diagram14_ButtonRound9.CornerRadius           
         0                     , //   Diagram14_ButtonRound9.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound9.Press_Color     
         0                     , //   Diagram14_ButtonRound9.OnUpPtr
         0                     , //   Diagram14_ButtonRound9.OnDownPtr
         SaveI                 , //   Diagram14_ButtonRound9.OnClickPtr
         0                       //   Diagram14_ButtonRound9.OnPressPtr
         };
const char Diagram14_ButtonRound9_Caption[2] = "I";

  TCButton_Round          Diagram14_ButtonRound8 = 
         {
         &Screen0              , //   Diagram14_ButtonRound8.OwnerScreen
         21                    , //   Diagram14_ButtonRound8.Order           
         480                   , //   Diagram14_ButtonRound8.Left            
         160                   , //   Diagram14_ButtonRound8.Top              
         80                    , //   Diagram14_ButtonRound8.Width            
         80                    , //   Diagram14_ButtonRound8.Height        
         0                     , //   Diagram14_ButtonRound8.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound8.Pen_Color       
         1                     , //   Diagram14_ButtonRound8.Visible         
         0                     , //   Diagram14_ButtonRound8.Active           
         1                     , //   Diagram14_ButtonRound8.Transparent     
         &Diagram14_ButtonRound8_Caption, //   Diagram14_ButtonRound8.Caption        
         _taCenter             , //   Diagram14_ButtonRound8.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound8.FontName        
         0xF79E                , //   Diagram14_ButtonRound8.FontColor       
         0                     , //   Diagram14_ButtonRound8.Gradient        
         0                     , //   Diagram14_ButtonRound8.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound8.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound8.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound8.Color           
         5                     , //   Diagram14_ButtonRound8.CornerRadius           
         0                     , //   Diagram14_ButtonRound8.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound8.Press_Color     
         0                     , //   Diagram14_ButtonRound8.OnUpPtr
         0                     , //   Diagram14_ButtonRound8.OnDownPtr
         SaveU                 , //   Diagram14_ButtonRound8.OnClickPtr
         0                       //   Diagram14_ButtonRound8.OnPressPtr
         };
const char Diagram14_ButtonRound8_Caption[2] = "U";

  TCButton_Round          Diagram14_ButtonRound7 = 
         {
         &Screen0              , //   Diagram14_ButtonRound7.OwnerScreen
         22                    , //   Diagram14_ButtonRound7.Order           
         400                   , //   Diagram14_ButtonRound7.Left            
         160                   , //   Diagram14_ButtonRound7.Top              
         80                    , //   Diagram14_ButtonRound7.Width            
         80                    , //   Diagram14_ButtonRound7.Height        
         0                     , //   Diagram14_ButtonRound7.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound7.Pen_Color       
         1                     , //   Diagram14_ButtonRound7.Visible         
         0                     , //   Diagram14_ButtonRound7.Active           
         1                     , //   Diagram14_ButtonRound7.Transparent     
         &Diagram14_ButtonRound7_Caption, //   Diagram14_ButtonRound7.Caption        
         _taCenter             , //   Diagram14_ButtonRound7.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound7.FontName        
         0xF79E                , //   Diagram14_ButtonRound7.FontColor       
         0                     , //   Diagram14_ButtonRound7.Gradient        
         0                     , //   Diagram14_ButtonRound7.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound7.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound7.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound7.Color           
         5                     , //   Diagram14_ButtonRound7.CornerRadius           
         0                     , //   Diagram14_ButtonRound7.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound7.Press_Color     
         0                     , //   Diagram14_ButtonRound7.OnUpPtr
         0                     , //   Diagram14_ButtonRound7.OnDownPtr
         SaveY                 , //   Diagram14_ButtonRound7.OnClickPtr
         0                       //   Diagram14_ButtonRound7.OnPressPtr
         };
const char Diagram14_ButtonRound7_Caption[2] = "Y";

  TCButton_Round          Diagram14_ButtonRound6 = 
         {
         &Screen0              , //   Diagram14_ButtonRound6.OwnerScreen
         23                    , //   Diagram14_ButtonRound6.Order           
         320                   , //   Diagram14_ButtonRound6.Left            
         160                   , //   Diagram14_ButtonRound6.Top              
         80                    , //   Diagram14_ButtonRound6.Width            
         80                    , //   Diagram14_ButtonRound6.Height        
         0                     , //   Diagram14_ButtonRound6.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound6.Pen_Color       
         1                     , //   Diagram14_ButtonRound6.Visible         
         0                     , //   Diagram14_ButtonRound6.Active           
         1                     , //   Diagram14_ButtonRound6.Transparent     
         &Diagram14_ButtonRound6_Caption, //   Diagram14_ButtonRound6.Caption        
         _taCenter             , //   Diagram14_ButtonRound6.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound6.FontName        
         0xF79E                , //   Diagram14_ButtonRound6.FontColor       
         0                     , //   Diagram14_ButtonRound6.Gradient        
         0                     , //   Diagram14_ButtonRound6.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound6.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound6.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound6.Color           
         5                     , //   Diagram14_ButtonRound6.CornerRadius           
         0                     , //   Diagram14_ButtonRound6.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound6.Press_Color     
         0                     , //   Diagram14_ButtonRound6.OnUpPtr
         0                     , //   Diagram14_ButtonRound6.OnDownPtr
         SaveT                 , //   Diagram14_ButtonRound6.OnClickPtr
         0                       //   Diagram14_ButtonRound6.OnPressPtr
         };
const char Diagram14_ButtonRound6_Caption[2] = "T";

  TCButton_Round          Diagram14_ButtonRound5 = 
         {
         &Screen0              , //   Diagram14_ButtonRound5.OwnerScreen
         24                    , //   Diagram14_ButtonRound5.Order           
         240                   , //   Diagram14_ButtonRound5.Left            
         160                   , //   Diagram14_ButtonRound5.Top              
         80                    , //   Diagram14_ButtonRound5.Width            
         80                    , //   Diagram14_ButtonRound5.Height        
         0                     , //   Diagram14_ButtonRound5.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound5.Pen_Color       
         1                     , //   Diagram14_ButtonRound5.Visible         
         0                     , //   Diagram14_ButtonRound5.Active           
         1                     , //   Diagram14_ButtonRound5.Transparent     
         &Diagram14_ButtonRound5_Caption, //   Diagram14_ButtonRound5.Caption        
         _taCenter             , //   Diagram14_ButtonRound5.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound5.FontName        
         0xF79E                , //   Diagram14_ButtonRound5.FontColor       
         0                     , //   Diagram14_ButtonRound5.Gradient        
         0                     , //   Diagram14_ButtonRound5.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound5.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound5.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound5.Color           
         5                     , //   Diagram14_ButtonRound5.CornerRadius           
         0                     , //   Diagram14_ButtonRound5.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound5.Press_Color     
         0                     , //   Diagram14_ButtonRound5.OnUpPtr
         0                     , //   Diagram14_ButtonRound5.OnDownPtr
         SaveR                 , //   Diagram14_ButtonRound5.OnClickPtr
         0                       //   Diagram14_ButtonRound5.OnPressPtr
         };
const char Diagram14_ButtonRound5_Caption[2] = "R";

  TCButton_Round          Diagram14_ButtonRound4 = 
         {
         &Screen0              , //   Diagram14_ButtonRound4.OwnerScreen
         25                    , //   Diagram14_ButtonRound4.Order           
         0                     , //   Diagram14_ButtonRound4.Left            
         160                   , //   Diagram14_ButtonRound4.Top              
         80                    , //   Diagram14_ButtonRound4.Width            
         80                    , //   Diagram14_ButtonRound4.Height        
         0                     , //   Diagram14_ButtonRound4.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound4.Pen_Color       
         1                     , //   Diagram14_ButtonRound4.Visible         
         0                     , //   Diagram14_ButtonRound4.Active           
         1                     , //   Diagram14_ButtonRound4.Transparent     
         &Diagram14_ButtonRound4_Caption, //   Diagram14_ButtonRound4.Caption        
         _taCenter             , //   Diagram14_ButtonRound4.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound4.FontName        
         0xF79E                , //   Diagram14_ButtonRound4.FontColor       
         0                     , //   Diagram14_ButtonRound4.Gradient        
         0                     , //   Diagram14_ButtonRound4.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound4.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound4.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound4.Color           
         5                     , //   Diagram14_ButtonRound4.CornerRadius           
         0                     , //   Diagram14_ButtonRound4.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound4.Press_Color     
         0                     , //   Diagram14_ButtonRound4.OnUpPtr
         0                     , //   Diagram14_ButtonRound4.OnDownPtr
         SaveQ                 , //   Diagram14_ButtonRound4.OnClickPtr
         0                       //   Diagram14_ButtonRound4.OnPressPtr
         };
const char Diagram14_ButtonRound4_Caption[2] = "Q";

  TCButton_Round          Diagram14_ButtonRound3 = 
         {
         &Screen0              , //   Diagram14_ButtonRound3.OwnerScreen
         26                    , //   Diagram14_ButtonRound3.Order           
         160                   , //   Diagram14_ButtonRound3.Left            
         160                   , //   Diagram14_ButtonRound3.Top              
         80                    , //   Diagram14_ButtonRound3.Width            
         80                    , //   Diagram14_ButtonRound3.Height        
         0                     , //   Diagram14_ButtonRound3.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound3.Pen_Color       
         1                     , //   Diagram14_ButtonRound3.Visible         
         0                     , //   Diagram14_ButtonRound3.Active           
         1                     , //   Diagram14_ButtonRound3.Transparent     
         &Diagram14_ButtonRound3_Caption, //   Diagram14_ButtonRound3.Caption        
         _taCenter             , //   Diagram14_ButtonRound3.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound3.FontName        
         0xF79E                , //   Diagram14_ButtonRound3.FontColor       
         0                     , //   Diagram14_ButtonRound3.Gradient        
         0                     , //   Diagram14_ButtonRound3.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound3.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound3.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound3.Color           
         5                     , //   Diagram14_ButtonRound3.CornerRadius           
         0                     , //   Diagram14_ButtonRound3.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound3.Press_Color     
         0                     , //   Diagram14_ButtonRound3.OnUpPtr
         0                     , //   Diagram14_ButtonRound3.OnDownPtr
         SaveE                 , //   Diagram14_ButtonRound3.OnClickPtr
         0                       //   Diagram14_ButtonRound3.OnPressPtr
         };
const char Diagram14_ButtonRound3_Caption[2] = "E";

  TCButton_Round          Diagram14_ButtonRound2 = 
         {
         &Screen0              , //   Diagram14_ButtonRound2.OwnerScreen
         27                    , //   Diagram14_ButtonRound2.Order           
         80                    , //   Diagram14_ButtonRound2.Left            
         160                   , //   Diagram14_ButtonRound2.Top              
         80                    , //   Diagram14_ButtonRound2.Width            
         80                    , //   Diagram14_ButtonRound2.Height        
         0                     , //   Diagram14_ButtonRound2.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound2.Pen_Color       
         1                     , //   Diagram14_ButtonRound2.Visible         
         0                     , //   Diagram14_ButtonRound2.Active           
         1                     , //   Diagram14_ButtonRound2.Transparent     
         &Diagram14_ButtonRound2_Caption, //   Diagram14_ButtonRound2.Caption        
         _taCenter             , //   Diagram14_ButtonRound2.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound2.FontName        
         0xF79E                , //   Diagram14_ButtonRound2.FontColor       
         0                     , //   Diagram14_ButtonRound2.Gradient        
         0                     , //   Diagram14_ButtonRound2.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound2.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound2.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound2.Color           
         5                     , //   Diagram14_ButtonRound2.CornerRadius           
         0                     , //   Diagram14_ButtonRound2.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound2.Press_Color     
         0                     , //   Diagram14_ButtonRound2.OnUpPtr
         0                     , //   Diagram14_ButtonRound2.OnDownPtr
         SaveW                 , //   Diagram14_ButtonRound2.OnClickPtr
         0                       //   Diagram14_ButtonRound2.OnPressPtr
         };
const char Diagram14_ButtonRound2_Caption[2] = "W";

  TCButton_Round          Diagram14_ButtonRound1 = 
         {
         &Screen0              , //   Diagram14_ButtonRound1.OwnerScreen
         28                    , //   Diagram14_ButtonRound1.Order           
         0                     , //   Diagram14_ButtonRound1.Left            
         400                   , //   Diagram14_ButtonRound1.Top              
         640                   , //   Diagram14_ButtonRound1.Width            
         80                    , //   Diagram14_ButtonRound1.Height        
         0                     , //   Diagram14_ButtonRound1.Pen_Width          
         0x0000                , //   Diagram14_ButtonRound1.Pen_Color       
         1                     , //   Diagram14_ButtonRound1.Visible         
         0                     , //   Diagram14_ButtonRound1.Active           
         1                     , //   Diagram14_ButtonRound1.Transparent     
         &Diagram14_ButtonRound1_Caption, //   Diagram14_ButtonRound1.Caption        
         _taCenter             , //   Diagram14_ButtonRound1.TextAlign        
         &Tahoma23x29_Regular  , //   Diagram14_ButtonRound1.FontName        
         0xF79E                , //   Diagram14_ButtonRound1.FontColor       
         0                     , //   Diagram14_ButtonRound1.Gradient        
         0                     , //   Diagram14_ButtonRound1.Gradient_Orientation    
         0x632C                , //   Diagram14_ButtonRound1.Gradient_Start_Color    
         0x6304                , //   Diagram14_ButtonRound1.Gradient_End_Color    
         0xE71C                , //   Diagram14_ButtonRound1.Color           
         5                     , //   Diagram14_ButtonRound1.CornerRadius           
         0                     , //   Diagram14_ButtonRound1.PressColEnabled 
         0xE267                , //   Diagram14_ButtonRound1.Press_Color     
         0                     , //   Diagram14_ButtonRound1.OnUpPtr
         0                     , //   Diagram14_ButtonRound1.OnDownPtr
         SaveSPC               , //   Diagram14_ButtonRound1.OnClickPtr
         0                       //   Diagram14_ButtonRound1.OnPressPtr
         };
const char Diagram14_ButtonRound1_Caption[6] = "SPACE";

  TLabel                 Diagram14_desc;
char Diagram14_desc_Caption[50] = "Initializing...";

  TLabel                 Diagram14_bigHeader;
char Diagram14_bigHeader_Caption[26] = "mikromedia7  for  STM32F4";

  TLabel                 Diagram14_smallHeader;
char Diagram14_smallHeader_Caption[13] = "WiFi example";

  TBox_Round             BoxRound1;
  TCButton_Round         * const code Screen14_CButtons_Round[29]=
         {
         &Diagram14_ButtonRound29,
         &Diagram14_ButtonRound28,
         &Diagram14_ButtonRound27,
         &Diagram14_ButtonRound26,
         &Diagram14_ButtonRound25,
         &Diagram14_ButtonRound24,
         &Diagram14_ButtonRound23,
         &Diagram14_ButtonRound22,
         &Diagram14_ButtonRound21,
         &Diagram14_ButtonRound20,
         &Diagram14_ButtonRound19,
         &Diagram14_ButtonRound18,
         &Diagram14_ButtonRound17,
         &Diagram14_ButtonRound16,
         &Diagram14_ButtonRound15,
         &Diagram14_ButtonRound14,
         &Diagram14_ButtonRound13,
         &Diagram14_ButtonRound12,
         &Diagram14_ButtonRound11,
         &Diagram14_ButtonRound10,
         &Diagram14_ButtonRound9,
         &Diagram14_ButtonRound8,
         &Diagram14_ButtonRound7,
         &Diagram14_ButtonRound6,
         &Diagram14_ButtonRound5,
         &Diagram14_ButtonRound4,
         &Diagram14_ButtonRound3,
         &Diagram14_ButtonRound2,
         &Diagram14_ButtonRound1
         };
  TLabel                 * const code Screen14_Labels[3]=
         {
         &Diagram14_desc,      
         &Diagram14_bigHeader, 
         &Diagram14_smallHeader
         };
  TBox_Round             * const code Screen14_Boxes_Round[1]=
         {
         &BoxRound1            
         };

  TScreen                Screen1;
  TBox                   Box26;
  TLabel                 line1;
char line1_Caption[51] = "Type something!";

  TLabel                 line2;
char line2_Caption[51] = " ";

  TLabel                 line3;
char line3_Caption[51] = " ";

  TButton_Round          ButtonW;
char ButtonW_Caption[2] = "W";

  TButton_Round          ButtonE;
char ButtonE_Caption[2] = "E";

  TButton_Round          ButtonQ;
char ButtonQ_Caption[2] = "Q";

  TButton_Round          ButtonR;
char ButtonR_Caption[2] = "R";

  TButton_Round          ButtonT;
char ButtonT_Caption[2] = "T";

  TButton_Round          ButtonY;
char ButtonY_Caption[2] = "Y";

  TButton_Round          ButtonU;
char ButtonU_Caption[2] = "U";

  TButton_Round          ButtonI;
char ButtonI_Caption[2] = "I";

  TButton_Round          ButtonP;
char ButtonP_Caption[2] = "P";

  TButton_Round          ButtonO;
char ButtonO_Caption[2] = "O";

  TButton_Round          ButtonX;
char ButtonX_Caption[2] = "X";

  TButton_Round          ButtonC;
char ButtonC_Caption[2] = "C";

  TButton_Round          ButtonZ;
char ButtonZ_Caption[2] = "Z";

  TButton_Round          ButtonV;
char ButtonV_Caption[2] = "V";

  TButton_Round          ButtonB;
char ButtonB_Caption[2] = "B";

  TButton_Round          ButtonN;
char ButtonN_Caption[2] = "N";

  TButton_Round          ButtonM;
char ButtonM_Caption[2] = "M";

  TButton_Round          ButtonS;
char ButtonS_Caption[2] = "S";

  TButton_Round          ButtonD;
char ButtonD_Caption[2] = "D";

  TButton_Round          ButtonA;
char ButtonA_Caption[2] = "A";

  TButton_Round          ButtonF;
char ButtonF_Caption[2] = "F";

  TButton_Round          ButtonG;
char ButtonG_Caption[2] = "G";

  TButton_Round          ButtonH;
char ButtonH_Caption[2] = "H";

  TButton_Round          ButtonJ;
char ButtonJ_Caption[2] = "J";

  TButton_Round          ButtonK;
char ButtonK_Caption[2] = "K";

  TButton_Round          ButtonL;
char ButtonL_Caption[2] = "L";

  TButton_Round          ButtonBCK;
char ButtonBCK_Caption[5] = "BACK";

  TButton_Round          ButtonCR;
char ButtonCR_Caption[6] = "ENTER";

  TBox                   Box27;
  TImage               Image28;
  TLabel                 Label49;
char Label49_Caption[5] = "WiFi";

  TLabel                 ipLabel;
char ipLabel_Caption[51] = "Type in your browser: 000.000.000.000";

  TButton_Round          ButtonSPC;
char ButtonSPC_Caption[6] = "SPACE";

  TButton_Round          ButtonCLRSCR;
char ButtonCLRSCR_Caption[4] = "CLR";

  TButton_Round          * const code Screen15_Buttons_Round[30]=
         {
         &ButtonW,             
         &ButtonE,             
         &ButtonQ,             
         &ButtonR,             
         &ButtonT,             
         &ButtonY,             
         &ButtonU,             
         &ButtonI,             
         &ButtonP,             
         &ButtonO,             
         &ButtonX,             
         &ButtonC,             
         &ButtonZ,             
         &ButtonV,             
         &ButtonB,             
         &ButtonN,             
         &ButtonM,             
         &ButtonS,             
         &ButtonD,             
         &ButtonA,             
         &ButtonF,             
         &ButtonG,             
         &ButtonH,             
         &ButtonJ,             
         &ButtonK,             
         &ButtonL,             
         &ButtonBCK,           
         &ButtonCR,            
         &ButtonSPC,           
         &ButtonCLRSCR         
         };
  TLabel                 * const code Screen15_Labels[5]=
         {
         &line1,               
         &line2,               
         &line3,               
         &Label49,             
         &ipLabel              
         };
  TImage                 * const code Screen15_Images[1]=
         {
         &Image28              
         };
  TBox                   * const code Screen15_Boxes[2]=
         {
         &Box26,               
         &Box27                
         };



static void InitializeObjects() {
  Home.Color                     = 0x2D33;
  Home.Width                     = 800;
  Home.Height                    = 480;
  Home.ButtonsCount              = 0;
  Home.Buttons_RoundCount        = 0;
  Home.CButtons_RoundCount       = 0;
  Home.LabelsCount               = 12;
  Home.Labels                    = Screen1_Labels;
  Home.ImagesCount               = 12;
  Home.Images                    = Screen1_Images;
  Home.CirclesCount              = 0;
  Home.BoxesCount                = 0;
  Home.Boxes_RoundCount          = 0;
  Home.CheckBoxesCount           = 0;
  Home.RadioButtonsCount         = 0;
  Home.ObjectsCount              = 24;

  Accelerometer.Color                     = 0x4229;
  Accelerometer.Width                     = 800;
  Accelerometer.Height                    = 480;
  Accelerometer.ButtonsCount              = 0;
  Accelerometer.Buttons_RoundCount        = 0;
  Accelerometer.CButtons_RoundCount       = 0;
  Accelerometer.LabelsCount               = 4;
  Accelerometer.Labels                    = Screen2_Labels;
  Accelerometer.ImagesCount               = 1;
  Accelerometer.Images                    = Screen2_Images;
  Accelerometer.CirclesCount              = 0;
  Accelerometer.BoxesCount                = 2;
  Accelerometer.Boxes                     = Screen2_Boxes;
  Accelerometer.Boxes_RoundCount          = 0;
  Accelerometer.CheckBoxesCount           = 0;
  Accelerometer.RadioButtonsCount         = 0;
  Accelerometer.ObjectsCount              = 7;

  RGBLight.Color                     = 0x4229;
  RGBLight.Width                     = 800;
  RGBLight.Height                    = 480;
  RGBLight.ButtonsCount              = 0;
  RGBLight.Buttons_RoundCount        = 0;
  RGBLight.CButtons_RoundCount       = 0;
  RGBLight.LabelsCount               = 5;
  RGBLight.Labels                    = Screen3_Labels;
  RGBLight.ImagesCount               = 1;
  RGBLight.Images                    = Screen3_Images;
  RGBLight.CirclesCount              = 1;
  RGBLight.Circles                   = Screen3_Circles;
  RGBLight.BoxesCount                = 2;
  RGBLight.Boxes                     = Screen3_Boxes;
  RGBLight.Boxes_RoundCount          = 0;
  RGBLight.CheckBoxesCount           = 0;
  RGBLight.RadioButtonsCount         = 0;
  RGBLight.ObjectsCount              = 9;

  Clock.Color                     = 0x54C3;
  Clock.Width                     = 800;
  Clock.Height                    = 480;
  Clock.ButtonsCount              = 0;
  Clock.Buttons_RoundCount        = 0;
  Clock.CButtons_RoundCount       = 0;
  Clock.LabelsCount               = 5;
  Clock.Labels                    = Screen4_Labels;
  Clock.ImagesCount               = 5;
  Clock.Images                    = Screen4_Images;
  Clock.CirclesCount              = 0;
  Clock.BoxesCount                = 9;
  Clock.Boxes                     = Screen4_Boxes;
  Clock.Boxes_RoundCount          = 0;
  Clock.CheckBoxesCount           = 0;
  Clock.RadioButtonsCount         = 0;
  Clock.ObjectsCount              = 19;

  Sensors.Color                     = 0xA948;
  Sensors.Width                     = 800;
  Sensors.Height                    = 480;
  Sensors.ButtonsCount              = 0;
  Sensors.Buttons_RoundCount        = 0;
  Sensors.CButtons_RoundCount       = 0;
  Sensors.LabelsCount               = 7;
  Sensors.Labels                    = Screen5_Labels;
  Sensors.ImagesCount               = 3;
  Sensors.Images                    = Screen5_Images;
  Sensors.CirclesCount              = 0;
  Sensors.BoxesCount                = 2;
  Sensors.Boxes                     = Screen5_Boxes;
  Sensors.Boxes_RoundCount          = 0;
  Sensors.CheckBoxesCount           = 0;
  Sensors.RadioButtonsCount         = 0;
  Sensors.ObjectsCount              = 12;

  MP3_SD.Color                     = 0x4457;
  MP3_SD.Width                     = 800;
  MP3_SD.Height                    = 480;
  MP3_SD.ButtonsCount              = 0;
  MP3_SD.Buttons_RoundCount        = 0;
  MP3_SD.CButtons_RoundCount       = 0;
  MP3_SD.LabelsCount               = 2;
  MP3_SD.Labels                    = Screen6_Labels;
  MP3_SD.ImagesCount               = 5;
  MP3_SD.Images                    = Screen6_Images;
  MP3_SD.CirclesCount              = 0;
  MP3_SD.BoxesCount                = 1;
  MP3_SD.Boxes                     = Screen6_Boxes;
  MP3_SD.Boxes_RoundCount          = 0;
  MP3_SD.CheckBoxesCount           = 0;
  MP3_SD.RadioButtonsCount         = 0;
  MP3_SD.ObjectsCount              = 8;

  MP3_SongList.Color                     = 0x4457;
  MP3_SongList.Width                     = 800;
  MP3_SongList.Height                    = 480;
  MP3_SongList.ButtonsCount              = 0;
  MP3_SongList.Buttons_RoundCount        = 0;
  MP3_SongList.CButtons_RoundCount       = 0;
  MP3_SongList.LabelsCount               = 2;
  MP3_SongList.Labels                    = Screen7_Labels;
  MP3_SongList.ImagesCount               = 4;
  MP3_SongList.Images                    = Screen7_Images;
  MP3_SongList.CirclesCount              = 0;
  MP3_SongList.BoxesCount                = 2;
  MP3_SongList.Boxes                     = Screen7_Boxes;
  MP3_SongList.Boxes_RoundCount          = 0;
  MP3_SongList.CheckBoxesCount           = 0;
  MP3_SongList.RadioButtonsCount         = 0;
  MP3_SongList.ObjectsCount              = 8;

  MP3_Player.Color                     = 0x4457;
  MP3_Player.Width                     = 800;
  MP3_Player.Height                    = 480;
  MP3_Player.ButtonsCount              = 0;
  MP3_Player.Buttons_RoundCount        = 0;
  MP3_Player.CButtons_RoundCount       = 0;
  MP3_Player.LabelsCount               = 3;
  MP3_Player.Labels                    = Screen8_Labels;
  MP3_Player.ImagesCount               = 9;
  MP3_Player.Images                    = Screen8_Images;
  MP3_Player.CirclesCount              = 0;
  MP3_Player.BoxesCount                = 3;
  MP3_Player.Boxes                     = Screen8_Boxes;
  MP3_Player.Boxes_RoundCount          = 0;
  MP3_Player.CheckBoxesCount           = 0;
  MP3_Player.RadioButtonsCount         = 0;
  MP3_Player.ObjectsCount              = 15;

  Paint.Color                     = 0x4229;
  Paint.Width                     = 800;
  Paint.Height                    = 480;
  Paint.ButtonsCount              = 0;
  Paint.Buttons_RoundCount        = 0;
  Paint.CButtons_RoundCount       = 0;
  Paint.LabelsCount               = 1;
  Paint.Labels                    = Screen9_Labels;
  Paint.ImagesCount               = 9;
  Paint.Images                    = Screen9_Images;
  Paint.CirclesCount              = 0;
  Paint.BoxesCount                = 35;
  Paint.Boxes                     = Screen9_Boxes;
  Paint.Boxes_RoundCount          = 0;
  Paint.CheckBoxesCount           = 0;
  Paint.RadioButtonsCount         = 0;
  Paint.ObjectsCount              = 45;

  SlideShow.Color                     = 0x4229;
  SlideShow.Width                     = 800;
  SlideShow.Height                    = 480;
  SlideShow.ButtonsCount              = 0;
  SlideShow.Buttons_RoundCount        = 0;
  SlideShow.CButtons_RoundCount       = 0;
  SlideShow.LabelsCount               = 4;
  SlideShow.Labels                    = Screen10_Labels;
  SlideShow.ImagesCount               = 3;
  SlideShow.Images                    = Screen10_Images;
  SlideShow.CirclesCount              = 0;
  SlideShow.BoxesCount                = 4;
  SlideShow.Boxes                     = Screen10_Boxes;
  SlideShow.Boxes_RoundCount          = 0;
  SlideShow.CheckBoxesCount           = 0;
  SlideShow.RadioButtonsCount         = 0;
  SlideShow.ObjectsCount              = 11;

  Tic_Tac_Toe.Color                     = 0xA1AE;
  Tic_Tac_Toe.Width                     = 800;
  Tic_Tac_Toe.Height                    = 480;
  Tic_Tac_Toe.ButtonsCount              = 9;
  Tic_Tac_Toe.Buttons                   = Screen11_Buttons;
  Tic_Tac_Toe.Buttons_RoundCount        = 0;
  Tic_Tac_Toe.CButtons_RoundCount       = 0;
  Tic_Tac_Toe.LabelsCount               = 14;
  Tic_Tac_Toe.Labels                    = Screen11_Labels;
  Tic_Tac_Toe.ImagesCount               = 2;
  Tic_Tac_Toe.Images                    = Screen11_Images;
  Tic_Tac_Toe.CirclesCount              = 0;
  Tic_Tac_Toe.BoxesCount                = 4;
  Tic_Tac_Toe.Boxes                     = Screen11_Boxes;
  Tic_Tac_Toe.Boxes_RoundCount          = 0;
  Tic_Tac_Toe.CheckBoxesCount           = 1;
  Tic_Tac_Toe.CheckBoxes                = Screen11_CheckBoxes;
  Tic_Tac_Toe.RadioButtonsCount         = 0;
  Tic_Tac_Toe.ObjectsCount              = 30;

  WiFi.Color                     = 0x4229;
  WiFi.Width                     = 800;
  WiFi.Height                    = 480;
  WiFi.ButtonsCount              = 0;
  WiFi.Buttons_RoundCount        = 0;
  WiFi.CButtons_RoundCount       = 0;
  WiFi.LabelsCount               = 1;
  WiFi.Labels                    = Screen12_Labels;
  WiFi.ImagesCount               = 1;
  WiFi.Images                    = Screen12_Images;
  WiFi.CirclesCount              = 0;
  WiFi.BoxesCount                = 1;
  WiFi.Boxes                     = Screen12_Boxes;
  WiFi.Boxes_RoundCount          = 0;
  WiFi.CheckBoxesCount           = 0;
  WiFi.RadioButtonsCount         = 0;
  WiFi.ObjectsCount              = 3;

  CAN.Color                     = 0x4229;
  CAN.Width                     = 800;
  CAN.Height                    = 480;
  CAN.ButtonsCount              = 0;
  CAN.Buttons_RoundCount        = 0;
  CAN.CButtons_RoundCount       = 0;
  CAN.LabelsCount               = 3;
  CAN.Labels                    = Screen13_Labels;
  CAN.ImagesCount               = 1;
  CAN.Images                    = Screen13_Images;
  CAN.CirclesCount              = 8;
  CAN.Circles                   = Screen13_Circles;
  CAN.BoxesCount                = 1;
  CAN.Boxes                     = Screen13_Boxes;
  CAN.Boxes_RoundCount          = 0;
  CAN.CheckBoxesCount           = 0;
  CAN.RadioButtonsCount         = 8;
  CAN.RadioButtons              = Screen13_RadioButtons;
  CAN.ObjectsCount              = 21;

  Screen0.Color                     = 0xFFFF;
  Screen0.Width                     = 800;
  Screen0.Height                    = 480;
  Screen0.ButtonsCount              = 0;
  Screen0.Buttons_RoundCount        = 0;
  Screen0.CButtons_RoundCount       = 29;
  Screen0.CButtons_Round            = Screen14_CButtons_Round;
  Screen0.LabelsCount               = 3;
  Screen0.Labels                    = Screen14_Labels;
  Screen0.ImagesCount               = 0;
  Screen0.CirclesCount              = 0;
  Screen0.BoxesCount                = 0;
  Screen0.Boxes_RoundCount          = 1;
  Screen0.Boxes_Round               = Screen14_Boxes_Round;
  Screen0.CheckBoxesCount           = 0;
  Screen0.RadioButtonsCount         = 0;
  Screen0.ObjectsCount              = 33;

  Screen1.Color                     = 0xFFFF;
  Screen1.Width                     = 800;
  Screen1.Height                    = 480;
  Screen1.ButtonsCount              = 0;
  Screen1.Buttons_RoundCount        = 30;
  Screen1.Buttons_Round             = Screen15_Buttons_Round;
  Screen1.CButtons_RoundCount       = 0;
  Screen1.LabelsCount               = 5;
  Screen1.Labels                    = Screen15_Labels;
  Screen1.ImagesCount               = 1;
  Screen1.Images                    = Screen15_Images;
  Screen1.CirclesCount              = 0;
  Screen1.BoxesCount                = 2;
  Screen1.Boxes                     = Screen15_Boxes;
  Screen1.Boxes_RoundCount          = 0;
  Screen1.CheckBoxesCount           = 0;
  Screen1.RadioButtonsCount         = 0;
  Screen1.ObjectsCount              = 38;


  Image1.OwnerScreen     = &Home;
  Image1.Order           = 0;
  Image1.Left            = 62;
  Image1.Top             = 100;
  Image1.Width           = 85;
  Image1.Height          = 90;
  Image1.Picture_Type    = 0;
  Image1.Picture_Ratio   = 1;
  Image1.Picture_Name    = accel_icon_7_bmp;
  Image1.Visible         = 1;
  Image1.Active          = 1;
  Image1.OnUpPtr         = 0;
  Image1.OnDownPtr       = 0;
  Image1.OnClickPtr      = 0;
  Image1.OnPressPtr      = Image1OnPress;

  Image3.OwnerScreen     = &Home;
  Image3.Order           = 1;
  Image3.Left            = 506;
  Image3.Top             = 280;
  Image3.Width           = 85;
  Image3.Height          = 90;
  Image3.Picture_Type    = 0;
  Image3.Picture_Ratio   = 1;
  Image3.Picture_Name    = rgb_icon_7_bmp;
  Image3.Visible         = 1;
  Image3.Active          = 1;
  Image3.OnUpPtr         = 0;
  Image3.OnDownPtr       = 0;
  Image3.OnClickPtr      = 0;
  Image3.OnPressPtr      = Image3OnPress;

  Label5.OwnerScreen     = &Home;
  Label5.Order           = 2;
  Label5.Left            = 300;
  Label5.Top             = 22;
  Label5.Width           = 195;
  Label5.Height          = 48;
  Label5.Visible         = 1;
  Label5.Active          = 1;
  Label5.Caption         = Label5_Caption;
  Label5.FontName        = Open_Sans_Light29x43_Regular;
  Label5.Font_Color      = 0xFFFF;
  Label5.OnUpPtr         = 0;
  Label5.OnDownPtr       = 0;
  Label5.OnClickPtr      = 0;
  Label5.OnPressPtr      = 0;

  Label7.OwnerScreen     = &Home;
  Label7.Order           = 3;
  Label7.Left            = 30;
  Label7.Top             = 200;
  Label7.Width           = 142;
  Label7.Height          = 31;
  Label7.Visible         = 1;
  Label7.Active          = 1;
  Label7.Caption         = Label7_Caption;
  Label7.FontName        = Open_Sans_Light19x28_Regular;
  Label7.Font_Color      = 0xFFFF;
  Label7.OnUpPtr         = 0;
  Label7.OnDownPtr       = 0;
  Label7.OnClickPtr      = 0;
  Label7.OnPressPtr      = 0;

  Label8.OwnerScreen     = &Home;
  Label8.Order           = 4;
  Label8.Left            = 500;
  Label8.Top             = 380;
  Label8.Width           = 95;
  Label8.Height          = 31;
  Label8.Visible         = 1;
  Label8.Active          = 1;
  Label8.Caption         = Label8_Caption;
  Label8.FontName        = Open_Sans_Light19x28_Regular;
  Label8.Font_Color      = 0xFFFF;
  Label8.OnUpPtr         = 0;
  Label8.OnDownPtr       = 0;
  Label8.OnClickPtr      = 0;
  Label8.OnPressPtr      = 0;

  Image6.OwnerScreen     = &Home;
  Image6.Order           = 5;
  Image6.Left            = 210;
  Image6.Top             = 280;
  Image6.Width           = 85;
  Image6.Height          = 90;
  Image6.Picture_Type    = 0;
  Image6.Picture_Ratio   = 1;
  Image6.Picture_Name    = clock_icon_7_bmp;
  Image6.Visible         = 1;
  Image6.Active          = 1;
  Image6.OnUpPtr         = 0;
  Image6.OnDownPtr       = 0;
  Image6.OnClickPtr      = Image6OnClick;
  Image6.OnPressPtr      = 0;

  Label14.OwnerScreen     = &Home;
  Label14.Order           = 6;
  Label14.Left            = 225;
  Label14.Top             = 380;
  Label14.Width           = 52;
  Label14.Height          = 31;
  Label14.Visible         = 1;
  Label14.Active          = 1;
  Label14.Caption         = Label14_Caption;
  Label14.FontName        = Open_Sans_Light19x28_Regular;
  Label14.Font_Color      = 0xFFFF;
  Label14.OnUpPtr         = 0;
  Label14.OnDownPtr       = 0;
  Label14.OnClickPtr      = 0;
  Label14.OnPressPtr      = 0;

  Image10.OwnerScreen     = &Home;
  Image10.Order           = 7;
  Image10.Left            = 657;
  Image10.Top             = 30;
  Image10.Width           = 28;
  Image10.Height          = 27;
  Image10.Picture_Type    = 0;
  Image10.Picture_Ratio   = 1;
  Image10.Picture_Name    = icon_time_bmp;
  Image10.Visible         = 1;
  Image10.Active          = 1;
  Image10.OnUpPtr         = 0;
  Image10.OnDownPtr       = 0;
  Image10.OnClickPtr      = 0;
  Image10.OnPressPtr      = 0;

  Label19.OwnerScreen     = &Home;
  Label19.Order           = 8;
  Label19.Left            = 696;
  Label19.Top             = 33;
  Label19.Width           = 74;
  Label19.Height          = 25;
  Label19.Visible         = 1;
  Label19.Active          = 1;
  Label19.Caption         = Label19_Caption;
  Label19.FontName        = Open_Sans_Light15x23_Regular;
  Label19.Font_Color      = 0xFFFF;
  Label19.OnUpPtr         = 0;
  Label19.OnDownPtr       = 0;
  Label19.OnClickPtr      = 0;
  Label19.OnPressPtr      = 0;

  Image9.OwnerScreen     = &Home;
  Image9.Order           = 9;
  Image9.Left            = 62;
  Image9.Top             = 280;
  Image9.Width           = 85;
  Image9.Height          = 90;
  Image9.Picture_Type    = 0;
  Image9.Picture_Ratio   = 1;
  Image9.Picture_Name    = temp_icon_7_bmp;
  Image9.Visible         = 1;
  Image9.Active          = 1;
  Image9.OnUpPtr         = 0;
  Image9.OnDownPtr       = 0;
  Image9.OnClickPtr      = 0;
  Image9.OnPressPtr      = Image9OnPress;

  Label20.OwnerScreen     = &Home;
  Label20.Order           = 10;
  Label20.Left            = 60;
  Label20.Top             = 380;
  Label20.Width           = 78;
  Label20.Height          = 31;
  Label20.Visible         = 1;
  Label20.Active          = 1;
  Label20.Caption         = Label20_Caption;
  Label20.FontName        = Open_Sans_Light19x28_Regular;
  Label20.Font_Color      = 0xFFFF;
  Label20.OnUpPtr         = 0;
  Label20.OnDownPtr       = 0;
  Label20.OnClickPtr      = 0;
  Label20.OnPressPtr      = 0;

  Image16.OwnerScreen     = &Home;
  Image16.Order           = 11;
  Image16.Left            = 506;
  Image16.Top             = 100;
  Image16.Width           = 85;
  Image16.Height          = 90;
  Image16.Picture_Type    = 0;
  Image16.Picture_Ratio   = 1;
  Image16.Picture_Name    = mp3_icon_7_bmp;
  Image16.Visible         = 1;
  Image16.Active          = 1;
  Image16.OnUpPtr         = 0;
  Image16.OnDownPtr       = 0;
  Image16.OnClickPtr      = Image16OnClick;
  Image16.OnPressPtr      = 0;

  Label25.OwnerScreen     = &Home;
  Label25.Order           = 12;
  Label25.Left            = 500;
  Label25.Top             = 200;
  Label25.Width           = 109;
  Label25.Height          = 31;
  Label25.Visible         = 1;
  Label25.Active          = 1;
  Label25.Caption         = Label25_Caption;
  Label25.FontName        = Open_Sans_Light19x28_Regular;
  Label25.Font_Color      = 0xFFFF;
  Label25.OnUpPtr         = 0;
  Label25.OnDownPtr       = 0;
  Label25.OnClickPtr      = 0;
  Label25.OnPressPtr      = 0;

  Image24.OwnerScreen     = &Home;
  Image24.Order           = 13;
  Image24.Left            = 210;
  Image24.Top             = 100;
  Image24.Width           = 85;
  Image24.Height          = 90;
  Image24.Picture_Type    = 0;
  Image24.Picture_Ratio   = 1;
  Image24.Picture_Name    = paint_icon_7_bmp;
  Image24.Visible         = 1;
  Image24.Active          = 1;
  Image24.OnUpPtr         = 0;
  Image24.OnDownPtr       = 0;
  Image24.OnClickPtr      = Image24OnPress;
  Image24.OnPressPtr      = Image24OnPress;

  Label30.OwnerScreen     = &Home;
  Label30.Order           = 14;
  Label30.Left            = 230;
  Label30.Top             = 200;
  Label30.Width           = 49;
  Label30.Height          = 31;
  Label30.Visible         = 1;
  Label30.Active          = 1;
  Label30.Caption         = Label30_Caption;
  Label30.FontName        = Open_Sans_Light19x28_Regular;
  Label30.Font_Color      = 0xFFFF;
  Label30.OnUpPtr         = 0;
  Label30.OnDownPtr       = 0;
  Label30.OnClickPtr      = 0;
  Label30.OnPressPtr      = 0;

  Image18.OwnerScreen     = &Home;
  Image18.Order           = 15;
  Image18.Left            = 358;
  Image18.Top             = 280;
  Image18.Width           = 85;
  Image18.Height          = 90;
  Image18.Picture_Type    = 0;
  Image18.Picture_Ratio   = 1;
  Image18.Picture_Name    = slide_icon_7_bmp;
  Image18.Visible         = 1;
  Image18.Active          = 1;
  Image18.OnUpPtr         = 0;
  Image18.OnDownPtr       = 0;
  Image18.OnClickPtr      = Image18OnClick;
  Image18.OnPressPtr      = 0;

  Label34.OwnerScreen     = &Home;
  Label34.Order           = 16;
  Label34.Left            = 350;
  Label34.Top             = 380;
  Label34.Width           = 105;
  Label34.Height          = 31;
  Label34.Visible         = 1;
  Label34.Active          = 1;
  Label34.Caption         = Label34_Caption;
  Label34.FontName        = Open_Sans_Light19x28_Regular;
  Label34.Font_Color      = 0xFFFF;
  Label34.OnUpPtr         = 0;
  Label34.OnDownPtr       = 0;
  Label34.OnClickPtr      = 0;
  Label34.OnPressPtr      = 0;

  TicTacToe.OwnerScreen     = &Home;
  TicTacToe.Order           = 17;
  TicTacToe.Left            = 358;
  TicTacToe.Top             = 100;
  TicTacToe.Width           = 85;
  TicTacToe.Height          = 90;
  TicTacToe.Picture_Type    = 0;
  TicTacToe.Picture_Ratio   = 1;
  TicTacToe.Picture_Name    = tic_tac_icon_7_bmp;
  TicTacToe.Visible         = 1;
  TicTacToe.Active          = 1;
  TicTacToe.OnUpPtr         = 0;
  TicTacToe.OnDownPtr       = 0;
  TicTacToe.OnClickPtr      = Image22OnClick;
  TicTacToe.OnPressPtr      = 0;

  Label40.OwnerScreen     = &Home;
  Label40.Order           = 18;
  Label40.Left            = 350;
  Label40.Top             = 200;
  Label40.Width           = 107;
  Label40.Height          = 31;
  Label40.Visible         = 1;
  Label40.Active          = 1;
  Label40.Caption         = Label40_Caption;
  Label40.FontName        = Open_Sans_Light19x28_Regular;
  Label40.Font_Color      = 0xFFFF;
  Label40.OnUpPtr         = 0;
  Label40.OnDownPtr       = 0;
  Label40.OnClickPtr      = 0;
  Label40.OnPressPtr      = 0;

  BatteryStatus.OwnerScreen     = &Home;
  BatteryStatus.Order           = 19;
  BatteryStatus.Left            = 27;
  BatteryStatus.Top             = 34;
  BatteryStatus.Width           = 55;
  BatteryStatus.Height          = 24;
  BatteryStatus.Picture_Type    = 0;
  BatteryStatus.Picture_Ratio   = 1;
  BatteryStatus.Picture_Name    = icon_battery_bmp;
  BatteryStatus.Visible         = 1;
  BatteryStatus.Active          = 0;
  BatteryStatus.OnUpPtr         = 0;
  BatteryStatus.OnDownPtr       = 0;
  BatteryStatus.OnClickPtr      = 0;
  BatteryStatus.OnPressPtr      = 0;

  Image19.OwnerScreen     = &Home;
  Image19.Order           = 20;
  Image19.Left            = 654;
  Image19.Top             = 100;
  Image19.Width           = 85;
  Image19.Height          = 90;
  Image19.Picture_Type    = 0;
  Image19.Picture_Ratio   = 1;
  Image19.Picture_Name    = wifi_icon_7_bmp;
  Image19.Visible         = 1;
  Image19.Active          = 1;
  Image19.OnUpPtr         = 0;
  Image19.OnDownPtr       = 0;
  Image19.OnClickPtr      = ImageWiFiOnClick;
  Image19.OnPressPtr      = 0;

  Image22.OwnerScreen     = &Home;
  Image22.Order           = 21;
  Image22.Left            = 654;
  Image22.Top             = 279;
  Image22.Width           = 85;
  Image22.Height          = 90;
  Image22.Picture_Type    = 0;
  Image22.Picture_Ratio   = 1;
  Image22.Picture_Name    = can_icon_7_bmp;
  Image22.Visible         = 1;
  Image22.Active          = 1;
  Image22.OnUpPtr         = 0;
  Image22.OnDownPtr       = 0;
  Image22.OnClickPtr      = ImageCanOnClick;
  Image22.OnPressPtr      = 0;

  Label43.OwnerScreen     = &Home;
  Label43.Order           = 22;
  Label43.Left            = 675;
  Label43.Top             = 200;
  Label43.Width           = 40;
  Label43.Height          = 31;
  Label43.Visible         = 1;
  Label43.Active          = 1;
  Label43.Caption         = Label43_Caption;
  Label43.FontName        = Open_Sans_Light19x28_Regular;
  Label43.Font_Color      = 0xFFFF;
  Label43.OnUpPtr         = 0;
  Label43.OnDownPtr       = 0;
  Label43.OnClickPtr      = 0;
  Label43.OnPressPtr      = 0;

  Label45.OwnerScreen     = &Home;
  Label45.Order           = 23;
  Label45.Left            = 675;
  Label45.Top             = 380;
  Label45.Width           = 42;
  Label45.Height          = 31;
  Label45.Visible         = 1;
  Label45.Active          = 1;
  Label45.Caption         = Label45_Caption;
  Label45.FontName        = Open_Sans_Light19x28_Regular;
  Label45.Font_Color      = 0xFFFF;
  Label45.OnUpPtr         = 0;
  Label45.OnDownPtr       = 0;
  Label45.OnClickPtr      = 0;
  Label45.OnPressPtr      = 0;

  Box23.OwnerScreen     = &Accelerometer;
  Box23.Order           = 0;
  Box23.Left            = 6;
  Box23.Top             = 7;
  Box23.Width           = 392;
  Box23.Height          = 44;
  Box23.Pen_Width       = 1;
  Box23.Pen_Color       = 0x0000;
  Box23.Visible         = 0;
  Box23.Active          = 1;
  Box23.Transparent     = 1;
  Box23.Gradient        = 0;
  Box23.Gradient_Orientation = 0;
  Box23.Gradient_Start_Color = 0xFFFF;
  Box23.Gradient_End_Color = 0xC618;
  Box23.Color           = 0xC618;
  Box23.PressColEnabled = 0;
  Box23.Press_Color     = 0xE71C;
  Box23.OnUpPtr         = 0;
  Box23.OnDownPtr       = 0;
  Box23.OnClickPtr      = Image2OnPress;
  Box23.OnPressPtr      = 0;

  Box1.OwnerScreen     = &Accelerometer;
  Box1.Order           = 1;
  Box1.Left            = 0;
  Box1.Top             = 70;
  Box1.Width           = 800;
  Box1.Height          = 364;
  Box1.Pen_Width       = 1;
  Box1.Pen_Color       = 0xFFFF;
  Box1.Visible         = 1;
  Box1.Active          = 1;
  Box1.Transparent     = 1;
  Box1.Gradient        = 0;
  Box1.Gradient_Orientation = 0;
  Box1.Gradient_Start_Color = 0xFFFF;
  Box1.Gradient_End_Color = 0xFFFF;
  Box1.Color           = 0xFFFF;
  Box1.PressColEnabled = 0;
  Box1.Press_Color     = 0xFFFF;
  Box1.OnUpPtr         = 0;
  Box1.OnDownPtr       = 0;
  Box1.OnClickPtr      = 0;
  Box1.OnPressPtr      = 0;

  Image2.OwnerScreen     = &Accelerometer;
  Image2.Order           = 2;
  Image2.Left            = 10;
  Image2.Top             = 11;
  Image2.Width           = 33;
  Image2.Height          = 33;
  Image2.Picture_Type    = 0;
  Image2.Picture_Ratio   = 1;
  Image2.Picture_Name    = icon_back_accel_bmp;
  Image2.Visible         = 1;
  Image2.Active          = 0;
  Image2.OnUpPtr         = 0;
  Image2.OnDownPtr       = 0;
  Image2.OnClickPtr      = 0;
  Image2.OnPressPtr      = Image2OnPress;

  Label1.OwnerScreen     = &Accelerometer;
  Label1.Order           = 3;
  Label1.Left            = 53;
  Label1.Top             = 4;
  Label1.Width           = 318;
  Label1.Height          = 48;
  Label1.Visible         = 1;
  Label1.Active          = 0;
  Label1.Caption         = Label1_Caption;
  Label1.FontName        = Open_Sans_Light29x43_Regular;
  Label1.Font_Color      = 0xFFFF;
  Label1.OnUpPtr         = 0;
  Label1.OnDownPtr       = 0;
  Label1.OnClickPtr      = 0;
  Label1.OnPressPtr      = 0;

  Label2.OwnerScreen     = &Accelerometer;
  Label2.Order           = 4;
  Label2.Left            = 170;
  Label2.Top             = 440;
  Label2.Width           = 22;
  Label2.Height          = 40;
  Label2.Visible         = 1;
  Label2.Active          = 1;
  Label2.Caption         = Label2_Caption;
  Label2.FontName        = Open_Sans_Light24x37_Regular;
  Label2.Font_Color      = 0xF800;
  Label2.OnUpPtr         = 0;
  Label2.OnDownPtr       = 0;
  Label2.OnClickPtr      = 0;
  Label2.OnPressPtr      = 0;

  Label3.OwnerScreen     = &Accelerometer;
  Label3.Order           = 5;
  Label3.Left            = 373;
  Label3.Top             = 440;
  Label3.Width           = 21;
  Label3.Height          = 40;
  Label3.Visible         = 1;
  Label3.Active          = 1;
  Label3.Caption         = Label3_Caption;
  Label3.FontName        = Open_Sans_Light24x37_Regular;
  Label3.Font_Color      = 0x001F;
  Label3.OnUpPtr         = 0;
  Label3.OnDownPtr       = 0;
  Label3.OnClickPtr      = 0;
  Label3.OnPressPtr      = 0;

  Label4.OwnerScreen     = &Accelerometer;
  Label4.Order           = 6;
  Label4.Left            = 575;
  Label4.Top             = 440;
  Label4.Width           = 23;
  Label4.Height          = 40;
  Label4.Visible         = 1;
  Label4.Active          = 1;
  Label4.Caption         = Label4_Caption;
  Label4.FontName        = Open_Sans_Light24x37_Regular;
  Label4.Font_Color      = 0x0400;
  Label4.OnUpPtr         = 0;
  Label4.OnDownPtr       = 0;
  Label4.OnClickPtr      = 0;
  Label4.OnPressPtr      = 0;

  Box22.OwnerScreen     = &RGBLight;
  Box22.Order           = 0;
  Box22.Left            = 5;
  Box22.Top             = 5;
  Box22.Width           = 209;
  Box22.Height          = 53;
  Box22.Pen_Width       = 1;
  Box22.Pen_Color       = 0x0000;
  Box22.Visible         = 0;
  Box22.Active          = 1;
  Box22.Transparent     = 1;
  Box22.Gradient        = 0;
  Box22.Gradient_Orientation = 0;
  Box22.Gradient_Start_Color = 0xFFFF;
  Box22.Gradient_End_Color = 0xC618;
  Box22.Color           = 0xC618;
  Box22.PressColEnabled = 0;
  Box22.Press_Color     = 0xE71C;
  Box22.OnUpPtr         = 0;
  Box22.OnDownPtr       = 0;
  Box22.OnClickPtr      = Image5OnPress;
  Box22.OnPressPtr      = 0;

  Label9.OwnerScreen     = &RGBLight;
  Label9.Order           = 1;
  Label9.Left            = 47;
  Label9.Top             = 14;
  Label9.Width           = 122;
  Label9.Height          = 40;
  Label9.Visible         = 1;
  Label9.Active          = 0;
  Label9.Caption         = Label9_Caption;
  Label9.FontName        = Open_Sans_Light24x37_Regular;
  Label9.Font_Color      = 0xFFFF;
  Label9.OnUpPtr         = 0;
  Label9.OnDownPtr       = 0;
  Label9.OnClickPtr      = 0;
  Label9.OnPressPtr      = 0;

  Image5.OwnerScreen     = &RGBLight;
  Image5.Order           = 2;
  Image5.Left            = 9;
  Image5.Top             = 17;
  Image5.Width           = 33;
  Image5.Height          = 33;
  Image5.Picture_Type    = 0;
  Image5.Picture_Ratio   = 1;
  Image5.Picture_Name    = icon_back_accel_bmp_1;
  Image5.Visible         = 1;
  Image5.Active          = 0;
  Image5.OnUpPtr         = 0;
  Image5.OnDownPtr       = 0;
  Image5.OnClickPtr      = 0;
  Image5.OnPressPtr      = Image5OnPress;

  Label10.OwnerScreen     = &RGBLight;
  Label10.Order           = 3;
  Label10.Left            = 17;
  Label10.Top             = 444;
  Label10.Width           = 129;
  Label10.Height          = 36;
  Label10.Visible         = 1;
  Label10.Active          = 1;
  Label10.Caption         = Label10_Caption;
  Label10.FontName        = Open_Sans_Light21x33_Regular;
  Label10.Font_Color      = 0xFFFF;
  Label10.OnUpPtr         = 0;
  Label10.OnDownPtr       = 0;
  Label10.OnClickPtr      = 0;
  Label10.OnPressPtr      = 0;

  Circle1.OwnerScreen     = &RGBLight;
  Circle1.Order           = 4;
  Circle1.Left            = 540;
  Circle1.Top             = 448;
  Circle1.Radius          = 11;
  Circle1.Pen_Width       = 0;
  Circle1.Pen_Color       = 0x0000;
  Circle1.Visible         = 1;
  Circle1.Active          = 1;
  Circle1.Transparent     = 1;
  Circle1.Gradient        = 0;
  Circle1.Gradient_Orientation = 0;
  Circle1.Gradient_Start_Color = 0xFFFF;
  Circle1.Gradient_End_Color = 0xC618;
  Circle1.Color           = 0x0023;
  Circle1.PressColEnabled = 1;
  Circle1.Press_Color     = 0x19E0;
  Circle1.OnUpPtr         = 0;
  Circle1.OnDownPtr       = 0;
  Circle1.OnClickPtr      = 0;
  Circle1.OnPressPtr      = 0;

  Label11.OwnerScreen     = &RGBLight;
  Label11.Order           = 5;
  Label11.Left            = 571;
  Label11.Top             = 444;
  Label11.Width           = 21;
  Label11.Height          = 36;
  Label11.Visible         = 1;
  Label11.Active          = 1;
  Label11.Caption         = Label11_Caption;
  Label11.FontName        = Open_Sans_Light21x33_Regular;
  Label11.Font_Color      = 0xFFFF;
  Label11.OnUpPtr         = 0;
  Label11.OnDownPtr       = 0;
  Label11.OnClickPtr      = 0;
  Label11.OnPressPtr      = 0;

  Label12.OwnerScreen     = &RGBLight;
  Label12.Order           = 6;
  Label12.Left            = 646;
  Label12.Top             = 445;
  Label12.Width           = 24;
  Label12.Height          = 36;
  Label12.Visible         = 1;
  Label12.Active          = 1;
  Label12.Caption         = Label12_Caption;
  Label12.FontName        = Open_Sans_Light21x33_Regular;
  Label12.Font_Color      = 0xFFFF;
  Label12.OnUpPtr         = 0;
  Label12.OnDownPtr       = 0;
  Label12.OnClickPtr      = 0;
  Label12.OnPressPtr      = 0;

  Label13.OwnerScreen     = &RGBLight;
  Label13.Order           = 7;
  Label13.Left            = 721;
  Label13.Top             = 444;
  Label13.Width           = 21;
  Label13.Height          = 36;
  Label13.Visible         = 1;
  Label13.Active          = 1;
  Label13.Caption         = Label13_Caption;
  Label13.FontName        = Open_Sans_Light21x33_Regular;
  Label13.Font_Color      = 0xFFFF;
  Label13.OnUpPtr         = 0;
  Label13.OnDownPtr       = 0;
  Label13.OnClickPtr      = 0;
  Label13.OnPressPtr      = 0;

  RGB_Active_area.OwnerScreen     = &RGBLight;
  RGB_Active_area.Order           = 8;
  RGB_Active_area.Left            = 0;
  RGB_Active_area.Top             = 65;
  RGB_Active_area.Width           = 800;
  RGB_Active_area.Height          = 375;
  RGB_Active_area.Pen_Width       = 1;
  RGB_Active_area.Pen_Color       = 0x0000;
  RGB_Active_area.Visible         = 0;
  RGB_Active_area.Active          = 1;
  RGB_Active_area.Transparent     = 1;
  RGB_Active_area.Gradient        = 0;
  RGB_Active_area.Gradient_Orientation = 0;
  RGB_Active_area.Gradient_Start_Color = 0xFFFF;
  RGB_Active_area.Gradient_End_Color = 0xC618;
  RGB_Active_area.Color           = 0xC618;
  RGB_Active_area.PressColEnabled = 0;
  RGB_Active_area.Press_Color     = 0xE71C;
  RGB_Active_area.OnUpPtr         = 0;
  RGB_Active_area.OnDownPtr       = 0;
  RGB_Active_area.OnClickPtr      = 0;
  RGB_Active_area.OnPressPtr      = RGB_Active_areaOnPress;

  Box16.OwnerScreen     = &Clock;
  Box16.Order           = 0;
  Box16.Left            = 2;
  Box16.Top             = 5;
  Box16.Width           = 125;
  Box16.Height          = 54;
  Box16.Pen_Width       = 1;
  Box16.Pen_Color       = 0x0000;
  Box16.Visible         = 0;
  Box16.Active          = 1;
  Box16.Transparent     = 1;
  Box16.Gradient        = 0;
  Box16.Gradient_Orientation = 0;
  Box16.Gradient_Start_Color = 0xFFFF;
  Box16.Gradient_End_Color = 0xC618;
  Box16.Color           = 0xC618;
  Box16.PressColEnabled = 0;
  Box16.Press_Color     = 0xE71C;
  Box16.OnUpPtr         = 0;
  Box16.OnDownPtr       = 0;
  Box16.OnClickPtr      = ClockBackOnPress;
  Box16.OnPressPtr      = 0;

  Box15.OwnerScreen     = &Clock;
  Box15.Order           = 1;
  Box15.Left            = 634;
  Box15.Top             = 397;
  Box15.Width           = 136;
  Box15.Height          = 54;
  Box15.Pen_Width       = 1;
  Box15.Pen_Color       = 0x0000;
  Box15.Visible         = 0;
  Box15.Active          = 1;
  Box15.Transparent     = 1;
  Box15.Gradient        = 0;
  Box15.Gradient_Orientation = 0;
  Box15.Gradient_Start_Color = 0xFFFF;
  Box15.Gradient_End_Color = 0xC618;
  Box15.Color           = 0xC618;
  Box15.PressColEnabled = 0;
  Box15.Press_Color     = 0xE71C;
  Box15.OnUpPtr         = 0;
  Box15.OnDownPtr       = 0;
  Box15.OnClickPtr      = Image8OnPress;
  Box15.OnPressPtr      = 0;

  Box13.OwnerScreen     = &Clock;
  Box13.Order           = 2;
  Box13.Left            = 1;
  Box13.Top             = 66;
  Box13.Width           = 800;
  Box13.Height          = 329;
  Box13.Pen_Width       = 0;
  Box13.Pen_Color       = 0x0000;
  Box13.Visible         = 0;
  Box13.Active          = 1;
  Box13.Transparent     = 1;
  Box13.Gradient        = 0;
  Box13.Gradient_Orientation = 0;
  Box13.Gradient_Start_Color = 0xFFFF;
  Box13.Gradient_End_Color = 0xC618;
  Box13.Color           = 0x54C3;
  Box13.PressColEnabled = 0;
  Box13.Press_Color     = 0xE71C;
  Box13.OnUpPtr         = 0;
  Box13.OnDownPtr       = 0;
  Box13.OnClickPtr      = Box13OnClick;
  Box13.OnPressPtr      = 0;

  Box12.OwnerScreen     = &Clock;
  Box12.Order           = 3;
  Box12.Left            = 459;
  Box12.Top             = 399;
  Box12.Width           = 130;
  Box12.Height          = 54;
  Box12.Pen_Width       = 1;
  Box12.Pen_Color       = 0x0000;
  Box12.Visible         = 0;
  Box12.Active          = 1;
  Box12.Transparent     = 1;
  Box12.Gradient        = 0;
  Box12.Gradient_Orientation = 0;
  Box12.Gradient_Start_Color = 0xFFFF;
  Box12.Gradient_End_Color = 0xC618;
  Box12.Color           = 0xC618;
  Box12.PressColEnabled = 0;
  Box12.Press_Color     = 0xE71C;
  Box12.OnUpPtr         = 0;
  Box12.OnDownPtr       = 0;
  Box12.OnClickPtr      = Box12OnClick;
  Box12.OnPressPtr      = 0;

  Label15.OwnerScreen     = &Clock;
  Label15.Order           = 4;
  Label15.Left            = 302;
  Label15.Top             = 180;
  Label15.Width           = 24;
  Label15.Height          = 143;
  Label15.Visible         = 1;
  Label15.Active          = 1;
  Label15.Caption         = Label15_Caption;
  Label15.FontName        = Open_Sans_Light85x131_Regular;
  Label15.Font_Color      = 0xFFFF;
  Label15.OnUpPtr         = 0;
  Label15.OnDownPtr       = 0;
  Label15.OnClickPtr      = 0;
  Label15.OnPressPtr      = 0;

  Box2.OwnerScreen     = &Clock;
  Box2.Order           = 5;
  Box2.Left            = 150;
  Box2.Top             = 80;
  Box2.Width           = 60;
  Box2.Height          = 345;
  Box2.Pen_Width       = 0;
  Box2.Pen_Color       = 0x0000;
  Box2.Visible         = 0;
  Box2.Active          = 1;
  Box2.Transparent     = 0;
  Box2.Gradient        = 0;
  Box2.Gradient_Orientation = 0;
  Box2.Gradient_Start_Color = 0xFFFF;
  Box2.Gradient_End_Color = 0xC618;
  Box2.Color           = 0xC618;
  Box2.PressColEnabled = 1;
  Box2.Press_Color     = 0xE71C;
  Box2.OnUpPtr         = 0;
  Box2.OnDownPtr       = 0;
  Box2.OnClickPtr      = 0;
  Box2.OnPressPtr      = Box2OnPress;

  Box3.OwnerScreen     = &Clock;
  Box3.Order           = 6;
  Box3.Left            = 233;
  Box3.Top             = 80;
  Box3.Width           = 60;
  Box3.Height          = 345;
  Box3.Pen_Width       = 0;
  Box3.Pen_Color       = 0x0000;
  Box3.Visible         = 0;
  Box3.Active          = 1;
  Box3.Transparent     = 0;
  Box3.Gradient        = 0;
  Box3.Gradient_Orientation = 0;
  Box3.Gradient_Start_Color = 0xFFFF;
  Box3.Gradient_End_Color = 0xC618;
  Box3.Color           = 0xC618;
  Box3.PressColEnabled = 1;
  Box3.Press_Color     = 0xE71C;
  Box3.OnUpPtr         = 0;
  Box3.OnDownPtr       = 0;
  Box3.OnClickPtr      = 0;
  Box3.OnPressPtr      = Box3OnPress;

  Label16.OwnerScreen     = &Clock;
  Label16.Order           = 7;
  Label16.Left            = 54;
  Label16.Top             = 24;
  Label16.Width           = 67;
  Label16.Height          = 40;
  Label16.Visible         = 1;
  Label16.Active          = 0;
  Label16.Caption         = Label16_Caption;
  Label16.FontName        = Open_Sans_Light24x37_Regular;
  Label16.Font_Color      = 0xFFFF;
  Label16.OnUpPtr         = 0;
  Label16.OnDownPtr       = 0;
  Label16.OnClickPtr      = 0;
  Label16.OnPressPtr      = 0;

  ClockBack.OwnerScreen     = &Clock;
  ClockBack.Order           = 8;
  ClockBack.Left            = 9;
  ClockBack.Top             = 25;
  ClockBack.Width           = 36;
  ClockBack.Height          = 35;
  ClockBack.Picture_Type    = 0;
  ClockBack.Picture_Ratio   = 1;
  ClockBack.Picture_Name    = icon_back_rtc_bmp;
  ClockBack.Visible         = 1;
  ClockBack.Active          = 0;
  ClockBack.OnUpPtr         = 0;
  ClockBack.OnDownPtr       = 0;
  ClockBack.OnClickPtr      = 0;
  ClockBack.OnPressPtr      = ClockBackOnPress;

  Label17.OwnerScreen     = &Clock;
  Label17.Order           = 9;
  Label17.Left            = 519;
  Label17.Top             = 404;
  Label17.Width           = 58;
  Label17.Height          = 40;
  Label17.Visible         = 1;
  Label17.Active          = 0;
  Label17.Caption         = Label17_Caption;
  Label17.FontName        = Open_Sans_Light24x37_Regular;
  Label17.Font_Color      = 0xFFFF;
  Label17.OnUpPtr         = 0;
  Label17.OnDownPtr       = 0;
  Label17.OnClickPtr      = 0;
  Label17.OnPressPtr      = 0;

  Label18.OwnerScreen     = &Clock;
  Label18.Order           = 10;
  Label18.Left            = 683;
  Label18.Top             = 405;
  Label18.Width           = 68;
  Label18.Height          = 40;
  Label18.Visible         = 1;
  Label18.Active          = 0;
  Label18.Caption         = Label18_Caption;
  Label18.FontName        = Open_Sans_Light24x37_Regular;
  Label18.Font_Color      = 0xFFFF;
  Label18.OnUpPtr         = 0;
  Label18.OnDownPtr       = 0;
  Label18.OnClickPtr      = 0;
  Label18.OnPressPtr      = 0;

  SyncIcon.OwnerScreen     = &Clock;
  SyncIcon.Order           = 11;
  SyncIcon.Left            = 475;
  SyncIcon.Top             = 408;
  SyncIcon.Width           = 38;
  SyncIcon.Height          = 35;
  SyncIcon.Picture_Type    = 0;
  SyncIcon.Picture_Ratio   = 1;
  SyncIcon.Picture_Name    = icon_sync_rtc_bmp;
  SyncIcon.Visible         = 1;
  SyncIcon.Active          = 0;
  SyncIcon.OnUpPtr         = 0;
  SyncIcon.OnDownPtr       = 0;
  SyncIcon.OnClickPtr      = 0;
  SyncIcon.OnPressPtr      = 0;

  Image8.OwnerScreen     = &Clock;
  Image8.Order           = 12;
  Image8.Left            = 635;
  Image8.Top             = 406;
  Image8.Width           = 41;
  Image8.Height          = 37;
  Image8.Picture_Type    = 0;
  Image8.Picture_Ratio   = 1;
  Image8.Picture_Name    = icon_done_rtc_bmp;
  Image8.Visible         = 1;
  Image8.Active          = 0;
  Image8.OnUpPtr         = 0;
  Image8.OnDownPtr       = 0;
  Image8.OnClickPtr      = 0;
  Image8.OnPressPtr      = Image8OnPress;

  Box4.OwnerScreen     = &Clock;
  Box4.Order           = 13;
  Box4.Left            = 328;
  Box4.Top             = 80;
  Box4.Width           = 60;
  Box4.Height          = 345;
  Box4.Pen_Width       = 0;
  Box4.Pen_Color       = 0x0000;
  Box4.Visible         = 0;
  Box4.Active          = 1;
  Box4.Transparent     = 0;
  Box4.Gradient        = 0;
  Box4.Gradient_Orientation = 0;
  Box4.Gradient_Start_Color = 0xFFFF;
  Box4.Gradient_End_Color = 0xC618;
  Box4.Color           = 0xC618;
  Box4.PressColEnabled = 1;
  Box4.Press_Color     = 0xE71C;
  Box4.OnUpPtr         = 0;
  Box4.OnDownPtr       = 0;
  Box4.OnClickPtr      = 0;
  Box4.OnPressPtr      = Box4OnPress;

  Box5.OwnerScreen     = &Clock;
  Box5.Order           = 14;
  Box5.Left            = 400;
  Box5.Top             = 80;
  Box5.Width           = 60;
  Box5.Height          = 345;
  Box5.Pen_Width       = 0;
  Box5.Pen_Color       = 0x0000;
  Box5.Visible         = 0;
  Box5.Active          = 1;
  Box5.Transparent     = 0;
  Box5.Gradient        = 0;
  Box5.Gradient_Orientation = 0;
  Box5.Gradient_Start_Color = 0xFFFF;
  Box5.Gradient_End_Color = 0xC618;
  Box5.Color           = 0xC618;
  Box5.PressColEnabled = 1;
  Box5.Press_Color     = 0xE71C;
  Box5.OnUpPtr         = 0;
  Box5.OnDownPtr       = 0;
  Box5.OnClickPtr      = 0;
  Box5.OnPressPtr      = Box5OnPress;

  Image7.OwnerScreen     = &Clock;
  Image7.Order           = 15;
  Image7.Left            = 764;
  Image7.Top             = 422;
  Image7.Width           = 60;
  Image7.Height          = 1204;
  Image7.Picture_Type    = 0;
  Image7.Picture_Ratio   = 1;
  Image7.Picture_Name    = stripe_numbers_rtc_bmp;
  Image7.Visible         = 0;
  Image7.Active          = 0;
  Image7.OnUpPtr         = 0;
  Image7.OnDownPtr       = 0;
  Image7.OnClickPtr      = 0;
  Image7.OnPressPtr      = 0;

  Label42.OwnerScreen     = &Clock;
  Label42.Order           = 16;
  Label42.Left            = 30;
  Label42.Top             = 435;
  Label42.Width           = 50;
  Label42.Height          = 19;
  Label42.Visible         = 1;
  Label42.Active          = 0;
  Label42.Caption         = Label42_Caption;
  Label42.FontName        = Open_Sans_Light12x18_Regular;
  Label42.Font_Color      = 0xFFFF;
  Label42.OnUpPtr         = 0;
  Label42.OnDownPtr       = 0;
  Label42.OnClickPtr      = 0;
  Label42.OnPressPtr      = 0;

  Image17.OwnerScreen     = &Clock;
  Image17.Order           = 17;
  Image17.Left            = 784;
  Image17.Top             = 6;
  Image17.Width           = 145;
  Image17.Height          = 237;
  Image17.Picture_Type    = 0;
  Image17.Picture_Ratio   = 1;
  Image17.Picture_Name    = am_pm_bmp;
  Image17.Visible         = 0;
  Image17.Active          = 0;
  Image17.OnUpPtr         = 0;
  Image17.OnDownPtr       = 0;
  Image17.OnClickPtr      = 0;
  Image17.OnPressPtr      = 0;

  Box14.OwnerScreen     = &Clock;
  Box14.Order           = 18;
  Box14.Left            = 477;
  Box14.Top             = 152;
  Box14.Width           = 145;
  Box14.Height          = 200;
  Box14.Pen_Width       = 0;
  Box14.Pen_Color       = 0x0000;
  Box14.Visible         = 0;
  Box14.Active          = 1;
  Box14.Transparent     = 0;
  Box14.Gradient        = 0;
  Box14.Gradient_Orientation = 0;
  Box14.Gradient_Start_Color = 0xFFFF;
  Box14.Gradient_End_Color = 0xC618;
  Box14.Color           = 0xC618;
  Box14.PressColEnabled = 1;
  Box14.Press_Color     = 0xE71C;
  Box14.OnUpPtr         = 0;
  Box14.OnDownPtr       = 0;
  Box14.OnClickPtr      = 0;
  Box14.OnPressPtr      = Box14OnPress;

  Box21.OwnerScreen     = &Sensors;
  Box21.Order           = 0;
  Box21.Left            = 7;
  Box21.Top             = 5;
  Box21.Width           = 190;
  Box21.Height          = 49;
  Box21.Pen_Width       = 1;
  Box21.Pen_Color       = 0x0000;
  Box21.Visible         = 0;
  Box21.Active          = 1;
  Box21.Transparent     = 1;
  Box21.Gradient        = 0;
  Box21.Gradient_Orientation = 0;
  Box21.Gradient_Start_Color = 0xFFFF;
  Box21.Gradient_End_Color = 0xC618;
  Box21.Color           = 0xC618;
  Box21.PressColEnabled = 0;
  Box21.Press_Color     = 0xE71C;
  Box21.OnUpPtr         = 0;
  Box21.OnDownPtr       = 0;
  Box21.OnClickPtr      = BackIconSensorsOnPress;
  Box21.OnPressPtr      = 0;

  Diagram5_Box1.OwnerScreen     = &Sensors;
  Diagram5_Box1.Order           = 1;
  Diagram5_Box1.Left            = 533;
  Diagram5_Box1.Top             = 0;
  Diagram5_Box1.Width           = 267;
  Diagram5_Box1.Height          = 480;
  Diagram5_Box1.Pen_Width       = 0;
  Diagram5_Box1.Pen_Color       = 0x0000;
  Diagram5_Box1.Visible         = 1;
  Diagram5_Box1.Active          = 0;
  Diagram5_Box1.Transparent     = 1;
  Diagram5_Box1.Gradient        = 0;
  Diagram5_Box1.Gradient_Orientation = 0;
  Diagram5_Box1.Gradient_Start_Color = 0xFFFF;
  Diagram5_Box1.Gradient_End_Color = 0xC618;
  Diagram5_Box1.Color           = 0x7907;
  Diagram5_Box1.PressColEnabled = 1;
  Diagram5_Box1.Press_Color     = 0xE71C;
  Diagram5_Box1.OnUpPtr         = 0;
  Diagram5_Box1.OnDownPtr       = 0;
  Diagram5_Box1.OnClickPtr      = 0;
  Diagram5_Box1.OnPressPtr      = 0;

  TempIcon.OwnerScreen     = &Sensors;
  TempIcon.Order           = 2;
  TempIcon.Left            = 229;
  TempIcon.Top             = 82;
  TempIcon.Width           = 39;
  TempIcon.Height          = 83;
  TempIcon.Picture_Type    = 0;
  TempIcon.Picture_Ratio   = 1;
  TempIcon.Picture_Name    = icon_temp_sensors_bmp;
  TempIcon.Visible         = 1;
  TempIcon.Active          = 1;
  TempIcon.OnUpPtr         = 0;
  TempIcon.OnDownPtr       = 0;
  TempIcon.OnClickPtr      = 0;
  TempIcon.OnPressPtr      = 0;

  LightIcon.OwnerScreen     = &Sensors;
  LightIcon.Order           = 3;
  LightIcon.Left            = 626;
  LightIcon.Top             = 82;
  LightIcon.Width           = 83;
  LightIcon.Height          = 86;
  LightIcon.Picture_Type    = 0;
  LightIcon.Picture_Ratio   = 1;
  LightIcon.Picture_Name    = icon_light_sensors_bmp;
  LightIcon.Visible         = 1;
  LightIcon.Active          = 1;
  LightIcon.OnUpPtr         = 0;
  LightIcon.OnDownPtr       = 0;
  LightIcon.OnClickPtr      = 0;
  LightIcon.OnPressPtr      = 0;

  Diagram5_Label1.OwnerScreen     = &Sensors;
  Diagram5_Label1.Order           = 4;
  Diagram5_Label1.Left            = 165;
  Diagram5_Label1.Top             = 186;
  Diagram5_Label1.Width           = 176;
  Diagram5_Label1.Height          = 43;
  Diagram5_Label1.Visible         = 1;
  Diagram5_Label1.Active          = 1;
  Diagram5_Label1.Caption         = Diagram5_Label1_Caption;
  Diagram5_Label1.FontName        = Open_Sans_Light26x39_Regular;
  Diagram5_Label1.Font_Color      = 0xFFFF;
  Diagram5_Label1.OnUpPtr         = 0;
  Diagram5_Label1.OnDownPtr       = 0;
  Diagram5_Label1.OnClickPtr      = 0;
  Diagram5_Label1.OnPressPtr      = 0;

  Diagram5_Label2.OwnerScreen     = &Sensors;
  Diagram5_Label2.Order           = 5;
  Diagram5_Label2.Left            = 100;
  Diagram5_Label2.Top             = 281;
  Diagram5_Label2.Width           = 210;
  Diagram5_Label2.Height          = 100;
  Diagram5_Label2.Visible         = 1;
  Diagram5_Label2.Active          = 1;
  Diagram5_Label2.Caption         = Diagram5_Label2_Caption;
  Diagram5_Label2.FontName        = Open_Sans62x92_Regular;
  Diagram5_Label2.Font_Color      = 0xFFFF;
  Diagram5_Label2.OnUpPtr         = 0;
  Diagram5_Label2.OnDownPtr       = 0;
  Diagram5_Label2.OnClickPtr      = 0;
  Diagram5_Label2.OnPressPtr      = 0;

  Diagram5_Label3.OwnerScreen     = &Sensors;
  Diagram5_Label3.Order           = 6;
  Diagram5_Label3.Left            = 589;
  Diagram5_Label3.Top             = 186;
  Diagram5_Label3.Width           = 169;
  Diagram5_Label3.Height          = 43;
  Diagram5_Label3.Visible         = 1;
  Diagram5_Label3.Active          = 1;
  Diagram5_Label3.Caption         = Diagram5_Label3_Caption;
  Diagram5_Label3.FontName        = Open_Sans_Light26x39_Regular;
  Diagram5_Label3.Font_Color      = 0xFFFF;
  Diagram5_Label3.OnUpPtr         = 0;
  Diagram5_Label3.OnDownPtr       = 0;
  Diagram5_Label3.OnClickPtr      = 0;
  Diagram5_Label3.OnPressPtr      = 0;

  Diagram5_Label4.OwnerScreen     = &Sensors;
  Diagram5_Label4.Order           = 7;
  Diagram5_Label4.Left            = 575;
  Diagram5_Label4.Top             = 281;
  Diagram5_Label4.Width           = 194;
  Diagram5_Label4.Height          = 100;
  Diagram5_Label4.Visible         = 1;
  Diagram5_Label4.Active          = 1;
  Diagram5_Label4.Caption         = Diagram5_Label4_Caption;
  Diagram5_Label4.FontName        = Open_Sans62x92_Regular;
  Diagram5_Label4.Font_Color      = 0xFFFF;
  Diagram5_Label4.OnUpPtr         = 0;
  Diagram5_Label4.OnDownPtr       = 0;
  Diagram5_Label4.OnClickPtr      = 0;
  Diagram5_Label4.OnPressPtr      = 0;

  Diagram5_Label5.OwnerScreen     = &Sensors;
  Diagram5_Label5.Order           = 8;
  Diagram5_Label5.Left            = 337;
  Diagram5_Label5.Top             = 284;
  Diagram5_Label5.Width           = 98;
  Diagram5_Label5.Height          = 49;
  Diagram5_Label5.Visible         = 1;
  Diagram5_Label5.Active          = 1;
  Diagram5_Label5.Caption         = Diagram5_Label5_Caption;
  Diagram5_Label5.FontName        = Open_Sans_Light29x45_Regular;
  Diagram5_Label5.Font_Color      = 0xFFFF;
  Diagram5_Label5.OnUpPtr         = 0;
  Diagram5_Label5.OnDownPtr       = 0;
  Diagram5_Label5.OnClickPtr      = 0;
  Diagram5_Label5.OnPressPtr      = 0;

  BackIconSensors.OwnerScreen     = &Sensors;
  BackIconSensors.Order           = 9;
  BackIconSensors.Left            = 8;
  BackIconSensors.Top             = 10;
  BackIconSensors.Width           = 37;
  BackIconSensors.Height          = 36;
  BackIconSensors.Picture_Type    = 0;
  BackIconSensors.Picture_Ratio   = 1;
  BackIconSensors.Picture_Name    = icon_back_sensors_bmp;
  BackIconSensors.Visible         = 1;
  BackIconSensors.Active          = 0;
  BackIconSensors.OnUpPtr         = 0;
  BackIconSensors.OnDownPtr       = 0;
  BackIconSensors.OnClickPtr      = 0;
  BackIconSensors.OnPressPtr      = BackIconSensorsOnPress;

  Diagram5_Label6.OwnerScreen     = &Sensors;
  Diagram5_Label6.Order           = 10;
  Diagram5_Label6.Left            = 53;
  Diagram5_Label6.Top             = 5;
  Diagram5_Label6.Width           = 118;
  Diagram5_Label6.Height          = 48;
  Diagram5_Label6.Visible         = 1;
  Diagram5_Label6.Active          = 0;
  Diagram5_Label6.Caption         = Diagram5_Label6_Caption;
  Diagram5_Label6.FontName        = Open_Sans_Light29x43_Regular;
  Diagram5_Label6.Font_Color      = 0xFFFF;
  Diagram5_Label6.OnUpPtr         = 0;
  Diagram5_Label6.OnDownPtr       = 0;
  Diagram5_Label6.OnClickPtr      = 0;
  Diagram5_Label6.OnPressPtr      = BackIconSensorsOnPress;

  Label21.OwnerScreen     = &Sensors;
  Label21.Order           = 11;
  Label21.Left            = 313;
  Label21.Top             = 287;
  Label21.Width           = 12;
  Label21.Height          = 49;
  Label21.Visible         = 1;
  Label21.Active          = 1;
  Label21.Caption         = Label21_Caption;
  Label21.FontName        = Open_Sans_Light29x45_Regular;
  Label21.Font_Color      = 0xFFFF;
  Label21.OnUpPtr         = 0;
  Label21.OnDownPtr       = 0;
  Label21.OnClickPtr      = 0;
  Label21.OnPressPtr      = 0;

  Box20.OwnerScreen     = &MP3_SD;
  Box20.Order           = 0;
  Box20.Left            = 2;
  Box20.Top             = 4;
  Box20.Width           = 199;
  Box20.Height          = 52;
  Box20.Pen_Width       = 1;
  Box20.Pen_Color       = 0x0000;
  Box20.Visible         = 0;
  Box20.Active          = 1;
  Box20.Transparent     = 1;
  Box20.Gradient        = 0;
  Box20.Gradient_Orientation = 0;
  Box20.Gradient_Start_Color = 0xFFFF;
  Box20.Gradient_End_Color = 0xC618;
  Box20.Color           = 0xC618;
  Box20.PressColEnabled = 0;
  Box20.Press_Color     = 0xE71C;
  Box20.OnUpPtr         = 0;
  Box20.OnDownPtr       = 0;
  Box20.OnClickPtr      = mp3_back_iconOnPress;
  Box20.OnPressPtr      = 0;

  Label22.OwnerScreen     = &MP3_SD;
  Label22.Order           = 1;
  Label22.Left            = 54;
  Label22.Top             = 8;
  Label22.Width           = 140;
  Label22.Height          = 40;
  Label22.Visible         = 1;
  Label22.Active          = 0;
  Label22.Caption         = Label22_Caption;
  Label22.FontName        = Open_Sans_Light24x37_Regular;
  Label22.Font_Color      = 0xFFFF;
  Label22.OnUpPtr         = 0;
  Label22.OnDownPtr       = 0;
  Label22.OnClickPtr      = 0;
  Label22.OnPressPtr      = Label22OnPress;

  Label23.OwnerScreen     = &MP3_SD;
  Label23.Order           = 2;
  Label23.Left            = 271;
  Label23.Top             = 233;
  Label23.Width           = 247;
  Label23.Height          = 40;
  Label23.Visible         = 1;
  Label23.Active          = 1;
  Label23.Caption         = Label23_Caption;
  Label23.FontName        = Open_Sans_Light24x37_Regular;
  Label23.Font_Color      = 0xFFFF;
  Label23.OnUpPtr         = 0;
  Label23.OnDownPtr       = 0;
  Label23.OnClickPtr      = 0;
  Label23.OnPressPtr      = 0;

  Image11.OwnerScreen     = &MP3_SD;
  Image11.Order           = 3;
  Image11.Left            = 709;
  Image11.Top             = 40;
  Image11.Width           = 79;
  Image11.Height          = 63;
  Image11.Picture_Type    = 0;
  Image11.Picture_Ratio   = 1;
  Image11.Picture_Name    = icon_microsd_mp3_bmp;
  Image11.Visible         = 1;
  Image11.Active          = 1;
  Image11.OnUpPtr         = 0;
  Image11.OnDownPtr       = 0;
  Image11.OnClickPtr      = 0;
  Image11.OnPressPtr      = 0;

  Image12.OwnerScreen     = &MP3_SD;
  Image12.Order           = 4;
  Image12.Left            = 645;
  Image12.Top             = 55;
  Image12.Width           = 54;
  Image12.Height          = 23;
  Image12.Picture_Type    = 0;
  Image12.Picture_Ratio   = 1;
  Image12.Picture_Name    = icon_anim_01_mp3_bmp;
  Image12.Visible         = 1;
  Image12.Active          = 1;
  Image12.OnUpPtr         = 0;
  Image12.OnDownPtr       = 0;
  Image12.OnClickPtr      = 0;
  Image12.OnPressPtr      = 0;

  Image13.OwnerScreen     = &MP3_SD;
  Image13.Order           = 5;
  Image13.Left            = 645;
  Image13.Top             = 55;
  Image13.Width           = 54;
  Image13.Height          = 23;
  Image13.Picture_Type    = 0;
  Image13.Picture_Ratio   = 1;
  Image13.Picture_Name    = icon_anim_02_mp3_bmp;
  Image13.Visible         = 1;
  Image13.Active          = 1;
  Image13.OnUpPtr         = 0;
  Image13.OnDownPtr       = 0;
  Image13.OnClickPtr      = 0;
  Image13.OnPressPtr      = 0;

  Image14.OwnerScreen     = &MP3_SD;
  Image14.Order           = 6;
  Image14.Left            = 645;
  Image14.Top             = 55;
  Image14.Width           = 54;
  Image14.Height          = 23;
  Image14.Picture_Type    = 0;
  Image14.Picture_Ratio   = 1;
  Image14.Picture_Name    = icon_anim_03_mp3_bmp;
  Image14.Visible         = 1;
  Image14.Active          = 1;
  Image14.OnUpPtr         = 0;
  Image14.OnDownPtr       = 0;
  Image14.OnClickPtr      = 0;
  Image14.OnPressPtr      = 0;

  mp3_back_icon.OwnerScreen     = &MP3_SD;
  mp3_back_icon.Order           = 7;
  mp3_back_icon.Left            = 5;
  mp3_back_icon.Top             = 12;
  mp3_back_icon.Width           = 36;
  mp3_back_icon.Height          = 36;
  mp3_back_icon.Picture_Type    = 0;
  mp3_back_icon.Picture_Ratio   = 1;
  mp3_back_icon.Picture_Name    = icon_back_mp3_bmp;
  mp3_back_icon.Visible         = 1;
  mp3_back_icon.Active          = 0;
  mp3_back_icon.OnUpPtr         = 0;
  mp3_back_icon.OnDownPtr       = 0;
  mp3_back_icon.OnClickPtr      = 0;
  mp3_back_icon.OnPressPtr      = mp3_back_iconOnPress;

  Box19.OwnerScreen     = &MP3_SongList;
  Box19.Order           = 0;
  Box19.Left            = 2;
  Box19.Top             = 4;
  Box19.Width           = 199;
  Box19.Height          = 44;
  Box19.Pen_Width       = 1;
  Box19.Pen_Color       = 0x0000;
  Box19.Visible         = 0;
  Box19.Active          = 1;
  Box19.Transparent     = 1;
  Box19.Gradient        = 0;
  Box19.Gradient_Orientation = 0;
  Box19.Gradient_Start_Color = 0xFFFF;
  Box19.Gradient_End_Color = 0xC618;
  Box19.Color           = 0xC618;
  Box19.PressColEnabled = 0;
  Box19.Press_Color     = 0xE71C;
  Box19.OnUpPtr         = 0;
  Box19.OnDownPtr       = 0;
  Box19.OnClickPtr      = Image15OnPress;
  Box19.OnPressPtr      = 0;

  Box6.OwnerScreen     = &MP3_SongList;
  Box6.Order           = 1;
  Box6.Left            = 0;
  Box6.Top             = 50;
  Box6.Width           = 800;
  Box6.Height          = 390;
  Box6.Pen_Width       = 0;
  Box6.Pen_Color       = 0x0000;
  Box6.Visible         = 1;
  Box6.Active          = 1;
  Box6.Transparent     = 1;
  Box6.Gradient        = 0;
  Box6.Gradient_Orientation = 0;
  Box6.Gradient_Start_Color = 0xFFFF;
  Box6.Gradient_End_Color = 0xC618;
  Box6.Color           = 0x2B31;
  Box6.PressColEnabled = 0;
  Box6.Press_Color     = 0xE71C;
  Box6.OnUpPtr         = 0;
  Box6.OnDownPtr       = 0;
  Box6.OnClickPtr      = Box6OnClick;
  Box6.OnPressPtr      = Box6OnPress;

  Label24.OwnerScreen     = &MP3_SongList;
  Label24.Order           = 2;
  Label24.Left            = 55;
  Label24.Top             = 11;
  Label24.Width           = 140;
  Label24.Height          = 40;
  Label24.Visible         = 1;
  Label24.Active          = 0;
  Label24.Caption         = Label24_Caption;
  Label24.FontName        = Open_Sans_Light24x37_Regular;
  Label24.Font_Color      = 0xFFFF;
  Label24.OnUpPtr         = 0;
  Label24.OnDownPtr       = 0;
  Label24.OnClickPtr      = 0;
  Label24.OnPressPtr      = Label24OnPress;

  mp3_back_icon2.OwnerScreen     = &MP3_SongList;
  mp3_back_icon2.Order           = 3;
  mp3_back_icon2.Left            = 8;
  mp3_back_icon2.Top             = 12;
  mp3_back_icon2.Width           = 36;
  mp3_back_icon2.Height          = 36;
  mp3_back_icon2.Picture_Type    = 0;
  mp3_back_icon2.Picture_Ratio   = 1;
  mp3_back_icon2.Picture_Name    = icon_back_mp3_bmp;
  mp3_back_icon2.Visible         = 1;
  mp3_back_icon2.Active          = 0;
  mp3_back_icon2.OnUpPtr         = 0;
  mp3_back_icon2.OnDownPtr       = 0;
  mp3_back_icon2.OnClickPtr      = 0;
  mp3_back_icon2.OnPressPtr      = Image15OnPress;

  Label26.OwnerScreen     = &MP3_SongList;
  Label26.Order           = 4;
  Label26.Left            = 290;
  Label26.Top             = 441;
  Label26.Width           = 244;
  Label26.Height          = 36;
  Label26.Visible         = 1;
  Label26.Active          = 1;
  Label26.Caption         = Label26_Caption;
  Label26.FontName        = Open_Sans_Light21x33_Regular;
  Label26.Font_Color      = 0xFFFF;
  Label26.OnUpPtr         = 0;
  Label26.OnDownPtr       = 0;
  Label26.OnClickPtr      = 0;
  Label26.OnPressPtr      = 0;

  folder_icon.OwnerScreen     = &MP3_SongList;
  folder_icon.Order           = 5;
  folder_icon.Left            = 772;
  folder_icon.Top             = 25;
  folder_icon.Width           = 26;
  folder_icon.Height          = 22;
  folder_icon.Picture_Type    = 0;
  folder_icon.Picture_Ratio   = 1;
  folder_icon.Picture_Name    = icon_folder_mp3_bmp;
  folder_icon.Visible         = 0;
  folder_icon.Active          = 0;
  folder_icon.OnUpPtr         = 0;
  folder_icon.OnDownPtr       = 0;
  folder_icon.OnClickPtr      = 0;
  folder_icon.OnPressPtr      = 0;

  file_icon.OwnerScreen     = &MP3_SongList;
  file_icon.Order           = 6;
  file_icon.Left            = 776;
  file_icon.Top             = 3;
  file_icon.Width           = 21;
  file_icon.Height          = 21;
  file_icon.Picture_Type    = 0;
  file_icon.Picture_Ratio   = 1;
  file_icon.Picture_Name    = icon_file_mp3_bmp;
  file_icon.Visible         = 0;
  file_icon.Active          = 0;
  file_icon.OnUpPtr         = 0;
  file_icon.OnDownPtr       = 0;
  file_icon.OnClickPtr      = 0;
  file_icon.OnPressPtr      = 0;

  Image30.OwnerScreen     = &MP3_SongList;
  Image30.Order           = 7;
  Image30.Left            = 330;
  Image30.Top             = 115;
  Image30.Width           = 133;
  Image30.Height          = 153;
  Image30.Picture_Type    = 0;
  Image30.Picture_Ratio   = 1;
  Image30.Picture_Name    = gabmp3_note_bmp;
  Image30.Visible         = 1;
  Image30.Active          = 1;
  Image30.OnUpPtr         = 0;
  Image30.OnDownPtr       = 0;
  Image30.OnClickPtr      = 0;
  Image30.OnPressPtr      = 0;

  Box17.OwnerScreen     = &MP3_Player;
  Box17.Order           = 0;
  Box17.Left            = 2;
  Box17.Top             = 3;
  Box17.Width           = 201;
  Box17.Height          = 55;
  Box17.Pen_Width       = 1;
  Box17.Pen_Color       = 0x0000;
  Box17.Visible         = 0;
  Box17.Active          = 1;
  Box17.Transparent     = 1;
  Box17.Gradient        = 0;
  Box17.Gradient_Orientation = 0;
  Box17.Gradient_Start_Color = 0xFFFF;
  Box17.Gradient_End_Color = 0xC618;
  Box17.Color           = 0xC618;
  Box17.PressColEnabled = 0;
  Box17.Press_Color     = 0xE71C;
  Box17.OnUpPtr         = 0;
  Box17.OnDownPtr       = 0;
  Box17.OnClickPtr      = Icon_back_mp3OnClick;
  Box17.OnPressPtr      = 0;

  Label27.OwnerScreen     = &MP3_Player;
  Label27.Order           = 1;
  Label27.Left            = 56;
  Label27.Top             = 20;
  Label27.Width           = 140;
  Label27.Height          = 40;
  Label27.Visible         = 1;
  Label27.Active          = 0;
  Label27.Caption         = Label27_Caption;
  Label27.FontName        = Open_Sans_Light24x37_Regular;
  Label27.Font_Color      = 0xFFFF;
  Label27.OnUpPtr         = 0;
  Label27.OnDownPtr       = 0;
  Label27.OnClickPtr      = 0;
  Label27.OnPressPtr      = Icon_back_mp3OnClick;

  Icon_back_mp3.OwnerScreen     = &MP3_Player;
  Icon_back_mp3.Order           = 2;
  Icon_back_mp3.Left            = 7;
  Icon_back_mp3.Top             = 20;
  Icon_back_mp3.Width           = 36;
  Icon_back_mp3.Height          = 36;
  Icon_back_mp3.Picture_Type    = 0;
  Icon_back_mp3.Picture_Ratio   = 1;
  Icon_back_mp3.Picture_Name    = icon_back_mp3_bmp;
  Icon_back_mp3.Visible         = 1;
  Icon_back_mp3.Active          = 0;
  Icon_back_mp3.OnUpPtr         = 0;
  Icon_back_mp3.OnDownPtr       = 0;
  Icon_back_mp3.OnClickPtr      = Icon_back_mp3OnClick;
  Icon_back_mp3.OnPressPtr      = Icon_back_mp3OnClick;

  VolmeBar.OwnerScreen     = &MP3_Player;
  VolmeBar.Order           = 3;
  VolmeBar.Left            = 664;
  VolmeBar.Top             = 27;
  VolmeBar.Width           = 120;
  VolmeBar.Height          = 20;
  VolmeBar.Pen_Width       = 0;
  VolmeBar.Pen_Color       = 0x0000;
  VolmeBar.Visible         = 1;
  VolmeBar.Active          = 1;
  VolmeBar.Transparent     = 1;
  VolmeBar.Gradient        = 0;
  VolmeBar.Gradient_Orientation = 0;
  VolmeBar.Gradient_Start_Color = 0xFFFF;
  VolmeBar.Gradient_End_Color = 0xC618;
  VolmeBar.Color           = 0x2B31;
  VolmeBar.PressColEnabled = 0;
  VolmeBar.Press_Color     = 0xE71C;
  VolmeBar.OnUpPtr         = 0;
  VolmeBar.OnDownPtr       = 0;
  VolmeBar.OnClickPtr      = 0;
  VolmeBar.OnPressPtr      = VolmeBarOnPress;

  Image15.OwnerScreen     = &MP3_Player;
  Image15.Order           = 4;
  Image15.Left            = 622;
  Image15.Top             = 24;
  Image15.Width           = 37;
  Image15.Height          = 24;
  Image15.Picture_Type    = 0;
  Image15.Picture_Ratio   = 1;
  Image15.Picture_Name    = icon_volume_mp3_bmp;
  Image15.Visible         = 1;
  Image15.Active          = 1;
  Image15.OnUpPtr         = 0;
  Image15.OnDownPtr       = 0;
  Image15.OnClickPtr      = 0;
  Image15.OnPressPtr      = 0;

  ProgressBar.OwnerScreen     = &MP3_Player;
  ProgressBar.Order           = 5;
  ProgressBar.Left            = 300;
  ProgressBar.Top             = 410;
  ProgressBar.Width           = 400;
  ProgressBar.Height          = 20;
  ProgressBar.Pen_Width       = 0;
  ProgressBar.Pen_Color       = 0x0000;
  ProgressBar.Visible         = 1;
  ProgressBar.Active          = 1;
  ProgressBar.Transparent     = 1;
  ProgressBar.Gradient        = 0;
  ProgressBar.Gradient_Orientation = 0;
  ProgressBar.Gradient_Start_Color = 0xFFFF;
  ProgressBar.Gradient_End_Color = 0xC618;
  ProgressBar.Color           = 0x2B31;
  ProgressBar.PressColEnabled = 0;
  ProgressBar.Press_Color     = 0xE71C;
  ProgressBar.OnUpPtr         = 0;
  ProgressBar.OnDownPtr       = 0;
  ProgressBar.OnClickPtr      = 0;
  ProgressBar.OnPressPtr      = ProgreesBarOnPress;

  Label28.OwnerScreen     = &MP3_Player;
  Label28.Order           = 6;
  Label28.Left            = 354;
  Label28.Top             = 324;
  Label28.Width           = 94;
  Label28.Height          = 40;
  Label28.Visible         = 1;
  Label28.Active          = 1;
  Label28.Caption         = Label28_Caption;
  Label28.FontName        = Open_Sans_Light24x37_Regular;
  Label28.Font_Color      = 0xFFFF;
  Label28.OnUpPtr         = 0;
  Label28.OnDownPtr       = 0;
  Label28.OnClickPtr      = 0;
  Label28.OnPressPtr      = 0;

  previous_icon.OwnerScreen     = &MP3_Player;
  previous_icon.Order           = 7;
  previous_icon.Left            = 64;
  previous_icon.Top             = 402;
  previous_icon.Width           = 40;
  previous_icon.Height          = 39;
  previous_icon.Picture_Type    = 0;
  previous_icon.Picture_Ratio   = 1;
  previous_icon.Picture_Name    = icon_prev_mp3_bmp;
  previous_icon.Visible         = 1;
  previous_icon.Active          = 1;
  previous_icon.OnUpPtr         = 0;
  previous_icon.OnDownPtr       = previous_iconOnDown;
  previous_icon.OnClickPtr      = 0;
  previous_icon.OnPressPtr      = 0;

  pause_icon.OwnerScreen     = &MP3_Player;
  pause_icon.Order           = 8;
  pause_icon.Left            = 116;
  pause_icon.Top             = 402;
  pause_icon.Width           = 40;
  pause_icon.Height          = 39;
  pause_icon.Picture_Type    = 0;
  pause_icon.Picture_Ratio   = 1;
  pause_icon.Picture_Name    = icon_pause_mp3_bmp;
  pause_icon.Visible         = 1;
  pause_icon.Active          = 1;
  pause_icon.OnUpPtr         = 0;
  pause_icon.OnDownPtr       = pause_iconOnPress;
  pause_icon.OnClickPtr      = pause_iconOnPress;
  pause_icon.OnPressPtr      = 0;

  Play_icon.OwnerScreen     = &MP3_Player;
  Play_icon.Order           = 9;
  Play_icon.Left            = 165;
  Play_icon.Top             = 402;
  Play_icon.Width           = 40;
  Play_icon.Height          = 39;
  Play_icon.Picture_Type    = 0;
  Play_icon.Picture_Ratio   = 1;
  Play_icon.Picture_Name    = icon_play_mp3_bmp;
  Play_icon.Visible         = 1;
  Play_icon.Active          = 0;
  Play_icon.OnUpPtr         = 0;
  Play_icon.OnDownPtr       = Play_iconOnDown;
  Play_icon.OnClickPtr      = 0;
  Play_icon.OnPressPtr      = 0;

  stop_icon.OwnerScreen     = &MP3_Player;
  stop_icon.Order           = 10;
  stop_icon.Left            = 208;
  stop_icon.Top             = 402;
  stop_icon.Width           = 40;
  stop_icon.Height          = 39;
  stop_icon.Picture_Type    = 0;
  stop_icon.Picture_Ratio   = 1;
  stop_icon.Picture_Name    = icon_stop_mp3_bmp;
  stop_icon.Visible         = 1;
  stop_icon.Active          = 1;
  stop_icon.OnUpPtr         = 0;
  stop_icon.OnDownPtr       = stop_iconOnDown;
  stop_icon.OnClickPtr      = 0;
  stop_icon.OnPressPtr      = 0;

  next_icon.OwnerScreen     = &MP3_Player;
  next_icon.Order           = 11;
  next_icon.Left            = 254;
  next_icon.Top             = 402;
  next_icon.Width           = 40;
  next_icon.Height          = 39;
  next_icon.Picture_Type    = 0;
  next_icon.Picture_Ratio   = 1;
  next_icon.Picture_Name    = icon_next_mp3_bmp;
  next_icon.Visible         = 1;
  next_icon.Active          = 1;
  next_icon.OnUpPtr         = 0;
  next_icon.OnDownPtr       = next_iconOnDown;
  next_icon.OnClickPtr      = 0;
  next_icon.OnPressPtr      = 0;

  songlist_icon.OwnerScreen     = &MP3_Player;
  songlist_icon.Order           = 12;
  songlist_icon.Left            = 12;
  songlist_icon.Top             = 402;
  songlist_icon.Width           = 40;
  songlist_icon.Height          = 39;
  songlist_icon.Picture_Type    = 0;
  songlist_icon.Picture_Ratio   = 1;
  songlist_icon.Picture_Name    = icon_playlist_mp3_bmp;
  songlist_icon.Visible         = 1;
  songlist_icon.Active          = 1;
  songlist_icon.OnUpPtr         = 0;
  songlist_icon.OnDownPtr       = songlist_iconOnPress;
  songlist_icon.OnClickPtr      = songlist_iconOnPress;
  songlist_icon.OnPressPtr      = 0;

  Label6.OwnerScreen     = &MP3_Player;
  Label6.Order           = 13;
  Label6.Left            = 717;
  Label6.Top             = 403;
  Label6.Width           = 70;
  Label6.Height          = 40;
  Label6.Visible         = 1;
  Label6.Active          = 1;
  Label6.Caption         = Label6_Caption;
  Label6.FontName        = Open_Sans_Light24x37_Regular;
  Label6.Font_Color      = 0xFFFF;
  Label6.OnUpPtr         = 0;
  Label6.OnDownPtr       = 0;
  Label6.OnClickPtr      = 0;
  Label6.OnPressPtr      = 0;

  Image31.OwnerScreen     = &MP3_Player;
  Image31.Order           = 14;
  Image31.Left            = 450;
  Image31.Top             = 130;
  Image31.Width           = 136;
  Image31.Height          = 153;
  Image31.Picture_Type    = 0;
  Image31.Picture_Ratio   = 1;
  Image31.Picture_Name    = gacmp3_player_note_bmp;
  Image31.Visible         = 1;
  Image31.Active          = 1;
  Image31.OnUpPtr         = 0;
  Image31.OnDownPtr       = 0;
  Image31.OnClickPtr      = 0;
  Image31.OnPressPtr      = 0;

  Box18.OwnerScreen     = &Paint;
  Box18.Order           = 0;
  Box18.Left            = 3;
  Box18.Top             = 5;
  Box18.Width           = 136;
  Box18.Height          = 44;
  Box18.Pen_Width       = 1;
  Box18.Pen_Color       = 0x0000;
  Box18.Visible         = 0;
  Box18.Active          = 1;
  Box18.Transparent     = 1;
  Box18.Gradient        = 0;
  Box18.Gradient_Orientation = 0;
  Box18.Gradient_Start_Color = 0xFFFF;
  Box18.Gradient_End_Color = 0xC618;
  Box18.Color           = 0xC618;
  Box18.PressColEnabled = 0;
  Box18.Press_Color     = 0xE71C;
  Box18.OnUpPtr         = 0;
  Box18.OnDownPtr       = 0;
  Box18.OnClickPtr      = icon_paint_backOnPress;
  Box18.OnPressPtr      = 0;

  Image4.OwnerScreen     = &Paint;
  Image4.Order           = 1;
  Image4.Left            = 0;
  Image4.Top             = 81;
  Image4.Width           = 53;
  Image4.Height          = 53;
  Image4.Picture_Type    = 0;
  Image4.Picture_Ratio   = 1;
  Image4.Picture_Name    = icon_new_screen_selected_bmp;
  Image4.Visible         = 0;
  Image4.Active          = 1;
  Image4.OnUpPtr         = 0;
  Image4.OnDownPtr       = 0;
  Image4.OnClickPtr      = 0;
  Image4.OnPressPtr      = 0;

  NewScreen.OwnerScreen     = &Paint;
  NewScreen.Order           = 2;
  NewScreen.Left            = 0;
  NewScreen.Top             = 81;
  NewScreen.Width           = 53;
  NewScreen.Height          = 53;
  NewScreen.Picture_Type    = 0;
  NewScreen.Picture_Ratio   = 1;
  NewScreen.Picture_Name    = icon_new_screen_bmp;
  NewScreen.Visible         = 1;
  NewScreen.Active          = 1;
  NewScreen.OnUpPtr         = 0;
  NewScreen.OnDownPtr       = 0;
  NewScreen.OnClickPtr      = 0;
  NewScreen.OnPressPtr      = NewScreenOnPress;

  Image25.OwnerScreen     = &Paint;
  Image25.Order           = 3;
  Image25.Left            = 0;
  Image25.Top             = 151;
  Image25.Width           = 53;
  Image25.Height          = 53;
  Image25.Picture_Type    = 0;
  Image25.Picture_Ratio   = 1;
  Image25.Picture_Name    = icon_brush_selected_bmp;
  Image25.Visible         = 0;
  Image25.Active          = 1;
  Image25.OnUpPtr         = 0;
  Image25.OnDownPtr       = 0;
  Image25.OnClickPtr      = 0;
  Image25.OnPressPtr      = 0;

  Pen.OwnerScreen     = &Paint;
  Pen.Order           = 4;
  Pen.Left            = 0;
  Pen.Top             = 151;
  Pen.Width           = 53;
  Pen.Height          = 53;
  Pen.Picture_Type    = 0;
  Pen.Picture_Ratio   = 1;
  Pen.Picture_Name    = icon_brush_bmp;
  Pen.Visible         = 1;
  Pen.Active          = 1;
  Pen.OnUpPtr         = 0;
  Pen.OnDownPtr       = 0;
  Pen.OnClickPtr      = 0;
  Pen.OnPressPtr      = PenOnPress;

  Image27.OwnerScreen     = &Paint;
  Image27.Order           = 5;
  Image27.Left            = 0;
  Image27.Top             = 218;
  Image27.Width           = 53;
  Image27.Height          = 53;
  Image27.Picture_Type    = 0;
  Image27.Picture_Ratio   = 1;
  Image27.Picture_Name    = icon_eraser_selected_bmp;
  Image27.Visible         = 0;
  Image27.Active          = 1;
  Image27.OnUpPtr         = 0;
  Image27.OnDownPtr       = 0;
  Image27.OnClickPtr      = 0;
  Image27.OnPressPtr      = 0;

  Eraser.OwnerScreen     = &Paint;
  Eraser.Order           = 6;
  Eraser.Left            = 0;
  Eraser.Top             = 218;
  Eraser.Width           = 53;
  Eraser.Height          = 53;
  Eraser.Picture_Type    = 0;
  Eraser.Picture_Ratio   = 1;
  Eraser.Picture_Name    = icon_eraser_bmp;
  Eraser.Visible         = 1;
  Eraser.Active          = 1;
  Eraser.OnUpPtr         = 0;
  Eraser.OnDownPtr       = 0;
  Eraser.OnClickPtr      = 0;
  Eraser.OnPressPtr      = EraserOnPress;

  Image29.OwnerScreen     = &Paint;
  Image29.Order           = 7;
  Image29.Left            = 0;
  Image29.Top             = 292;
  Image29.Width           = 53;
  Image29.Height          = 53;
  Image29.Picture_Type    = 0;
  Image29.Picture_Ratio   = 1;
  Image29.Picture_Name    = icon_fill_back_selected_bmp;
  Image29.Visible         = 0;
  Image29.Active          = 1;
  Image29.OnUpPtr         = 0;
  Image29.OnDownPtr       = 0;
  Image29.OnClickPtr      = 0;
  Image29.OnPressPtr      = 0;

  DrawingArea.OwnerScreen     = &Paint;
  DrawingArea.Order           = 8;
  DrawingArea.Left            = 53;
  DrawingArea.Top             = 55;
  DrawingArea.Width           = 768;
  DrawingArea.Height          = 425;
  DrawingArea.Pen_Width       = 0;
  DrawingArea.Pen_Color       = 0x0000;
  DrawingArea.Visible         = 1;
  DrawingArea.Active          = 1;
  DrawingArea.Transparent     = 1;
  DrawingArea.Gradient        = 0;
  DrawingArea.Gradient_Orientation = 0;
  DrawingArea.Gradient_Start_Color = 0xFFFF;
  DrawingArea.Gradient_End_Color = 0xC618;
  DrawingArea.Color           = 0xFFFF;
  DrawingArea.PressColEnabled = 0;
  DrawingArea.Press_Color     = 0xE71C;
  DrawingArea.OnUpPtr         = 0;
  DrawingArea.OnDownPtr       = 0;
  DrawingArea.OnClickPtr      = 0;
  DrawingArea.OnPressPtr      = DrawingAreaOnPress;

  icon_paint_back.OwnerScreen     = &Paint;
  icon_paint_back.Order           = 9;
  icon_paint_back.Left            = 6;
  icon_paint_back.Top             = 8;
  icon_paint_back.Width           = 40;
  icon_paint_back.Height          = 39;
  icon_paint_back.Picture_Type    = 0;
  icon_paint_back.Picture_Ratio   = 1;
  icon_paint_back.Picture_Name    = icon_back_paint_bmp;
  icon_paint_back.Visible         = 1;
  icon_paint_back.Active          = 0;
  icon_paint_back.OnUpPtr         = 0;
  icon_paint_back.OnDownPtr       = 0;
  icon_paint_back.OnClickPtr      = 0;
  icon_paint_back.OnPressPtr      = icon_paint_backOnPress;

  Label29.OwnerScreen     = &Paint;
  Label29.Order           = 10;
  Label29.Left            = 58;
  Label29.Top             = 3;
  Label29.Width           = 75;
  Label29.Height          = 48;
  Label29.Visible         = 1;
  Label29.Active          = 0;
  Label29.Caption         = Label29_Caption;
  Label29.FontName        = Open_Sans_Light29x43_Regular;
  Label29.Font_Color      = 0xFFFF;
  Label29.OnUpPtr         = 0;
  Label29.OnDownPtr       = 0;
  Label29.OnClickPtr      = 0;
  Label29.OnPressPtr      = icon_paint_backOnPress;

  Color01.OwnerScreen     = &Paint;
  Color01.Order           = 11;
  Color01.Left            = 170;
  Color01.Top             = 0;
  Color01.Width           = 20;
  Color01.Height          = 54;
  Color01.Pen_Width       = 1;
  Color01.Pen_Color       = 0x0000;
  Color01.Visible         = 1;
  Color01.Active          = 1;
  Color01.Transparent     = 1;
  Color01.Gradient        = 0;
  Color01.Gradient_Orientation = 0;
  Color01.Gradient_Start_Color = 0xFFFF;
  Color01.Gradient_End_Color = 0xC618;
  Color01.Color           = 0x0000;
  Color01.PressColEnabled = 0;
  Color01.Press_Color     = 0xE71C;
  Color01.OnUpPtr         = 0;
  Color01.OnDownPtr       = 0;
  Color01.OnClickPtr      = 0;
  Color01.OnPressPtr      = Color01OnPress;

  Color02.OwnerScreen     = &Paint;
  Color02.Order           = 12;
  Color02.Left            = 191;
  Color02.Top             = 0;
  Color02.Width           = 20;
  Color02.Height          = 54;
  Color02.Pen_Width       = 1;
  Color02.Pen_Color       = 0x8410;
  Color02.Visible         = 1;
  Color02.Active          = 1;
  Color02.Transparent     = 1;
  Color02.Gradient        = 0;
  Color02.Gradient_Orientation = 0;
  Color02.Gradient_Start_Color = 0xFFFF;
  Color02.Gradient_End_Color = 0xC618;
  Color02.Color           = 0x8410;
  Color02.PressColEnabled = 0;
  Color02.Press_Color     = 0xE71C;
  Color02.OnUpPtr         = 0;
  Color02.OnDownPtr       = 0;
  Color02.OnClickPtr      = 0;
  Color02.OnPressPtr      = Color02OnPress;

  Color03.OwnerScreen     = &Paint;
  Color03.Order           = 13;
  Color03.Left            = 212;
  Color03.Top             = 0;
  Color03.Width           = 20;
  Color03.Height          = 54;
  Color03.Pen_Width       = 1;
  Color03.Pen_Color       = 0xA534;
  Color03.Visible         = 1;
  Color03.Active          = 1;
  Color03.Transparent     = 1;
  Color03.Gradient        = 0;
  Color03.Gradient_Orientation = 0;
  Color03.Gradient_Start_Color = 0xFFFF;
  Color03.Gradient_End_Color = 0xC618;
  Color03.Color           = 0xA534;
  Color03.PressColEnabled = 0;
  Color03.Press_Color     = 0xE71C;
  Color03.OnUpPtr         = 0;
  Color03.OnDownPtr       = 0;
  Color03.OnClickPtr      = 0;
  Color03.OnPressPtr      = Color03OnPress;

  Color04.OwnerScreen     = &Paint;
  Color04.Order           = 14;
  Color04.Left            = 233;
  Color04.Top             = 0;
  Color04.Width           = 20;
  Color04.Height          = 54;
  Color04.Pen_Width       = 1;
  Color04.Pen_Color       = 0xDEDB;
  Color04.Visible         = 1;
  Color04.Active          = 1;
  Color04.Transparent     = 1;
  Color04.Gradient        = 0;
  Color04.Gradient_Orientation = 0;
  Color04.Gradient_Start_Color = 0xFFFF;
  Color04.Gradient_End_Color = 0xC618;
  Color04.Color           = 0xDEDB;
  Color04.PressColEnabled = 0;
  Color04.Press_Color     = 0xE71C;
  Color04.OnUpPtr         = 0;
  Color04.OnDownPtr       = 0;
  Color04.OnClickPtr      = 0;
  Color04.OnPressPtr      = Color04OnPress;

  Color05.OwnerScreen     = &Paint;
  Color05.Order           = 15;
  Color05.Left            = 254;
  Color05.Top             = 0;
  Color05.Width           = 20;
  Color05.Height          = 54;
  Color05.Pen_Width       = 1;
  Color05.Pen_Color       = 0xFFFF;
  Color05.Visible         = 1;
  Color05.Active          = 1;
  Color05.Transparent     = 1;
  Color05.Gradient        = 0;
  Color05.Gradient_Orientation = 0;
  Color05.Gradient_Start_Color = 0xFFFF;
  Color05.Gradient_End_Color = 0xC618;
  Color05.Color           = 0xFFFF;
  Color05.PressColEnabled = 0;
  Color05.Press_Color     = 0xE71C;
  Color05.OnUpPtr         = 0;
  Color05.OnDownPtr       = 0;
  Color05.OnClickPtr      = 0;
  Color05.OnPressPtr      = Color05OnPress;

  Color06.OwnerScreen     = &Paint;
  Color06.Order           = 16;
  Color06.Left            = 275;
  Color06.Top             = 0;
  Color06.Width           = 20;
  Color06.Height          = 54;
  Color06.Pen_Width       = 1;
  Color06.Pen_Color       = 0xFF5B;
  Color06.Visible         = 1;
  Color06.Active          = 1;
  Color06.Transparent     = 1;
  Color06.Gradient        = 0;
  Color06.Gradient_Orientation = 0;
  Color06.Gradient_Start_Color = 0xFFFF;
  Color06.Gradient_End_Color = 0xC618;
  Color06.Color           = 0xFF5B;
  Color06.PressColEnabled = 0;
  Color06.Press_Color     = 0xE71C;
  Color06.OnUpPtr         = 0;
  Color06.OnDownPtr       = 0;
  Color06.OnClickPtr      = 0;
  Color06.OnPressPtr      = Color06OnPress;

  Color07.OwnerScreen     = &Paint;
  Color07.Order           = 17;
  Color07.Left            = 296;
  Color07.Top             = 0;
  Color07.Width           = 20;
  Color07.Height          = 54;
  Color07.Pen_Width       = 1;
  Color07.Pen_Color       = 0xFE53;
  Color07.Visible         = 1;
  Color07.Active          = 1;
  Color07.Transparent     = 1;
  Color07.Gradient        = 0;
  Color07.Gradient_Orientation = 0;
  Color07.Gradient_Start_Color = 0xFFFF;
  Color07.Gradient_End_Color = 0xC618;
  Color07.Color           = 0xFE53;
  Color07.PressColEnabled = 0;
  Color07.Press_Color     = 0xE71C;
  Color07.OnUpPtr         = 0;
  Color07.OnDownPtr       = 0;
  Color07.OnClickPtr      = 0;
  Color07.OnPressPtr      = Color07OnPress;

  Color08.OwnerScreen     = &Paint;
  Color08.Order           = 18;
  Color08.Left            = 317;
  Color08.Top             = 0;
  Color08.Width           = 20;
  Color08.Height          = 54;
  Color08.Pen_Width       = 1;
  Color08.Pen_Color       = 0x9B26;
  Color08.Visible         = 1;
  Color08.Active          = 1;
  Color08.Transparent     = 1;
  Color08.Gradient        = 0;
  Color08.Gradient_Orientation = 0;
  Color08.Gradient_Start_Color = 0xFFFF;
  Color08.Gradient_End_Color = 0xC618;
  Color08.Color           = 0x9B26;
  Color08.PressColEnabled = 0;
  Color08.Press_Color     = 0xE71C;
  Color08.OnUpPtr         = 0;
  Color08.OnDownPtr       = 0;
  Color08.OnClickPtr      = 0;
  Color08.OnPressPtr      = Color08OnPress;

  Color09.OwnerScreen     = &Paint;
  Color09.Order           = 19;
  Color09.Left            = 338;
  Color09.Top             = 0;
  Color09.Width           = 20;
  Color09.Height          = 54;
  Color09.Pen_Width       = 1;
  Color09.Pen_Color       = 0x61A0;
  Color09.Visible         = 1;
  Color09.Active          = 1;
  Color09.Transparent     = 1;
  Color09.Gradient        = 0;
  Color09.Gradient_Orientation = 0;
  Color09.Gradient_Start_Color = 0xFFFF;
  Color09.Gradient_End_Color = 0xC618;
  Color09.Color           = 0x61A0;
  Color09.PressColEnabled = 0;
  Color09.Press_Color     = 0xE71C;
  Color09.OnUpPtr         = 0;
  Color09.OnDownPtr       = 0;
  Color09.OnClickPtr      = 0;
  Color09.OnPressPtr      = Color09OnPress;

  Color10.OwnerScreen     = &Paint;
  Color10.Order           = 20;
  Color10.Left            = 359;
  Color10.Top             = 0;
  Color10.Width           = 20;
  Color10.Height          = 54;
  Color10.Pen_Width       = 1;
  Color10.Pen_Color       = 0x8800;
  Color10.Visible         = 1;
  Color10.Active          = 1;
  Color10.Transparent     = 1;
  Color10.Gradient        = 0;
  Color10.Gradient_Orientation = 0;
  Color10.Gradient_Start_Color = 0xFFFF;
  Color10.Gradient_End_Color = 0xC618;
  Color10.Color           = 0x8800;
  Color10.PressColEnabled = 0;
  Color10.Press_Color     = 0xE71C;
  Color10.OnUpPtr         = 0;
  Color10.OnDownPtr       = 0;
  Color10.OnClickPtr      = 0;
  Color10.OnPressPtr      = Color10OnPress;

  Color11.OwnerScreen     = &Paint;
  Color11.Order           = 21;
  Color11.Left            = 380;
  Color11.Top             = 0;
  Color11.Width           = 20;
  Color11.Height          = 54;
  Color11.Pen_Width       = 1;
  Color11.Pen_Color       = 0xF800;
  Color11.Visible         = 1;
  Color11.Active          = 1;
  Color11.Transparent     = 1;
  Color11.Gradient        = 0;
  Color11.Gradient_Orientation = 0;
  Color11.Gradient_Start_Color = 0xFFFF;
  Color11.Gradient_End_Color = 0xC618;
  Color11.Color           = 0xF800;
  Color11.PressColEnabled = 0;
  Color11.Press_Color     = 0xE71C;
  Color11.OnUpPtr         = 0;
  Color11.OnDownPtr       = 0;
  Color11.OnClickPtr      = 0;
  Color11.OnPressPtr      = Color11OnPress;

  Color12.OwnerScreen     = &Paint;
  Color12.Order           = 22;
  Color12.Left            = 401;
  Color12.Top             = 0;
  Color12.Width           = 20;
  Color12.Height          = 54;
  Color12.Pen_Width       = 1;
  Color12.Pen_Color       = 0xFB20;
  Color12.Visible         = 1;
  Color12.Active          = 1;
  Color12.Transparent     = 1;
  Color12.Gradient        = 0;
  Color12.Gradient_Orientation = 0;
  Color12.Gradient_Start_Color = 0xFFFF;
  Color12.Gradient_End_Color = 0xC618;
  Color12.Color           = 0xFB20;
  Color12.PressColEnabled = 0;
  Color12.Press_Color     = 0xE71C;
  Color12.OnUpPtr         = 0;
  Color12.OnDownPtr       = 0;
  Color12.OnClickPtr      = 0;
  Color12.OnPressPtr      = Color12OnPress;

  Color13.OwnerScreen     = &Paint;
  Color13.Order           = 23;
  Color13.Left            = 422;
  Color13.Top             = 0;
  Color13.Width           = 20;
  Color13.Height          = 54;
  Color13.Pen_Width       = 1;
  Color13.Pen_Color       = 0xFDC0;
  Color13.Visible         = 1;
  Color13.Active          = 1;
  Color13.Transparent     = 1;
  Color13.Gradient        = 0;
  Color13.Gradient_Orientation = 0;
  Color13.Gradient_Start_Color = 0xFFFF;
  Color13.Gradient_End_Color = 0xC618;
  Color13.Color           = 0xFDC0;
  Color13.PressColEnabled = 0;
  Color13.Press_Color     = 0xE71C;
  Color13.OnUpPtr         = 0;
  Color13.OnDownPtr       = 0;
  Color13.OnClickPtr      = 0;
  Color13.OnPressPtr      = Color13OnPress;

  Color14.OwnerScreen     = &Paint;
  Color14.Order           = 24;
  Color14.Left            = 443;
  Color14.Top             = 0;
  Color14.Width           = 20;
  Color14.Height          = 54;
  Color14.Pen_Width       = 1;
  Color14.Pen_Color       = 0xFEA4;
  Color14.Visible         = 1;
  Color14.Active          = 1;
  Color14.Transparent     = 1;
  Color14.Gradient        = 0;
  Color14.Gradient_Orientation = 0;
  Color14.Gradient_Start_Color = 0xFFFF;
  Color14.Gradient_End_Color = 0xC618;
  Color14.Color           = 0xFEA4;
  Color14.PressColEnabled = 0;
  Color14.Press_Color     = 0xE71C;
  Color14.OnUpPtr         = 0;
  Color14.OnDownPtr       = 0;
  Color14.OnClickPtr      = 0;
  Color14.OnPressPtr      = Color14OnPress;

  Color15.OwnerScreen     = &Paint;
  Color15.Order           = 25;
  Color15.Left            = 464;
  Color15.Top             = 0;
  Color15.Width           = 20;
  Color15.Height          = 54;
  Color15.Pen_Width       = 1;
  Color15.Pen_Color       = 0xFFE0;
  Color15.Visible         = 1;
  Color15.Active          = 1;
  Color15.Transparent     = 1;
  Color15.Gradient        = 0;
  Color15.Gradient_Orientation = 0;
  Color15.Gradient_Start_Color = 0xFFFF;
  Color15.Gradient_End_Color = 0xC618;
  Color15.Color           = 0xFFE0;
  Color15.PressColEnabled = 0;
  Color15.Press_Color     = 0xE71C;
  Color15.OnUpPtr         = 0;
  Color15.OnDownPtr       = 0;
  Color15.OnClickPtr      = 0;
  Color15.OnPressPtr      = Color15OnPress;

  Color16.OwnerScreen     = &Paint;
  Color16.Order           = 26;
  Color16.Left            = 485;
  Color16.Top             = 0;
  Color16.Width           = 20;
  Color16.Height          = 54;
  Color16.Pen_Width       = 1;
  Color16.Pen_Color       = 0xFFF3;
  Color16.Visible         = 1;
  Color16.Active          = 1;
  Color16.Transparent     = 1;
  Color16.Gradient        = 0;
  Color16.Gradient_Orientation = 0;
  Color16.Gradient_Start_Color = 0xFFFF;
  Color16.Gradient_End_Color = 0xC618;
  Color16.Color           = 0xFFF3;
  Color16.PressColEnabled = 0;
  Color16.Press_Color     = 0xE71C;
  Color16.OnUpPtr         = 0;
  Color16.OnDownPtr       = 0;
  Color16.OnClickPtr      = 0;
  Color16.OnPressPtr      = Color16OnPress;

  Color17.OwnerScreen     = &Paint;
  Color17.Order           = 27;
  Color17.Left            = 506;
  Color17.Top             = 0;
  Color17.Width           = 20;
  Color17.Height          = 54;
  Color17.Pen_Width       = 1;
  Color17.Pen_Color       = 0xCFED;
  Color17.Visible         = 1;
  Color17.Active          = 1;
  Color17.Transparent     = 1;
  Color17.Gradient        = 0;
  Color17.Gradient_Orientation = 0;
  Color17.Gradient_Start_Color = 0xFFFF;
  Color17.Gradient_End_Color = 0xC618;
  Color17.Color           = 0xCFED;
  Color17.PressColEnabled = 0;
  Color17.Press_Color     = 0xE71C;
  Color17.OnUpPtr         = 0;
  Color17.OnDownPtr       = 0;
  Color17.OnClickPtr      = 0;
  Color17.OnPressPtr      = Color17OnPress;

  Color18.OwnerScreen     = &Paint;
  Color18.Order           = 28;
  Color18.Left            = 527;
  Color18.Top             = 0;
  Color18.Width           = 20;
  Color18.Height          = 54;
  Color18.Pen_Width       = 1;
  Color18.Pen_Color       = 0x97F3;
  Color18.Visible         = 1;
  Color18.Active          = 1;
  Color18.Transparent     = 1;
  Color18.Gradient        = 0;
  Color18.Gradient_Orientation = 0;
  Color18.Gradient_Start_Color = 0xFFFF;
  Color18.Gradient_End_Color = 0xC618;
  Color18.Color           = 0x97F3;
  Color18.PressColEnabled = 0;
  Color18.Press_Color     = 0xE71C;
  Color18.OnUpPtr         = 0;
  Color18.OnDownPtr       = 0;
  Color18.OnClickPtr      = 0;
  Color18.OnPressPtr      = Color18OnPress;

  Color19.OwnerScreen     = &Paint;
  Color19.Order           = 29;
  Color19.Left            = 548;
  Color19.Top             = 0;
  Color19.Width           = 20;
  Color19.Height          = 54;
  Color19.Pen_Width       = 1;
  Color19.Pen_Color       = 0x0E21;
  Color19.Visible         = 1;
  Color19.Active          = 1;
  Color19.Transparent     = 1;
  Color19.Gradient        = 0;
  Color19.Gradient_Orientation = 0;
  Color19.Gradient_Start_Color = 0xFFFF;
  Color19.Gradient_End_Color = 0xC618;
  Color19.Color           = 0x0E21;
  Color19.PressColEnabled = 0;
  Color19.Press_Color     = 0xE71C;
  Color19.OnUpPtr         = 0;
  Color19.OnDownPtr       = 0;
  Color19.OnClickPtr      = 0;
  Color19.OnPressPtr      = Color19OnPress;

  Color20.OwnerScreen     = &Paint;
  Color20.Order           = 30;
  Color20.Left            = 569;
  Color20.Top             = 0;
  Color20.Width           = 20;
  Color20.Height          = 54;
  Color20.Pen_Width       = 1;
  Color20.Pen_Color       = 0x0400;
  Color20.Visible         = 1;
  Color20.Active          = 1;
  Color20.Transparent     = 1;
  Color20.Gradient        = 0;
  Color20.Gradient_Orientation = 0;
  Color20.Gradient_Start_Color = 0xFFFF;
  Color20.Gradient_End_Color = 0xC618;
  Color20.Color           = 0x0400;
  Color20.PressColEnabled = 0;
  Color20.Press_Color     = 0xE71C;
  Color20.OnUpPtr         = 0;
  Color20.OnDownPtr       = 0;
  Color20.OnClickPtr      = 0;
  Color20.OnPressPtr      = Color20OnPress;

  Color21.OwnerScreen     = &Paint;
  Color21.Order           = 31;
  Color21.Left            = 590;
  Color21.Top             = 0;
  Color21.Width           = 20;
  Color21.Height          = 54;
  Color21.Pen_Width       = 1;
  Color21.Pen_Color       = 0x2CEB;
  Color21.Visible         = 1;
  Color21.Active          = 1;
  Color21.Transparent     = 1;
  Color21.Gradient        = 0;
  Color21.Gradient_Orientation = 0;
  Color21.Gradient_Start_Color = 0xFFFF;
  Color21.Gradient_End_Color = 0xC618;
  Color21.Color           = 0x2CEB;
  Color21.PressColEnabled = 0;
  Color21.Press_Color     = 0xE71C;
  Color21.OnUpPtr         = 0;
  Color21.OnDownPtr       = 0;
  Color21.OnClickPtr      = 0;
  Color21.OnPressPtr      = Color21OnPress;

  Color22.OwnerScreen     = &Paint;
  Color22.Order           = 32;
  Color22.Left            = 611;
  Color22.Top             = 0;
  Color22.Width           = 20;
  Color22.Height          = 54;
  Color22.Pen_Width       = 1;
  Color22.Pen_Color       = 0x059E;
  Color22.Visible         = 1;
  Color22.Active          = 1;
  Color22.Transparent     = 1;
  Color22.Gradient        = 0;
  Color22.Gradient_Orientation = 0;
  Color22.Gradient_Start_Color = 0xFFFF;
  Color22.Gradient_End_Color = 0xC618;
  Color22.Color           = 0x059E;
  Color22.PressColEnabled = 0;
  Color22.Press_Color     = 0xE71C;
  Color22.OnUpPtr         = 0;
  Color22.OnDownPtr       = 0;
  Color22.OnClickPtr      = 0;
  Color22.OnPressPtr      = Color22OnPress;

  Color23.OwnerScreen     = &Paint;
  Color23.Order           = 33;
  Color23.Left            = 632;
  Color23.Top             = 0;
  Color23.Width           = 20;
  Color23.Height          = 54;
  Color23.Pen_Width       = 1;
  Color23.Pen_Color       = 0x001F;
  Color23.Visible         = 1;
  Color23.Active          = 1;
  Color23.Transparent     = 1;
  Color23.Gradient        = 0;
  Color23.Gradient_Orientation = 0;
  Color23.Gradient_Start_Color = 0xFFFF;
  Color23.Gradient_End_Color = 0xC618;
  Color23.Color           = 0x001F;
  Color23.PressColEnabled = 0;
  Color23.Press_Color     = 0xE71C;
  Color23.OnUpPtr         = 0;
  Color23.OnDownPtr       = 0;
  Color23.OnClickPtr      = 0;
  Color23.OnPressPtr      = Color23OnPress;

  Color24.OwnerScreen     = &Paint;
  Color24.Order           = 34;
  Color24.Left            = 653;
  Color24.Top             = 0;
  Color24.Width           = 20;
  Color24.Height          = 54;
  Color24.Pen_Width       = 1;
  Color24.Pen_Color       = 0x0013;
  Color24.Visible         = 1;
  Color24.Active          = 1;
  Color24.Transparent     = 1;
  Color24.Gradient        = 0;
  Color24.Gradient_Orientation = 0;
  Color24.Gradient_Start_Color = 0xFFFF;
  Color24.Gradient_End_Color = 0xC618;
  Color24.Color           = 0x0013;
  Color24.PressColEnabled = 0;
  Color24.Press_Color     = 0xE71C;
  Color24.OnUpPtr         = 0;
  Color24.OnDownPtr       = 0;
  Color24.OnClickPtr      = 0;
  Color24.OnPressPtr      = Color24OnPress;

  Color25.OwnerScreen     = &Paint;
  Color25.Order           = 35;
  Color25.Left            = 674;
  Color25.Top             = 0;
  Color25.Width           = 20;
  Color25.Height          = 54;
  Color25.Pen_Width       = 1;
  Color25.Pen_Color       = 0x5013;
  Color25.Visible         = 1;
  Color25.Active          = 1;
  Color25.Transparent     = 1;
  Color25.Gradient        = 0;
  Color25.Gradient_Orientation = 0;
  Color25.Gradient_Start_Color = 0xFFFF;
  Color25.Gradient_End_Color = 0xC618;
  Color25.Color           = 0x5013;
  Color25.PressColEnabled = 0;
  Color25.Press_Color     = 0xE71C;
  Color25.OnUpPtr         = 0;
  Color25.OnDownPtr       = 0;
  Color25.OnClickPtr      = 0;
  Color25.OnPressPtr      = Color25OnPress;

  Color26.OwnerScreen     = &Paint;
  Color26.Order           = 36;
  Color26.Left            = 695;
  Color26.Top             = 0;
  Color26.Width           = 20;
  Color26.Height          = 54;
  Color26.Pen_Width       = 1;
  Color26.Pen_Color       = 0x7194;
  Color26.Visible         = 1;
  Color26.Active          = 1;
  Color26.Transparent     = 1;
  Color26.Gradient        = 0;
  Color26.Gradient_Orientation = 0;
  Color26.Gradient_Start_Color = 0xFFFF;
  Color26.Gradient_End_Color = 0xC618;
  Color26.Color           = 0x7194;
  Color26.PressColEnabled = 0;
  Color26.Press_Color     = 0xE71C;
  Color26.OnUpPtr         = 0;
  Color26.OnDownPtr       = 0;
  Color26.OnClickPtr      = 0;
  Color26.OnPressPtr      = Color26OnPress;

  Color27.OwnerScreen     = &Paint;
  Color27.Order           = 37;
  Color27.Left            = 716;
  Color27.Top             = 0;
  Color27.Width           = 20;
  Color27.Height          = 54;
  Color27.Pen_Width       = 1;
  Color27.Pen_Color       = 0x935F;
  Color27.Visible         = 1;
  Color27.Active          = 1;
  Color27.Transparent     = 1;
  Color27.Gradient        = 0;
  Color27.Gradient_Orientation = 0;
  Color27.Gradient_Start_Color = 0xFFFF;
  Color27.Gradient_End_Color = 0xC618;
  Color27.Color           = 0x935F;
  Color27.PressColEnabled = 0;
  Color27.Press_Color     = 0xE71C;
  Color27.OnUpPtr         = 0;
  Color27.OnDownPtr       = 0;
  Color27.OnClickPtr      = 0;
  Color27.OnPressPtr      = Color27OnPress;

  Color28.OwnerScreen     = &Paint;
  Color28.Order           = 38;
  Color28.Left            = 737;
  Color28.Top             = 0;
  Color28.Width           = 20;
  Color28.Height          = 54;
  Color28.Pen_Width       = 1;
  Color28.Pen_Color       = 0xFCDF;
  Color28.Visible         = 1;
  Color28.Active          = 1;
  Color28.Transparent     = 1;
  Color28.Gradient        = 0;
  Color28.Gradient_Orientation = 0;
  Color28.Gradient_Start_Color = 0xFFFF;
  Color28.Gradient_End_Color = 0xC618;
  Color28.Color           = 0xFCDF;
  Color28.PressColEnabled = 0;
  Color28.Press_Color     = 0xE71C;
  Color28.OnUpPtr         = 0;
  Color28.OnDownPtr       = 0;
  Color28.OnClickPtr      = 0;
  Color28.OnPressPtr      = Color28OnPress;

  Color29.OwnerScreen     = &Paint;
  Color29.Order           = 39;
  Color29.Left            = 758;
  Color29.Top             = 0;
  Color29.Width           = 20;
  Color29.Height          = 54;
  Color29.Pen_Width       = 1;
  Color29.Pen_Color       = 0xF992;
  Color29.Visible         = 1;
  Color29.Active          = 1;
  Color29.Transparent     = 1;
  Color29.Gradient        = 0;
  Color29.Gradient_Orientation = 0;
  Color29.Gradient_Start_Color = 0xFFFF;
  Color29.Gradient_End_Color = 0xC618;
  Color29.Color           = 0xF992;
  Color29.PressColEnabled = 0;
  Color29.Press_Color     = 0xE71C;
  Color29.OnUpPtr         = 0;
  Color29.OnDownPtr       = 0;
  Color29.OnClickPtr      = 0;
  Color29.OnPressPtr      = Color29OnPress;

  Color30.OwnerScreen     = &Paint;
  Color30.Order           = 40;
  Color30.Left            = 779;
  Color30.Top             = 0;
  Color30.Width           = 20;
  Color30.Height          = 54;
  Color30.Pen_Width       = 1;
  Color30.Pen_Color       = 0xC813;
  Color30.Visible         = 1;
  Color30.Active          = 1;
  Color30.Transparent     = 1;
  Color30.Gradient        = 0;
  Color30.Gradient_Orientation = 0;
  Color30.Gradient_Start_Color = 0xFFFF;
  Color30.Gradient_End_Color = 0xC618;
  Color30.Color           = 0xC813;
  Color30.PressColEnabled = 0;
  Color30.Press_Color     = 0xE71C;
  Color30.OnUpPtr         = 0;
  Color30.OnDownPtr       = 0;
  Color30.OnClickPtr      = 0;
  Color30.OnPressPtr      = Color30OnPress;

  BackGroundColor.OwnerScreen     = &Paint;
  BackGroundColor.Order           = 41;
  BackGroundColor.Left            = 0;
  BackGroundColor.Top             = 292;
  BackGroundColor.Width           = 53;
  BackGroundColor.Height          = 53;
  BackGroundColor.Picture_Type    = 0;
  BackGroundColor.Picture_Ratio   = 1;
  BackGroundColor.Picture_Name    = icon_fill_back_bmp;
  BackGroundColor.Visible         = 1;
  BackGroundColor.Active          = 1;
  BackGroundColor.OnUpPtr         = 0;
  BackGroundColor.OnDownPtr       = 0;
  BackGroundColor.OnClickPtr      = 0;
  BackGroundColor.OnPressPtr      = BackGroundColorOnPress;

  Pen1.OwnerScreen     = &Paint;
  Pen1.Order           = 42;
  Pen1.Left            = 10;
  Pen1.Top             = 373;
  Pen1.Width           = 31;
  Pen1.Height          = 8;
  Pen1.Pen_Width       = 1;
  Pen1.Pen_Color       = 0xFFFF;
  Pen1.Visible         = 1;
  Pen1.Active          = 1;
  Pen1.Transparent     = 1;
  Pen1.Gradient        = 0;
  Pen1.Gradient_Orientation = 0;
  Pen1.Gradient_Start_Color = 0xFFFF;
  Pen1.Gradient_End_Color = 0xC618;
  Pen1.Color           = 0xFFFF;
  Pen1.PressColEnabled = 0;
  Pen1.Press_Color     = 0xE71C;
  Pen1.OnUpPtr         = 0;
  Pen1.OnDownPtr       = 0;
  Pen1.OnClickPtr      = 0;
  Pen1.OnPressPtr      = Pen1OnPress;

  Pen2.OwnerScreen     = &Paint;
  Pen2.Order           = 43;
  Pen2.Left            = 10;
  Pen2.Top             = 403;
  Pen2.Width           = 31;
  Pen2.Height          = 10;
  Pen2.Pen_Width       = 1;
  Pen2.Pen_Color       = 0xFFFF;
  Pen2.Visible         = 1;
  Pen2.Active          = 1;
  Pen2.Transparent     = 1;
  Pen2.Gradient        = 0;
  Pen2.Gradient_Orientation = 0;
  Pen2.Gradient_Start_Color = 0xFFFF;
  Pen2.Gradient_End_Color = 0xC618;
  Pen2.Color           = 0xFFFF;
  Pen2.PressColEnabled = 0;
  Pen2.Press_Color     = 0xE71C;
  Pen2.OnUpPtr         = 0;
  Pen2.OnDownPtr       = 0;
  Pen2.OnClickPtr      = 0;
  Pen2.OnPressPtr      = Pen2OnPress;

  Pen3.OwnerScreen     = &Paint;
  Pen3.Order           = 44;
  Pen3.Left            = 10;
  Pen3.Top             = 436;
  Pen3.Width           = 31;
  Pen3.Height          = 14;
  Pen3.Pen_Width       = 1;
  Pen3.Pen_Color       = 0xFFFF;
  Pen3.Visible         = 1;
  Pen3.Active          = 1;
  Pen3.Transparent     = 1;
  Pen3.Gradient        = 0;
  Pen3.Gradient_Orientation = 0;
  Pen3.Gradient_Start_Color = 0xFFFF;
  Pen3.Gradient_End_Color = 0xC618;
  Pen3.Color           = 0xFFFF;
  Pen3.PressColEnabled = 0;
  Pen3.Press_Color     = 0xE71C;
  Pen3.OnUpPtr         = 0;
  Pen3.OnDownPtr       = 0;
  Pen3.OnClickPtr      = 0;
  Pen3.OnPressPtr      = Pen3OnPress;

  Box7.OwnerScreen     = &SlideShow;
  Box7.Order           = 0;
  Box7.Left            = 2;
  Box7.Top             = 3;
  Box7.Width           = 195;
  Box7.Height          = 47;
  Box7.Pen_Width       = 1;
  Box7.Pen_Color       = 0x0000;
  Box7.Visible         = 0;
  Box7.Active          = 1;
  Box7.Transparent     = 1;
  Box7.Gradient        = 0;
  Box7.Gradient_Orientation = 0;
  Box7.Gradient_Start_Color = 0xFFFF;
  Box7.Gradient_End_Color = 0xC618;
  Box7.Color           = 0xC618;
  Box7.PressColEnabled = 0;
  Box7.Press_Color     = 0xE71C;
  Box7.OnUpPtr         = 0;
  Box7.OnDownPtr       = Box7OnDown;
  Box7.OnClickPtr      = 0;
  Box7.OnPressPtr      = 0;

  icon_previous_box.OwnerScreen     = &SlideShow;
  icon_previous_box.Order           = 1;
  icon_previous_box.Left            = 410;
  icon_previous_box.Top             = 420;
  icon_previous_box.Width           = 61;
  icon_previous_box.Height          = 55;
  icon_previous_box.Pen_Width       = 1;
  icon_previous_box.Pen_Color       = 0x0000;
  icon_previous_box.Visible         = 0;
  icon_previous_box.Active          = 1;
  icon_previous_box.Transparent     = 1;
  icon_previous_box.Gradient        = 0;
  icon_previous_box.Gradient_Orientation = 0;
  icon_previous_box.Gradient_Start_Color = 0xFFFF;
  icon_previous_box.Gradient_End_Color = 0xC618;
  icon_previous_box.Color           = 0xC618;
  icon_previous_box.PressColEnabled = 0;
  icon_previous_box.Press_Color     = 0xE71C;
  icon_previous_box.OnUpPtr         = 0;
  icon_previous_box.OnDownPtr       = 0;
  icon_previous_box.OnClickPtr      = 0;
  icon_previous_box.OnPressPtr      = icon_previous_boxOnPress;

  Icon_next_box.OwnerScreen     = &SlideShow;
  Icon_next_box.Order           = 2;
  Icon_next_box.Left            = 332;
  Icon_next_box.Top             = 419;
  Icon_next_box.Width           = 67;
  Icon_next_box.Height          = 56;
  Icon_next_box.Pen_Width       = 1;
  Icon_next_box.Pen_Color       = 0x0000;
  Icon_next_box.Visible         = 0;
  Icon_next_box.Active          = 1;
  Icon_next_box.Transparent     = 1;
  Icon_next_box.Gradient        = 0;
  Icon_next_box.Gradient_Orientation = 0;
  Icon_next_box.Gradient_Start_Color = 0xFFFF;
  Icon_next_box.Gradient_End_Color = 0xC618;
  Icon_next_box.Color           = 0xC618;
  Icon_next_box.PressColEnabled = 0;
  Icon_next_box.Press_Color     = 0xE71C;
  Icon_next_box.OnUpPtr         = 0;
  Icon_next_box.OnDownPtr       = 0;
  Icon_next_box.OnClickPtr      = 0;
  Icon_next_box.OnPressPtr      = Icon_next_boxOnPress;

  Label31.OwnerScreen     = &SlideShow;
  Label31.Order           = 3;
  Label31.Left            = 58;
  Label31.Top             = 11;
  Label31.Width           = 135;
  Label31.Height          = 40;
  Label31.Visible         = 1;
  Label31.Active          = 0;
  Label31.Caption         = Label31_Caption;
  Label31.FontName        = Open_Sans_Light24x37_Regular;
  Label31.Font_Color      = 0xFFFF;
  Label31.OnUpPtr         = 0;
  Label31.OnDownPtr       = 0;
  Label31.OnClickPtr      = 0;
  Label31.OnPressPtr      = 0;

  back_slide_show.OwnerScreen     = &SlideShow;
  back_slide_show.Order           = 4;
  back_slide_show.Left            = 13;
  back_slide_show.Top             = 13;
  back_slide_show.Width           = 36;
  back_slide_show.Height          = 39;
  back_slide_show.Picture_Type    = 0;
  back_slide_show.Picture_Ratio   = 1;
  back_slide_show.Picture_Name    = icon_back_slideshow_bmp;
  back_slide_show.Visible         = 1;
  back_slide_show.Active          = 0;
  back_slide_show.OnUpPtr         = 0;
  back_slide_show.OnDownPtr       = 0;
  back_slide_show.OnClickPtr      = 0;
  back_slide_show.OnPressPtr      = 0;

  Label32.OwnerScreen     = &SlideShow;
  Label32.Order           = 5;
  Label32.Left            = 20;
  Label32.Top             = 440;
  Label32.Width           = 159;
  Label32.Height          = 36;
  Label32.Visible         = 1;
  Label32.Active          = 1;
  Label32.Caption         = Label32_Caption;
  Label32.FontName        = Open_Sans_Light21x33_Regular;
  Label32.Font_Color      = 0xFFFF;
  Label32.OnUpPtr         = 0;
  Label32.OnDownPtr       = 0;
  Label32.OnClickPtr      = 0;
  Label32.OnPressPtr      = 0;

  Label33.OwnerScreen     = &SlideShow;
  Label33.Order           = 6;
  Label33.Left            = 720;
  Label33.Top             = 440;
  Label33.Width           = 42;
  Label33.Height          = 36;
  Label33.Visible         = 1;
  Label33.Active          = 1;
  Label33.Caption         = Label33_Caption;
  Label33.FontName        = Open_Sans_Light21x33_Regular;
  Label33.Font_Color      = 0xFFFF;
  Label33.OnUpPtr         = 0;
  Label33.OnDownPtr       = 0;
  Label33.OnClickPtr      = 0;
  Label33.OnPressPtr      = 0;

  icon_previous.OwnerScreen     = &SlideShow;
  icon_previous.Order           = 7;
  icon_previous.Left            = 412;
  icon_previous.Top             = 445;
  icon_previous.Width           = 32;
  icon_previous.Height          = 28;
  icon_previous.Picture_Type    = 0;
  icon_previous.Picture_Ratio   = 1;
  icon_previous.Picture_Name    = icon_up_slideshow_bmp;
  icon_previous.Visible         = 1;
  icon_previous.Active          = 0;
  icon_previous.OnUpPtr         = 0;
  icon_previous.OnDownPtr       = 0;
  icon_previous.OnClickPtr      = 0;
  icon_previous.OnPressPtr      = 0;

  Icon_next.OwnerScreen     = &SlideShow;
  Icon_next.Order           = 8;
  Icon_next.Left            = 363;
  Icon_next.Top             = 445;
  Icon_next.Width           = 32;
  Icon_next.Height          = 28;
  Icon_next.Picture_Type    = 0;
  Icon_next.Picture_Ratio   = 1;
  Icon_next.Picture_Name    = icon_down_slideshow_bmp;
  Icon_next.Visible         = 1;
  Icon_next.Active          = 0;
  Icon_next.OnUpPtr         = 0;
  Icon_next.OnDownPtr       = 0;
  Icon_next.OnClickPtr      = 0;
  Icon_next.OnPressPtr      = 0;

  Label35.OwnerScreen     = &SlideShow;
  Label35.Order           = 9;
  Label35.Left            = 690;
  Label35.Top             = 440;
  Label35.Width           = 50;
  Label35.Height          = 36;
  Label35.Visible         = 1;
  Label35.Active          = 1;
  Label35.Caption         = Label35_Caption;
  Label35.FontName        = Open_Sans_Light21x33_Regular;
  Label35.Font_Color      = 0xFFFF;
  Label35.OnUpPtr         = 0;
  Label35.OnDownPtr       = 0;
  Label35.OnClickPtr      = 0;
  Label35.OnPressPtr      = 0;

  Slide_Active_area.OwnerScreen     = &SlideShow;
  Slide_Active_area.Order           = 10;
  Slide_Active_area.Left            = 0;
  Slide_Active_area.Top             = 62;
  Slide_Active_area.Width           = 800;
  Slide_Active_area.Height          = 376;
  Slide_Active_area.Pen_Width       = 1;
  Slide_Active_area.Pen_Color       = 0x0000;
  Slide_Active_area.Visible         = 0;
  Slide_Active_area.Active          = 1;
  Slide_Active_area.Transparent     = 1;
  Slide_Active_area.Gradient        = 0;
  Slide_Active_area.Gradient_Orientation = 0;
  Slide_Active_area.Gradient_Start_Color = 0xFFFF;
  Slide_Active_area.Gradient_End_Color = 0xC618;
  Slide_Active_area.Color           = 0xC618;
  Slide_Active_area.PressColEnabled = 0;
  Slide_Active_area.Press_Color     = 0xE71C;
  Slide_Active_area.OnUpPtr         = 0;
  Slide_Active_area.OnDownPtr       = 0;
  Slide_Active_area.OnClickPtr      = 0;
  Slide_Active_area.OnPressPtr      = Slide_Active_areaOnPress;

  Box10.OwnerScreen     = &Tic_Tac_Toe;
  Box10.Order           = 0;
  Box10.Left            = 81;
  Box10.Top             = 359;
  Box10.Width           = 161;
  Box10.Height          = 28;
  Box10.Pen_Width       = 1;
  Box10.Pen_Color       = 0x0000;
  Box10.Visible         = 0;
  Box10.Active          = 1;
  Box10.Transparent     = 1;
  Box10.Gradient        = 0;
  Box10.Gradient_Orientation = 0;
  Box10.Gradient_Start_Color = 0xFFFF;
  Box10.Gradient_End_Color = 0xC618;
  Box10.Color           = 0xC618;
  Box10.PressColEnabled = 0;
  Box10.Press_Color     = 0xE71C;
  Box10.OnUpPtr         = 0;
  Box10.OnDownPtr       = 0;
  Box10.OnClickPtr      = Box10OnClick;
  Box10.OnPressPtr      = 0;

  Box11.OwnerScreen     = &Tic_Tac_Toe;
  Box11.Order           = 1;
  Box11.Left            = 50;
  Box11.Top             = 395;
  Box11.Width           = 185;
  Box11.Height          = 30;
  Box11.Pen_Width       = 1;
  Box11.Pen_Color       = 0x0000;
  Box11.Visible         = 0;
  Box11.Active          = 1;
  Box11.Transparent     = 1;
  Box11.Gradient        = 0;
  Box11.Gradient_Orientation = 0;
  Box11.Gradient_Start_Color = 0xFFFF;
  Box11.Gradient_End_Color = 0xC618;
  Box11.Color           = 0xC618;
  Box11.PressColEnabled = 0;
  Box11.Press_Color     = 0xE71C;
  Box11.OnUpPtr         = 0;
  Box11.OnDownPtr       = 0;
  Box11.OnClickPtr      = 0;
  Box11.OnPressPtr      = Box11OnPress;

  Box9.OwnerScreen     = &Tic_Tac_Toe;
  Box9.Order           = 2;
  Box9.Left            = 2;
  Box9.Top             = 2;
  Box9.Width           = 286;
  Box9.Height          = 59;
  Box9.Pen_Width       = 1;
  Box9.Pen_Color       = 0x0000;
  Box9.Visible         = 0;
  Box9.Active          = 1;
  Box9.Transparent     = 1;
  Box9.Gradient        = 0;
  Box9.Gradient_Orientation = 0;
  Box9.Gradient_Start_Color = 0xFFFF;
  Box9.Gradient_End_Color = 0xC618;
  Box9.Color           = 0xC618;
  Box9.PressColEnabled = 0;
  Box9.Press_Color     = 0xE71C;
  Box9.OnUpPtr         = 0;
  Box9.OnDownPtr       = 0;
  Box9.OnClickPtr      = 0;
  Box9.OnPressPtr      = Box9OnPress;

  Button9.OwnerScreen     = &Tic_Tac_Toe;
  Button9.Order           = 3;
  Button9.Left            = 647;
  Button9.Top             = 307;
  Button9.Width           = 106;
  Button9.Height          = 105;
  Button9.Pen_Width       = 1;
  Button9.Pen_Color       = 0x0000;
  Button9.Visible         = 0;
  Button9.Active          = 1;
  Button9.Transparent     = 1;
  Button9.Caption         = Button9_Caption;
  Button9.TextAlign       = _taCenter;
  Button9.FontName        = Furro_Script50x64_Regular;
  Button9.PressColEnabled = 0;
  Button9.Font_Color      = 0x0000;
  Button9.Gradient        = 0;
  Button9.Gradient_Orientation = 0;
  Button9.Gradient_Start_Color = 0xFFFF;
  Button9.Gradient_End_Color = 0xC618;
  Button9.Color           = 0xC618;
  Button9.Press_Color     = 0xE71C;
  Button9.OnUpPtr         = 0;
  Button9.OnDownPtr       = 0;
  Button9.OnClickPtr      = Button9OnClick;
  Button9.OnPressPtr      = 0;

  Button8.OwnerScreen     = &Tic_Tac_Toe;
  Button8.Order           = 4;
  Button8.Left            = 521;
  Button8.Top             = 315;
  Button8.Width           = 106;
  Button8.Height          = 101;
  Button8.Pen_Width       = 1;
  Button8.Pen_Color       = 0x0000;
  Button8.Visible         = 0;
  Button8.Active          = 1;
  Button8.Transparent     = 1;
  Button8.Caption         = Button8_Caption;
  Button8.TextAlign       = _taCenter;
  Button8.FontName        = Furro_Script50x64_Regular;
  Button8.PressColEnabled = 0;
  Button8.Font_Color      = 0x0000;
  Button8.Gradient        = 0;
  Button8.Gradient_Orientation = 0;
  Button8.Gradient_Start_Color = 0xFFFF;
  Button8.Gradient_End_Color = 0xC618;
  Button8.Color           = 0xC618;
  Button8.Press_Color     = 0xE71C;
  Button8.OnUpPtr         = 0;
  Button8.OnDownPtr       = 0;
  Button8.OnClickPtr      = Button8OnClick;
  Button8.OnPressPtr      = 0;

  Button7.OwnerScreen     = &Tic_Tac_Toe;
  Button7.Order           = 5;
  Button7.Left            = 392;
  Button7.Top             = 322;
  Button7.Width           = 114;
  Button7.Height          = 100;
  Button7.Pen_Width       = 1;
  Button7.Pen_Color       = 0x0000;
  Button7.Visible         = 0;
  Button7.Active          = 1;
  Button7.Transparent     = 1;
  Button7.Caption         = Button7_Caption;
  Button7.TextAlign       = _taCenter;
  Button7.FontName        = Furro_Script50x64_Regular;
  Button7.PressColEnabled = 0;
  Button7.Font_Color      = 0x0000;
  Button7.Gradient        = 0;
  Button7.Gradient_Orientation = 0;
  Button7.Gradient_Start_Color = 0xFFFF;
  Button7.Gradient_End_Color = 0xC618;
  Button7.Color           = 0xC618;
  Button7.Press_Color     = 0xE71C;
  Button7.OnUpPtr         = 0;
  Button7.OnDownPtr       = 0;
  Button7.OnClickPtr      = Button7OnClick;
  Button7.OnPressPtr      = 0;

  Button6.OwnerScreen     = &Tic_Tac_Toe;
  Button6.Order           = 6;
  Button6.Left            = 638;
  Button6.Top             = 184;
  Button6.Width           = 107;
  Button6.Height          = 102;
  Button6.Pen_Width       = 1;
  Button6.Pen_Color       = 0x0000;
  Button6.Visible         = 0;
  Button6.Active          = 1;
  Button6.Transparent     = 1;
  Button6.Caption         = Button6_Caption;
  Button6.TextAlign       = _taCenter;
  Button6.FontName        = Furro_Script50x64_Regular;
  Button6.PressColEnabled = 0;
  Button6.Font_Color      = 0x0000;
  Button6.Gradient        = 0;
  Button6.Gradient_Orientation = 0;
  Button6.Gradient_Start_Color = 0xFFFF;
  Button6.Gradient_End_Color = 0xC618;
  Button6.Color           = 0xC618;
  Button6.Press_Color     = 0xE71C;
  Button6.OnUpPtr         = 0;
  Button6.OnDownPtr       = 0;
  Button6.OnClickPtr      = Button6OnClick;
  Button6.OnPressPtr      = 0;

  Button5.OwnerScreen     = &Tic_Tac_Toe;
  Button5.Order           = 7;
  Button5.Left            = 512;
  Button5.Top             = 190;
  Button5.Width           = 106;
  Button5.Height          = 104;
  Button5.Pen_Width       = 1;
  Button5.Pen_Color       = 0x0000;
  Button5.Visible         = 0;
  Button5.Active          = 1;
  Button5.Transparent     = 1;
  Button5.Caption         = Button5_Caption;
  Button5.TextAlign       = _taCenter;
  Button5.FontName        = Furro_Script50x64_Regular;
  Button5.PressColEnabled = 0;
  Button5.Font_Color      = 0x0000;
  Button5.Gradient        = 0;
  Button5.Gradient_Orientation = 0;
  Button5.Gradient_Start_Color = 0xFFFF;
  Button5.Gradient_End_Color = 0xC618;
  Button5.Color           = 0xC618;
  Button5.Press_Color     = 0xE71C;
  Button5.OnUpPtr         = 0;
  Button5.OnDownPtr       = 0;
  Button5.OnClickPtr      = Button5OnClick;
  Button5.OnPressPtr      = 0;

  Button4.OwnerScreen     = &Tic_Tac_Toe;
  Button4.Order           = 8;
  Button4.Left            = 385;
  Button4.Top             = 200;
  Button4.Width           = 114;
  Button4.Height          = 99;
  Button4.Pen_Width       = 1;
  Button4.Pen_Color       = 0x0000;
  Button4.Visible         = 0;
  Button4.Active          = 1;
  Button4.Transparent     = 1;
  Button4.Caption         = Button4_Caption;
  Button4.TextAlign       = _taCenter;
  Button4.FontName        = Furro_Script50x64_Regular;
  Button4.PressColEnabled = 0;
  Button4.Font_Color      = 0x0000;
  Button4.Gradient        = 0;
  Button4.Gradient_Orientation = 0;
  Button4.Gradient_Start_Color = 0xFFFF;
  Button4.Gradient_End_Color = 0xC618;
  Button4.Color           = 0xC618;
  Button4.Press_Color     = 0xE71C;
  Button4.OnUpPtr         = 0;
  Button4.OnDownPtr       = 0;
  Button4.OnClickPtr      = Button4OnClick;
  Button4.OnPressPtr      = 0;

  Button3.OwnerScreen     = &Tic_Tac_Toe;
  Button3.Order           = 9;
  Button3.Left            = 628;
  Button3.Top             = 59;
  Button3.Width           = 111;
  Button3.Height          = 106;
  Button3.Pen_Width       = 1;
  Button3.Pen_Color       = 0x0000;
  Button3.Visible         = 0;
  Button3.Active          = 1;
  Button3.Transparent     = 1;
  Button3.Caption         = Button3_Caption;
  Button3.TextAlign       = _taCenter;
  Button3.FontName        = Furro_Script50x64_Regular;
  Button3.PressColEnabled = 0;
  Button3.Font_Color      = 0x0000;
  Button3.Gradient        = 0;
  Button3.Gradient_Orientation = 0;
  Button3.Gradient_Start_Color = 0xFFFF;
  Button3.Gradient_End_Color = 0xC618;
  Button3.Color           = 0xC618;
  Button3.Press_Color     = 0xE71C;
  Button3.OnUpPtr         = 0;
  Button3.OnDownPtr       = 0;
  Button3.OnClickPtr      = Button3OnClick;
  Button3.OnPressPtr      = 0;

  Button2.OwnerScreen     = &Tic_Tac_Toe;
  Button2.Order           = 10;
  Button2.Left            = 507;
  Button2.Top             = 71;
  Button2.Width           = 108;
  Button2.Height          = 100;
  Button2.Pen_Width       = 1;
  Button2.Pen_Color       = 0x0000;
  Button2.Visible         = 0;
  Button2.Active          = 1;
  Button2.Transparent     = 1;
  Button2.Caption         = Button2_Caption;
  Button2.TextAlign       = _taCenter;
  Button2.FontName        = Furro_Script50x64_Regular;
  Button2.PressColEnabled = 0;
  Button2.Font_Color      = 0x0000;
  Button2.Gradient        = 0;
  Button2.Gradient_Orientation = 0;
  Button2.Gradient_Start_Color = 0xFFFF;
  Button2.Gradient_End_Color = 0xC618;
  Button2.Color           = 0xC618;
  Button2.Press_Color     = 0xE71C;
  Button2.OnUpPtr         = 0;
  Button2.OnDownPtr       = 0;
  Button2.OnClickPtr      = Button2OnClick;
  Button2.OnPressPtr      = 0;

  Button1.OwnerScreen     = &Tic_Tac_Toe;
  Button1.Order           = 11;
  Button1.Left            = 379;
  Button1.Top             = 72;
  Button1.Width           = 111;
  Button1.Height          = 102;
  Button1.Pen_Width       = 1;
  Button1.Pen_Color       = 0x0000;
  Button1.Visible         = 0;
  Button1.Active          = 1;
  Button1.Transparent     = 1;
  Button1.Caption         = Button1_Caption;
  Button1.TextAlign       = _taCenter;
  Button1.FontName        = Furro_Script50x64_Regular;
  Button1.PressColEnabled = 0;
  Button1.Font_Color      = 0x0000;
  Button1.Gradient        = 0;
  Button1.Gradient_Orientation = 0;
  Button1.Gradient_Start_Color = 0xFFFF;
  Button1.Gradient_End_Color = 0xC618;
  Button1.Color           = 0xC618;
  Button1.Press_Color     = 0xE71C;
  Button1.OnUpPtr         = 0;
  Button1.OnDownPtr       = 0;
  Button1.OnClickPtr      = Button1OnClick;
  Button1.OnPressPtr      = 0;

  Box8.OwnerScreen     = &Tic_Tac_Toe;
  Box8.Order           = 12;
  Box8.Left            = 52;
  Box8.Top             = 154;
  Box8.Width           = 221;
  Box8.Height          = 170;
  Box8.Pen_Width       = 0;
  Box8.Pen_Color       = 0x0000;
  Box8.Visible         = 1;
  Box8.Active          = 0;
  Box8.Transparent     = 1;
  Box8.Gradient        = 0;
  Box8.Gradient_Orientation = 0;
  Box8.Gradient_Start_Color = 0xFFFF;
  Box8.Gradient_End_Color = 0xC618;
  Box8.Color           = 0x796C;
  Box8.PressColEnabled = 1;
  Box8.Press_Color     = 0xE71C;
  Box8.OnUpPtr         = 0;
  Box8.OnDownPtr       = 0;
  Box8.OnClickPtr      = 0;
  Box8.OnPressPtr      = 0;

  Label36.OwnerScreen     = &Tic_Tac_Toe;
  Label36.Order           = 13;
  Label36.Left            = 53;
  Label36.Top             = 22;
  Label36.Width           = 222;
  Label36.Height          = 40;
  Label36.Visible         = 1;
  Label36.Active          = 0;
  Label36.Caption         = Label36_Caption;
  Label36.FontName        = Open_Sans_Light24x37_Regular;
  Label36.Font_Color      = 0xFFFF;
  Label36.OnUpPtr         = 0;
  Label36.OnDownPtr       = 0;
  Label36.OnClickPtr      = 0;
  Label36.OnPressPtr      = 0;

  Image20.OwnerScreen     = &Tic_Tac_Toe;
  Image20.Order           = 14;
  Image20.Left            = 8;
  Image20.Top             = 22;
  Image20.Width           = 37;
  Image20.Height          = 36;
  Image20.Picture_Type    = 0;
  Image20.Picture_Ratio   = 1;
  Image20.Picture_Name    = icon_back_tic_tac_toe_bmp;
  Image20.Visible         = 1;
  Image20.Active          = 0;
  Image20.OnUpPtr         = 0;
  Image20.OnDownPtr       = 0;
  Image20.OnClickPtr      = 0;
  Image20.OnPressPtr      = 0;

  Label37.OwnerScreen     = &Tic_Tac_Toe;
  Label37.Order           = 15;
  Label37.Left            = 84;
  Label37.Top             = 391;
  Label37.Width           = 137;
  Label37.Height          = 40;
  Label37.Visible         = 1;
  Label37.Active          = 0;
  Label37.Caption         = Label37_Caption;
  Label37.FontName        = Open_Sans_Light24x37_Regular;
  Label37.Font_Color      = 0xFFFF;
  Label37.OnUpPtr         = 0;
  Label37.OnDownPtr       = 0;
  Label37.OnClickPtr      = 0;
  Label37.OnPressPtr      = 0;

  Image21.OwnerScreen     = &Tic_Tac_Toe;
  Image21.Order           = 16;
  Image21.Left            = 50;
  Image21.Top             = 395;
  Image21.Width           = 29;
  Image21.Height          = 28;
  Image21.Picture_Type    = 0;
  Image21.Picture_Ratio   = 1;
  Image21.Picture_Name    = icon_new_game_tic_tac_toe_bmp;
  Image21.Visible         = 1;
  Image21.Active          = 0;
  Image21.OnUpPtr         = 0;
  Image21.OnDownPtr       = 0;
  Image21.OnClickPtr      = 0;
  Image21.OnPressPtr      = 0;

  Label38.OwnerScreen     = &Tic_Tac_Toe;
  Label38.Order           = 17;
  Label38.Left            = 65;
  Label38.Top             = 186;
  Label38.Width           = 17;
  Label38.Height          = 80;
  Label38.Visible         = 1;
  Label38.Active          = 1;
  Label38.Caption         = Label38_Caption;
  Label38.FontName        = Furro_Script63x80_Regular;
  Label38.Font_Color      = 0x25A4;
  Label38.OnUpPtr         = 0;
  Label38.OnDownPtr       = 0;
  Label38.OnClickPtr      = 0;
  Label38.OnPressPtr      = 0;

  Label39.OwnerScreen     = &Tic_Tac_Toe;
  Label39.Order           = 18;
  Label39.Left            = 85;
  Label39.Top             = 283;
  Label39.Width           = 129;
  Label39.Height          = 36;
  Label39.Visible         = 1;
  Label39.Active          = 1;
  Label39.Caption         = Label39_Caption;
  Label39.FontName        = Open_Sans_Light21x33_Regular;
  Label39.Font_Color      = 0xFFFF;
  Label39.OnUpPtr         = 0;
  Label39.OnDownPtr       = 0;
  Label39.OnClickPtr      = 0;
  Label39.OnPressPtr      = 0;

  XO1.OwnerScreen     = &Tic_Tac_Toe;
  XO1.Order           = 19;
  XO1.Left            = 401;
  XO1.Top             = 90;
  XO1.Width           = 20;
  XO1.Height          = 96;
  XO1.Visible         = 1;
  XO1.Active          = 1;
  XO1.Caption         = XO1_Caption;
  XO1.FontName        = Furro_Script75x96_Regular;
  XO1.Font_Color      = 0x25A4;
  XO1.OnUpPtr         = 0;
  XO1.OnDownPtr       = 0;
  XO1.OnClickPtr      = 0;
  XO1.OnPressPtr      = 0;

  XO2.OwnerScreen     = &Tic_Tac_Toe;
  XO2.Order           = 20;
  XO2.Left            = 522;
  XO2.Top             = 83;
  XO2.Width           = 20;
  XO2.Height          = 96;
  XO2.Visible         = 1;
  XO2.Active          = 1;
  XO2.Caption         = XO2_Caption;
  XO2.FontName        = Furro_Script75x96_Regular;
  XO2.Font_Color      = 0x25A4;
  XO2.OnUpPtr         = 0;
  XO2.OnDownPtr       = 0;
  XO2.OnClickPtr      = 0;
  XO2.OnPressPtr      = 0;

  XO3.OwnerScreen     = &Tic_Tac_Toe;
  XO3.Order           = 21;
  XO3.Left            = 650;
  XO3.Top             = 77;
  XO3.Width           = 20;
  XO3.Height          = 96;
  XO3.Visible         = 1;
  XO3.Active          = 1;
  XO3.Caption         = XO3_Caption;
  XO3.FontName        = Furro_Script75x96_Regular;
  XO3.Font_Color      = 0x25A4;
  XO3.OnUpPtr         = 0;
  XO3.OnDownPtr       = 0;
  XO3.OnClickPtr      = 0;
  XO3.OnPressPtr      = 0;

  XO4.OwnerScreen     = &Tic_Tac_Toe;
  XO4.Order           = 22;
  XO4.Left            = 407;
  XO4.Top             = 214;
  XO4.Width           = 20;
  XO4.Height          = 96;
  XO4.Visible         = 1;
  XO4.Active          = 1;
  XO4.Caption         = XO4_Caption;
  XO4.FontName        = Furro_Script75x96_Regular;
  XO4.Font_Color      = 0x25A4;
  XO4.OnUpPtr         = 0;
  XO4.OnDownPtr       = 0;
  XO4.OnClickPtr      = 0;
  XO4.OnPressPtr      = 0;

  XO5.OwnerScreen     = &Tic_Tac_Toe;
  XO5.Order           = 23;
  XO5.Left            = 531;
  XO5.Top             = 209;
  XO5.Width           = 20;
  XO5.Height          = 96;
  XO5.Visible         = 1;
  XO5.Active          = 1;
  XO5.Caption         = XO5_Caption;
  XO5.FontName        = Furro_Script75x96_Regular;
  XO5.Font_Color      = 0x25A4;
  XO5.OnUpPtr         = 0;
  XO5.OnDownPtr       = 0;
  XO5.OnClickPtr      = 0;
  XO5.OnPressPtr      = 0;

  XO6.OwnerScreen     = &Tic_Tac_Toe;
  XO6.Order           = 24;
  XO6.Left            = 654;
  XO6.Top             = 201;
  XO6.Width           = 20;
  XO6.Height          = 96;
  XO6.Visible         = 1;
  XO6.Active          = 1;
  XO6.Caption         = XO6_Caption;
  XO6.FontName        = Furro_Script75x96_Regular;
  XO6.Font_Color      = 0x25A4;
  XO6.OnUpPtr         = 0;
  XO6.OnDownPtr       = 0;
  XO6.OnClickPtr      = 0;
  XO6.OnPressPtr      = 0;

  XO7.OwnerScreen     = &Tic_Tac_Toe;
  XO7.Order           = 25;
  XO7.Left            = 410;
  XO7.Top             = 340;
  XO7.Width           = 20;
  XO7.Height          = 96;
  XO7.Visible         = 1;
  XO7.Active          = 1;
  XO7.Caption         = XO7_Caption;
  XO7.FontName        = Furro_Script75x96_Regular;
  XO7.Font_Color      = 0x25A4;
  XO7.OnUpPtr         = 0;
  XO7.OnDownPtr       = 0;
  XO7.OnClickPtr      = 0;
  XO7.OnPressPtr      = 0;

  XO8.OwnerScreen     = &Tic_Tac_Toe;
  XO8.Order           = 26;
  XO8.Left            = 540;
  XO8.Top             = 335;
  XO8.Width           = 20;
  XO8.Height          = 96;
  XO8.Visible         = 1;
  XO8.Active          = 1;
  XO8.Caption         = XO8_Caption;
  XO8.FontName        = Furro_Script75x96_Regular;
  XO8.Font_Color      = 0x25A4;
  XO8.OnUpPtr         = 0;
  XO8.OnDownPtr       = 0;
  XO8.OnClickPtr      = 0;
  XO8.OnPressPtr      = 0;

  XO9.OwnerScreen     = &Tic_Tac_Toe;
  XO9.Order           = 27;
  XO9.Left            = 668;
  XO9.Top             = 330;
  XO9.Width           = 20;
  XO9.Height          = 96;
  XO9.Visible         = 1;
  XO9.Active          = 1;
  XO9.Caption         = XO9_Caption;
  XO9.FontName        = Furro_Script75x96_Regular;
  XO9.Font_Color      = 0x25A4;
  XO9.OnUpPtr         = 0;
  XO9.OnDownPtr       = 0;
  XO9.OnClickPtr      = 0;
  XO9.OnPressPtr      = 0;

  CheckBox1.OwnerScreen     = &Tic_Tac_Toe;
  CheckBox1.Order           = 28;
  CheckBox1.Left            = 53;
  CheckBox1.Top             = 360;
  CheckBox1.Width           = 24;
  CheckBox1.Height          = 20;
  CheckBox1.Pen_Width       = 1;
  CheckBox1.Pen_Color       = 0xFFFF;
  CheckBox1.Visible         = 1;
  CheckBox1.Active          = 1;
  CheckBox1.Checked         = 0;
  CheckBox1.Transparent     = 1;
  CheckBox1.Caption         = CheckBox1_Caption;
  CheckBox1.TextAlign       = _taLeft;
  CheckBox1.FontName        = Open_Sans_Light12x18_Regular;
  CheckBox1.PressColEnabled = 0;
  CheckBox1.Font_Color      = 0xFFFF;
  CheckBox1.Gradient        = 0;
  CheckBox1.Gradient_Orientation = 0;
  CheckBox1.Gradient_Start_Color = 0xFFFF;
  CheckBox1.Gradient_End_Color = 0xC618;
  CheckBox1.Color           = 0xA1AE;
  CheckBox1.Press_Color     = 0xE71C;
  CheckBox1.Rounded         = 0;
  CheckBox1.Corner_Radius   = 1;
  CheckBox1.OnUpPtr         = 0;
  CheckBox1.OnDownPtr       = 0;
  CheckBox1.OnClickPtr      = CheckBox1OnClick;
  CheckBox1.OnPressPtr      = 0;

  Label41.OwnerScreen     = &Tic_Tac_Toe;
  Label41.Order           = 29;
  Label41.Left            = 84;
  Label41.Top             = 353;
  Label41.Width           = 155;
  Label41.Height          = 40;
  Label41.Visible         = 1;
  Label41.Active          = 0;
  Label41.Caption         = Label41_Caption;
  Label41.FontName        = Open_Sans_Light24x37_Regular;
  Label41.Font_Color      = 0xFFFF;
  Label41.OnUpPtr         = 0;
  Label41.OnDownPtr       = 0;
  Label41.OnClickPtr      = 0;
  Label41.OnPressPtr      = 0;

  Box24.OwnerScreen     = &WiFi;
  Box24.Order           = 0;
  Box24.Left            = 7;
  Box24.Top             = 5;
  Box24.Width           = 190;
  Box24.Height          = 49;
  Box24.Pen_Width       = 1;
  Box24.Pen_Color       = 0x0000;
  Box24.Visible         = 0;
  Box24.Active          = 1;
  Box24.Transparent     = 1;
  Box24.Gradient        = 0;
  Box24.Gradient_Orientation = 0;
  Box24.Gradient_Start_Color = 0xFFFF;
  Box24.Gradient_End_Color = 0xC618;
  Box24.Color           = 0xC618;
  Box24.PressColEnabled = 1;
  Box24.Press_Color     = 0xE71C;
  Box24.OnUpPtr         = 0;
  Box24.OnDownPtr       = 0;
  Box24.OnClickPtr      = BackIconWiFiOnPress;
  Box24.OnPressPtr      = 0;

  Label44.OwnerScreen     = &WiFi;
  Label44.Order           = 1;
  Label44.Left            = 53;
  Label44.Top             = 5;
  Label44.Width           = 61;
  Label44.Height          = 48;
  Label44.Visible         = 1;
  Label44.Active          = 1;
  Label44.Caption         = Label44_Caption;
  Label44.FontName        = Open_Sans_Light29x43_Regular;
  Label44.Font_Color      = 0xFFFF;
  Label44.OnUpPtr         = 0;
  Label44.OnDownPtr       = 0;
  Label44.OnClickPtr      = BackIconWiFiOnPress;
  Label44.OnPressPtr      = 0;

  Image23.OwnerScreen     = &WiFi;
  Image23.Order           = 2;
  Image23.Left            = 8;
  Image23.Top             = 10;
  Image23.Width           = 33;
  Image23.Height          = 33;
  Image23.Picture_Type    = 0;
  Image23.Picture_Ratio   = 1;
  Image23.Picture_Name    = icon_back_accel_bmp_1;
  Image23.Visible         = 1;
  Image23.Active          = 1;
  Image23.OnUpPtr         = 0;
  Image23.OnDownPtr       = 0;
  Image23.OnClickPtr      = BackIconWiFiOnPress;
  Image23.OnPressPtr      = 0;

  Box25.OwnerScreen     = &CAN;
  Box25.Order           = 0;
  Box25.Left            = 7;
  Box25.Top             = 5;
  Box25.Width           = 190;
  Box25.Height          = 49;
  Box25.Pen_Width       = 1;
  Box25.Pen_Color       = 0x0000;
  Box25.Visible         = 0;
  Box25.Active          = 1;
  Box25.Transparent     = 1;
  Box25.Gradient        = 0;
  Box25.Gradient_Orientation = 0;
  Box25.Gradient_Start_Color = 0xFFFF;
  Box25.Gradient_End_Color = 0xC618;
  Box25.Color           = 0xC618;
  Box25.PressColEnabled = 1;
  Box25.Press_Color     = 0xE71C;
  Box25.OnUpPtr         = 0;
  Box25.OnDownPtr       = 0;
  Box25.OnClickPtr      = BackIconCANOnPress;
  Box25.OnPressPtr      = 0;

  Label46.OwnerScreen     = &CAN;
  Label46.Order           = 1;
  Label46.Left            = 53;
  Label46.Top             = 5;
  Label46.Width           = 64;
  Label46.Height          = 48;
  Label46.Visible         = 1;
  Label46.Active          = 1;
  Label46.Caption         = Label46_Caption;
  Label46.FontName        = Open_Sans_Light29x43_Regular;
  Label46.Font_Color      = 0xFFFF;
  Label46.OnUpPtr         = 0;
  Label46.OnDownPtr       = 0;
  Label46.OnClickPtr      = BackIconCANOnPress;
  Label46.OnPressPtr      = 0;

  Image26.OwnerScreen     = &CAN;
  Image26.Order           = 2;
  Image26.Left            = 8;
  Image26.Top             = 10;
  Image26.Width           = 33;
  Image26.Height          = 33;
  Image26.Picture_Type    = 0;
  Image26.Picture_Ratio   = 1;
  Image26.Picture_Name    = icon_back_accel_bmp_1;
  Image26.Visible         = 1;
  Image26.Active          = 1;
  Image26.OnUpPtr         = 0;
  Image26.OnDownPtr       = 0;
  Image26.OnClickPtr      = BackIconCANOnPress;
  Image26.OnPressPtr      = 0;

  RadioButton1.OwnerScreen     = &CAN;
  RadioButton1.Order           = 3;
  RadioButton1.Left            = 455;
  RadioButton1.Top             = 337;
  RadioButton1.Width           = 49;
  RadioButton1.Height          = 45;
  RadioButton1.Pen_Width       = 1;
  RadioButton1.Pen_Color       = 0x0000;
  RadioButton1.Visible         = 1;
  RadioButton1.Active          = 1;
  RadioButton1.Checked         = 1;
  RadioButton1.Transparent     = 1;
  RadioButton1.Caption         = RadioButton1_Caption;
  RadioButton1.TextAlign       = _taLeft;
  RadioButton1.FontName        = Tahoma11x13_Regular;
  RadioButton1.PressColEnabled = 1;
  RadioButton1.Font_Color      = 0x0000;
  RadioButton1.Gradient        = 0;
  RadioButton1.Gradient_Orientation = 0;
  RadioButton1.Gradient_Start_Color = 0xFFFF;
  RadioButton1.Gradient_End_Color = 0xFFFF;
  RadioButton1.Color           = 0xFFFF;
  RadioButton1.Press_Color     = 0x07E0;
  RadioButton1.Background_Color = 0x8410;
  RadioButton1.OnUpPtr         = 0;
  RadioButton1.OnDownPtr       = 0;
  RadioButton1.OnClickPtr      = CAN_Button4;
  RadioButton1.OnPressPtr      = 0;

  RadioButton2.OwnerScreen     = &CAN;
  RadioButton2.Order           = 4;
  RadioButton2.Left            = 455;
  RadioButton2.Top             = 278;
  RadioButton2.Width           = 49;
  RadioButton2.Height          = 45;
  RadioButton2.Pen_Width       = 1;
  RadioButton2.Pen_Color       = 0x0000;
  RadioButton2.Visible         = 1;
  RadioButton2.Active          = 1;
  RadioButton2.Checked         = 1;
  RadioButton2.Transparent     = 1;
  RadioButton2.Caption         = RadioButton2_Caption;
  RadioButton2.TextAlign       = _taLeft;
  RadioButton2.FontName        = Tahoma11x13_Regular;
  RadioButton2.PressColEnabled = 1;
  RadioButton2.Font_Color      = 0x0000;
  RadioButton2.Gradient        = 0;
  RadioButton2.Gradient_Orientation = 0;
  RadioButton2.Gradient_Start_Color = 0xFFFF;
  RadioButton2.Gradient_End_Color = 0xFFFF;
  RadioButton2.Color           = 0xFFFF;
  RadioButton2.Press_Color     = 0x07E0;
  RadioButton2.Background_Color = 0x8410;
  RadioButton2.OnUpPtr         = 0;
  RadioButton2.OnDownPtr       = 0;
  RadioButton2.OnClickPtr      = CAN_Button5;
  RadioButton2.OnPressPtr      = 0;

  RadioButton3.OwnerScreen     = &CAN;
  RadioButton3.Order           = 5;
  RadioButton3.Left            = 455;
  RadioButton3.Top             = 219;
  RadioButton3.Width           = 49;
  RadioButton3.Height          = 45;
  RadioButton3.Pen_Width       = 1;
  RadioButton3.Pen_Color       = 0x0000;
  RadioButton3.Visible         = 1;
  RadioButton3.Active          = 1;
  RadioButton3.Checked         = 1;
  RadioButton3.Transparent     = 1;
  RadioButton3.Caption         = RadioButton3_Caption;
  RadioButton3.TextAlign       = _taLeft;
  RadioButton3.FontName        = Tahoma11x13_Regular;
  RadioButton3.PressColEnabled = 1;
  RadioButton3.Font_Color      = 0x0000;
  RadioButton3.Gradient        = 0;
  RadioButton3.Gradient_Orientation = 0;
  RadioButton3.Gradient_Start_Color = 0xFFFF;
  RadioButton3.Gradient_End_Color = 0xFFFF;
  RadioButton3.Color           = 0xFFFF;
  RadioButton3.Press_Color     = 0x07E0;
  RadioButton3.Background_Color = 0x8410;
  RadioButton3.OnUpPtr         = 0;
  RadioButton3.OnDownPtr       = 0;
  RadioButton3.OnClickPtr      = CAN_Button6;
  RadioButton3.OnPressPtr      = 0;

  RadioButton4.OwnerScreen     = &CAN;
  RadioButton4.Order           = 6;
  RadioButton4.Left            = 455;
  RadioButton4.Top             = 159;
  RadioButton4.Width           = 49;
  RadioButton4.Height          = 45;
  RadioButton4.Pen_Width       = 1;
  RadioButton4.Pen_Color       = 0x0000;
  RadioButton4.Visible         = 1;
  RadioButton4.Active          = 1;
  RadioButton4.Checked         = 1;
  RadioButton4.Transparent     = 1;
  RadioButton4.Caption         = RadioButton4_Caption;
  RadioButton4.TextAlign       = _taLeft;
  RadioButton4.FontName        = Tahoma11x13_Regular;
  RadioButton4.PressColEnabled = 1;
  RadioButton4.Font_Color      = 0x0000;
  RadioButton4.Gradient        = 0;
  RadioButton4.Gradient_Orientation = 0;
  RadioButton4.Gradient_Start_Color = 0xFFFF;
  RadioButton4.Gradient_End_Color = 0xFFFF;
  RadioButton4.Color           = 0xFFFF;
  RadioButton4.Press_Color     = 0x07E0;
  RadioButton4.Background_Color = 0x8410;
  RadioButton4.OnUpPtr         = 0;
  RadioButton4.OnDownPtr       = 0;
  RadioButton4.OnClickPtr      = CAN_Button7;
  RadioButton4.OnPressPtr      = 0;

  RadioButton5.OwnerScreen     = &CAN;
  RadioButton5.Order           = 7;
  RadioButton5.Left            = 540;
  RadioButton5.Top             = 337;
  RadioButton5.Width           = 49;
  RadioButton5.Height          = 45;
  RadioButton5.Pen_Width       = 1;
  RadioButton5.Pen_Color       = 0x0000;
  RadioButton5.Visible         = 1;
  RadioButton5.Active          = 1;
  RadioButton5.Checked         = 1;
  RadioButton5.Transparent     = 1;
  RadioButton5.Caption         = RadioButton5_Caption;
  RadioButton5.TextAlign       = _taLeft;
  RadioButton5.FontName        = Tahoma11x13_Regular;
  RadioButton5.PressColEnabled = 1;
  RadioButton5.Font_Color      = 0x0000;
  RadioButton5.Gradient        = 0;
  RadioButton5.Gradient_Orientation = 0;
  RadioButton5.Gradient_Start_Color = 0xFFFF;
  RadioButton5.Gradient_End_Color = 0xFFFF;
  RadioButton5.Color           = 0xFFFF;
  RadioButton5.Press_Color     = 0x07E0;
  RadioButton5.Background_Color = 0x8410;
  RadioButton5.OnUpPtr         = 0;
  RadioButton5.OnDownPtr       = 0;
  RadioButton5.OnClickPtr      = CAN_Button0;
  RadioButton5.OnPressPtr      = 0;

  RadioButton6.OwnerScreen     = &CAN;
  RadioButton6.Order           = 8;
  RadioButton6.Left            = 540;
  RadioButton6.Top             = 278;
  RadioButton6.Width           = 49;
  RadioButton6.Height          = 45;
  RadioButton6.Pen_Width       = 1;
  RadioButton6.Pen_Color       = 0x0000;
  RadioButton6.Visible         = 1;
  RadioButton6.Active          = 1;
  RadioButton6.Checked         = 1;
  RadioButton6.Transparent     = 1;
  RadioButton6.Caption         = RadioButton6_Caption;
  RadioButton6.TextAlign       = _taLeft;
  RadioButton6.FontName        = Tahoma11x13_Regular;
  RadioButton6.PressColEnabled = 1;
  RadioButton6.Font_Color      = 0x0000;
  RadioButton6.Gradient        = 0;
  RadioButton6.Gradient_Orientation = 0;
  RadioButton6.Gradient_Start_Color = 0xFFFF;
  RadioButton6.Gradient_End_Color = 0xFFFF;
  RadioButton6.Color           = 0xFFFF;
  RadioButton6.Press_Color     = 0x07E0;
  RadioButton6.Background_Color = 0x8410;
  RadioButton6.OnUpPtr         = 0;
  RadioButton6.OnDownPtr       = 0;
  RadioButton6.OnClickPtr      = CAN_Button1;
  RadioButton6.OnPressPtr      = 0;

  RadioButton7.OwnerScreen     = &CAN;
  RadioButton7.Order           = 9;
  RadioButton7.Left            = 540;
  RadioButton7.Top             = 219;
  RadioButton7.Width           = 49;
  RadioButton7.Height          = 45;
  RadioButton7.Pen_Width       = 1;
  RadioButton7.Pen_Color       = 0x0000;
  RadioButton7.Visible         = 1;
  RadioButton7.Active          = 1;
  RadioButton7.Checked         = 1;
  RadioButton7.Transparent     = 1;
  RadioButton7.Caption         = RadioButton7_Caption;
  RadioButton7.TextAlign       = _taLeft;
  RadioButton7.FontName        = Tahoma11x13_Regular;
  RadioButton7.PressColEnabled = 1;
  RadioButton7.Font_Color      = 0x0000;
  RadioButton7.Gradient        = 0;
  RadioButton7.Gradient_Orientation = 0;
  RadioButton7.Gradient_Start_Color = 0xFFFF;
  RadioButton7.Gradient_End_Color = 0xFFFF;
  RadioButton7.Color           = 0xFFFF;
  RadioButton7.Press_Color     = 0x07E0;
  RadioButton7.Background_Color = 0x8410;
  RadioButton7.OnUpPtr         = 0;
  RadioButton7.OnDownPtr       = 0;
  RadioButton7.OnClickPtr      = CAN_Button2;
  RadioButton7.OnPressPtr      = 0;

  RadioButton8.OwnerScreen     = &CAN;
  RadioButton8.Order           = 10;
  RadioButton8.Left            = 540;
  RadioButton8.Top             = 160;
  RadioButton8.Width           = 49;
  RadioButton8.Height          = 45;
  RadioButton8.Pen_Width       = 1;
  RadioButton8.Pen_Color       = 0x0000;
  RadioButton8.Visible         = 1;
  RadioButton8.Active          = 1;
  RadioButton8.Checked         = 1;
  RadioButton8.Transparent     = 1;
  RadioButton8.Caption         = RadioButton8_Caption;
  RadioButton8.TextAlign       = _taLeft;
  RadioButton8.FontName        = Tahoma11x13_Regular;
  RadioButton8.PressColEnabled = 1;
  RadioButton8.Font_Color      = 0x0000;
  RadioButton8.Gradient        = 0;
  RadioButton8.Gradient_Orientation = 0;
  RadioButton8.Gradient_Start_Color = 0xFFFF;
  RadioButton8.Gradient_End_Color = 0xFFFF;
  RadioButton8.Color           = 0xFFFF;
  RadioButton8.Press_Color     = 0x07E0;
  RadioButton8.Background_Color = 0x8410;
  RadioButton8.OnUpPtr         = 0;
  RadioButton8.OnDownPtr       = 0;
  RadioButton8.OnClickPtr      = CAN_Button3;
  RadioButton8.OnPressPtr      = 0;

  Label47.OwnerScreen     = &CAN;
  Label47.Order           = 11;
  Label47.Left            = 435;
  Label47.Top             = 90;
  Label47.Width           = 190;
  Label47.Height          = 48;
  Label47.Visible         = 1;
  Label47.Active          = 1;
  Label47.Caption         = Label47_Caption;
  Label47.FontName        = Open_Sans_Light29x43_Regular;
  Label47.Font_Color      = 0xFFFF;
  Label47.OnUpPtr         = 0;
  Label47.OnDownPtr       = 0;
  Label47.OnClickPtr      = BackIconCANOnPress;
  Label47.OnPressPtr      = 0;

  Label48.OwnerScreen     = &CAN;
  Label48.Order           = 12;
  Label48.Left            = 228;
  Label48.Top             = 90;
  Label48.Width           = 74;
  Label48.Height          = 48;
  Label48.Visible         = 1;
  Label48.Active          = 1;
  Label48.Caption         = Label48_Caption;
  Label48.FontName        = Open_Sans_Light29x43_Regular;
  Label48.Font_Color      = 0xFFFF;
  Label48.OnUpPtr         = 0;
  Label48.OnDownPtr       = 0;
  Label48.OnClickPtr      = BackIconCANOnPress;
  Label48.OnPressPtr      = 0;

  Circle2.OwnerScreen     = &CAN;
  Circle2.Order           = 13;
  Circle2.Left            = 280;
  Circle2.Top             = 340;
  Circle2.Radius          = 20;
  Circle2.Pen_Width       = 1;
  Circle2.Pen_Color       = 0xFFFF;
  Circle2.Visible         = 1;
  Circle2.Active          = 0;
  Circle2.Transparent     = 1;
  Circle2.Gradient        = 0;
  Circle2.Gradient_Orientation = 0;
  Circle2.Gradient_Start_Color = 0xFFFF;
  Circle2.Gradient_End_Color = 0xC618;
  Circle2.Color           = 0x4229;
  Circle2.PressColEnabled = 1;
  Circle2.Press_Color     = 0xE71C;
  Circle2.OnUpPtr         = 0;
  Circle2.OnDownPtr       = 0;
  Circle2.OnClickPtr      = 0;
  Circle2.OnPressPtr      = 0;

  Circle3.OwnerScreen     = &CAN;
  Circle3.Order           = 14;
  Circle3.Left            = 280;
  Circle3.Top             = 280;
  Circle3.Radius          = 20;
  Circle3.Pen_Width       = 1;
  Circle3.Pen_Color       = 0xFFFF;
  Circle3.Visible         = 1;
  Circle3.Active          = 0;
  Circle3.Transparent     = 1;
  Circle3.Gradient        = 0;
  Circle3.Gradient_Orientation = 0;
  Circle3.Gradient_Start_Color = 0xFFFF;
  Circle3.Gradient_End_Color = 0xC618;
  Circle3.Color           = 0x4229;
  Circle3.PressColEnabled = 1;
  Circle3.Press_Color     = 0xE71C;
  Circle3.OnUpPtr         = 0;
  Circle3.OnDownPtr       = 0;
  Circle3.OnClickPtr      = 0;
  Circle3.OnPressPtr      = 0;

  Circle4.OwnerScreen     = &CAN;
  Circle4.Order           = 15;
  Circle4.Left            = 280;
  Circle4.Top             = 220;
  Circle4.Radius          = 20;
  Circle4.Pen_Width       = 1;
  Circle4.Pen_Color       = 0xFFFF;
  Circle4.Visible         = 1;
  Circle4.Active          = 0;
  Circle4.Transparent     = 1;
  Circle4.Gradient        = 0;
  Circle4.Gradient_Orientation = 0;
  Circle4.Gradient_Start_Color = 0xFFFF;
  Circle4.Gradient_End_Color = 0xC618;
  Circle4.Color           = 0x4229;
  Circle4.PressColEnabled = 1;
  Circle4.Press_Color     = 0xE71C;
  Circle4.OnUpPtr         = 0;
  Circle4.OnDownPtr       = 0;
  Circle4.OnClickPtr      = 0;
  Circle4.OnPressPtr      = 0;

  Circle5.OwnerScreen     = &CAN;
  Circle5.Order           = 16;
  Circle5.Left            = 280;
  Circle5.Top             = 160;
  Circle5.Radius          = 20;
  Circle5.Pen_Width       = 1;
  Circle5.Pen_Color       = 0xFFFF;
  Circle5.Visible         = 1;
  Circle5.Active          = 0;
  Circle5.Transparent     = 1;
  Circle5.Gradient        = 0;
  Circle5.Gradient_Orientation = 0;
  Circle5.Gradient_Start_Color = 0xFFFF;
  Circle5.Gradient_End_Color = 0xC618;
  Circle5.Color           = 0x4229;
  Circle5.PressColEnabled = 1;
  Circle5.Press_Color     = 0xE71C;
  Circle5.OnUpPtr         = 0;
  Circle5.OnDownPtr       = 0;
  Circle5.OnClickPtr      = 0;
  Circle5.OnPressPtr      = 0;

  Circle6.OwnerScreen     = &CAN;
  Circle6.Order           = 17;
  Circle6.Left            = 200;
  Circle6.Top             = 340;
  Circle6.Radius          = 20;
  Circle6.Pen_Width       = 1;
  Circle6.Pen_Color       = 0xFFFF;
  Circle6.Visible         = 1;
  Circle6.Active          = 0;
  Circle6.Transparent     = 1;
  Circle6.Gradient        = 0;
  Circle6.Gradient_Orientation = 0;
  Circle6.Gradient_Start_Color = 0xFFFF;
  Circle6.Gradient_End_Color = 0xC618;
  Circle6.Color           = 0x4229;
  Circle6.PressColEnabled = 1;
  Circle6.Press_Color     = 0xE71C;
  Circle6.OnUpPtr         = 0;
  Circle6.OnDownPtr       = 0;
  Circle6.OnClickPtr      = 0;
  Circle6.OnPressPtr      = 0;

  Circle7.OwnerScreen     = &CAN;
  Circle7.Order           = 18;
  Circle7.Left            = 200;
  Circle7.Top             = 280;
  Circle7.Radius          = 20;
  Circle7.Pen_Width       = 1;
  Circle7.Pen_Color       = 0xFFFF;
  Circle7.Visible         = 1;
  Circle7.Active          = 0;
  Circle7.Transparent     = 1;
  Circle7.Gradient        = 0;
  Circle7.Gradient_Orientation = 0;
  Circle7.Gradient_Start_Color = 0xFFFF;
  Circle7.Gradient_End_Color = 0xC618;
  Circle7.Color           = 0x4229;
  Circle7.PressColEnabled = 1;
  Circle7.Press_Color     = 0xE71C;
  Circle7.OnUpPtr         = 0;
  Circle7.OnDownPtr       = 0;
  Circle7.OnClickPtr      = 0;
  Circle7.OnPressPtr      = 0;

  Circle8.OwnerScreen     = &CAN;
  Circle8.Order           = 19;
  Circle8.Left            = 200;
  Circle8.Top             = 220;
  Circle8.Radius          = 20;
  Circle8.Pen_Width       = 1;
  Circle8.Pen_Color       = 0xFFFF;
  Circle8.Visible         = 1;
  Circle8.Active          = 0;
  Circle8.Transparent     = 1;
  Circle8.Gradient        = 0;
  Circle8.Gradient_Orientation = 0;
  Circle8.Gradient_Start_Color = 0xFFFF;
  Circle8.Gradient_End_Color = 0xC618;
  Circle8.Color           = 0x4229;
  Circle8.PressColEnabled = 1;
  Circle8.Press_Color     = 0xE71C;
  Circle8.OnUpPtr         = 0;
  Circle8.OnDownPtr       = 0;
  Circle8.OnClickPtr      = 0;
  Circle8.OnPressPtr      = 0;

  Circle9.OwnerScreen     = &CAN;
  Circle9.Order           = 20;
  Circle9.Left            = 200;
  Circle9.Top             = 160;
  Circle9.Radius          = 20;
  Circle9.Pen_Width       = 1;
  Circle9.Pen_Color       = 0xFFFF;
  Circle9.Visible         = 1;
  Circle9.Active          = 0;
  Circle9.Transparent     = 1;
  Circle9.Gradient        = 0;
  Circle9.Gradient_Orientation = 0;
  Circle9.Gradient_Start_Color = 0xFFFF;
  Circle9.Gradient_End_Color = 0xC618;
  Circle9.Color           = 0x4229;
  Circle9.PressColEnabled = 1;
  Circle9.Press_Color     = 0xE71C;
  Circle9.OnUpPtr         = 0;
  Circle9.OnDownPtr       = 0;
  Circle9.OnClickPtr      = 0;
  Circle9.OnPressPtr      = 0;

  Diagram14_desc.OwnerScreen     = &Screen0;
  Diagram14_desc.Order           = 29;
  Diagram14_desc.Left            = 10;
  Diagram14_desc.Top             = 66;
  Diagram14_desc.Width           = 161;
  Diagram14_desc.Height          = 39;
  Diagram14_desc.Visible         = 1;
  Diagram14_desc.Active          = 0;
  Diagram14_desc.Caption         = Diagram14_desc_Caption;
  Diagram14_desc.FontName        = Tahoma28x35_Regular;
  Diagram14_desc.Font_Color      = 0x6BCF;
  Diagram14_desc.OnUpPtr         = 0;
  Diagram14_desc.OnDownPtr       = 0;
  Diagram14_desc.OnClickPtr      = 0;
  Diagram14_desc.OnPressPtr      = 0;

  Diagram14_bigHeader.OwnerScreen     = &Screen0;
  Diagram14_bigHeader.Order           = 30;
  Diagram14_bigHeader.Left            = 107;
  Diagram14_bigHeader.Top             = 240;
  Diagram14_bigHeader.Width           = 642;
  Diagram14_bigHeader.Height          = 68;
  Diagram14_bigHeader.Visible         = 1;
  Diagram14_bigHeader.Active          = 1;
  Diagram14_bigHeader.Caption         = Diagram14_bigHeader_Caption;
  Diagram14_bigHeader.FontName        = Tahoma50x62_Regular;
  Diagram14_bigHeader.Font_Color      = 0x6BCF;
  Diagram14_bigHeader.OnUpPtr         = 0;
  Diagram14_bigHeader.OnDownPtr       = 0;
  Diagram14_bigHeader.OnClickPtr      = 0;
  Diagram14_bigHeader.OnPressPtr      = 0;

  Diagram14_smallHeader.OwnerScreen     = &Screen0;
  Diagram14_smallHeader.Order           = 31;
  Diagram14_smallHeader.Left            = 310;
  Diagram14_smallHeader.Top             = 320;
  Diagram14_smallHeader.Width           = 176;
  Diagram14_smallHeader.Height          = 39;
  Diagram14_smallHeader.Visible         = 1;
  Diagram14_smallHeader.Active          = 1;
  Diagram14_smallHeader.Caption         = Diagram14_smallHeader_Caption;
  Diagram14_smallHeader.FontName        = Tahoma28x35_Regular;
  Diagram14_smallHeader.Font_Color      = 0x6BCF;
  Diagram14_smallHeader.OnUpPtr         = 0;
  Diagram14_smallHeader.OnDownPtr       = 0;
  Diagram14_smallHeader.OnClickPtr      = 0;
  Diagram14_smallHeader.OnPressPtr      = 0;

  BoxRound1.OwnerScreen     = &Screen0;
  BoxRound1.Order           = 32;
  BoxRound1.Left            = 0;
  BoxRound1.Top             = 0;
  BoxRound1.Width           = 800;
  BoxRound1.Height          = 60;
  BoxRound1.Pen_Width       = 0;
  BoxRound1.Pen_Color       = 0xE71C;
  BoxRound1.Visible         = 1;
  BoxRound1.Active          = 1;
  BoxRound1.Transparent     = 1;
  BoxRound1.Gradient        = 0;
  BoxRound1.Gradient_Orientation = 0;
  BoxRound1.Gradient_Start_Color = 0x632C;
  BoxRound1.Gradient_End_Color = 0x6304;
  BoxRound1.Color           = 0xE71C;
  BoxRound1.PressColEnabled = 1;
  BoxRound1.Press_Color     = 0xE71C;
  BoxRound1.Corner_Radius   = 5;
  BoxRound1.OnUpPtr         = 0;
  BoxRound1.OnDownPtr       = 0;
  BoxRound1.OnClickPtr      = 0;
  BoxRound1.OnPressPtr      = 0;

  Box26.OwnerScreen     = &Screen1;
  Box26.Order           = 0;
  Box26.Left            = 0;
  Box26.Top             = 0;
  Box26.Width           = 800;
  Box26.Height          = 60;
  Box26.Pen_Width       = 1;
  Box26.Pen_Color       = 0x0000;
  Box26.Visible         = 1;
  Box26.Active          = 0;
  Box26.Transparent     = 1;
  Box26.Gradient        = 1;
  Box26.Gradient_Orientation = 0;
  Box26.Gradient_Start_Color = 0x4229;
  Box26.Gradient_End_Color = 0x4229;
  Box26.Color           = 0x4229;
  Box26.PressColEnabled = 1;
  Box26.Press_Color     = 0xE71C;
  Box26.OnUpPtr         = 0;
  Box26.OnDownPtr       = 0;
  Box26.OnClickPtr      = 0;
  Box26.OnPressPtr      = 0;

  line1.OwnerScreen     = &Screen1;
  line1.Order           = 1;
  line1.Left            = 10;
  line1.Top             = 60;
  line1.Width           = 206;
  line1.Height          = 36;
  line1.Visible         = 1;
  line1.Active          = 0;
  line1.Caption         = line1_Caption;
  line1.FontName        = Tahoma26x33_Regular;
  line1.Font_Color      = 0x9534;
  line1.OnUpPtr         = 0;
  line1.OnDownPtr       = 0;
  line1.OnClickPtr      = 0;
  line1.OnPressPtr      = 0;

  line2.OwnerScreen     = &Screen1;
  line2.Order           = 2;
  line2.Left            = 10;
  line2.Top             = 90;
  line2.Width           = 0;
  line2.Height          = 36;
  line2.Visible         = 1;
  line2.Active          = 0;
  line2.Caption         = line2_Caption;
  line2.FontName        = Tahoma26x33_Regular;
  line2.Font_Color      = 0x9534;
  line2.OnUpPtr         = 0;
  line2.OnDownPtr       = 0;
  line2.OnClickPtr      = 0;
  line2.OnPressPtr      = 0;

  line3.OwnerScreen     = &Screen1;
  line3.Order           = 3;
  line3.Left            = 10;
  line3.Top             = 120;
  line3.Width           = 0;
  line3.Height          = 36;
  line3.Visible         = 1;
  line3.Active          = 0;
  line3.Caption         = line3_Caption;
  line3.FontName        = Tahoma26x33_Regular;
  line3.Font_Color      = 0x9534;
  line3.OnUpPtr         = 0;
  line3.OnDownPtr       = 0;
  line3.OnClickPtr      = 0;
  line3.OnPressPtr      = 0;

  ButtonW.OwnerScreen     = &Screen1;
  ButtonW.Order           = 4;
  ButtonW.Left            = 80;
  ButtonW.Top             = 160;
  ButtonW.Width           = 80;
  ButtonW.Height          = 80;
  ButtonW.Pen_Width       = 0;
  ButtonW.Pen_Color       = 0x0000;
  ButtonW.Visible         = 1;
  ButtonW.Active          = 1;
  ButtonW.Transparent     = 1;
  ButtonW.Caption         = ButtonW_Caption;
  ButtonW.TextAlign       = _taCenter;
  ButtonW.FontName        = Tahoma23x29_Regular;
  ButtonW.PressColEnabled = 1;
  ButtonW.Font_Color      = 0xF79E;
  ButtonW.Gradient        = 0;
  ButtonW.Gradient_Orientation = 0;
  ButtonW.Gradient_Start_Color = 0x632C;
  ButtonW.Gradient_End_Color = 0x6304;
  ButtonW.Color           = 0x4229;
  ButtonW.Press_Color     = 0xE267;
  ButtonW.Corner_Radius   = 5;
  ButtonW.OnUpPtr         = 0;
  ButtonW.OnDownPtr       = 0;
  ButtonW.OnClickPtr      = SaveW;
  ButtonW.OnPressPtr      = 0;

  ButtonE.OwnerScreen     = &Screen1;
  ButtonE.Order           = 5;
  ButtonE.Left            = 160;
  ButtonE.Top             = 160;
  ButtonE.Width           = 80;
  ButtonE.Height          = 80;
  ButtonE.Pen_Width       = 0;
  ButtonE.Pen_Color       = 0x0000;
  ButtonE.Visible         = 1;
  ButtonE.Active          = 1;
  ButtonE.Transparent     = 1;
  ButtonE.Caption         = ButtonE_Caption;
  ButtonE.TextAlign       = _taCenter;
  ButtonE.FontName        = Tahoma23x29_Regular;
  ButtonE.PressColEnabled = 1;
  ButtonE.Font_Color      = 0xF79E;
  ButtonE.Gradient        = 0;
  ButtonE.Gradient_Orientation = 0;
  ButtonE.Gradient_Start_Color = 0x632C;
  ButtonE.Gradient_End_Color = 0x6304;
  ButtonE.Color           = 0x4229;
  ButtonE.Press_Color     = 0xE267;
  ButtonE.Corner_Radius   = 5;
  ButtonE.OnUpPtr         = 0;
  ButtonE.OnDownPtr       = 0;
  ButtonE.OnClickPtr      = SaveE;
  ButtonE.OnPressPtr      = 0;

  ButtonQ.OwnerScreen     = &Screen1;
  ButtonQ.Order           = 6;
  ButtonQ.Left            = 0;
  ButtonQ.Top             = 160;
  ButtonQ.Width           = 80;
  ButtonQ.Height          = 80;
  ButtonQ.Pen_Width       = 0;
  ButtonQ.Pen_Color       = 0x0000;
  ButtonQ.Visible         = 1;
  ButtonQ.Active          = 1;
  ButtonQ.Transparent     = 1;
  ButtonQ.Caption         = ButtonQ_Caption;
  ButtonQ.TextAlign       = _taCenter;
  ButtonQ.FontName        = Tahoma23x29_Regular;
  ButtonQ.PressColEnabled = 1;
  ButtonQ.Font_Color      = 0xF79E;
  ButtonQ.Gradient        = 0;
  ButtonQ.Gradient_Orientation = 0;
  ButtonQ.Gradient_Start_Color = 0x632C;
  ButtonQ.Gradient_End_Color = 0x6304;
  ButtonQ.Color           = 0x4229;
  ButtonQ.Press_Color     = 0xE267;
  ButtonQ.Corner_Radius   = 5;
  ButtonQ.OnUpPtr         = 0;
  ButtonQ.OnDownPtr       = 0;
  ButtonQ.OnClickPtr      = SaveQ;
  ButtonQ.OnPressPtr      = 0;

  ButtonR.OwnerScreen     = &Screen1;
  ButtonR.Order           = 7;
  ButtonR.Left            = 240;
  ButtonR.Top             = 160;
  ButtonR.Width           = 80;
  ButtonR.Height          = 80;
  ButtonR.Pen_Width       = 0;
  ButtonR.Pen_Color       = 0x0000;
  ButtonR.Visible         = 1;
  ButtonR.Active          = 1;
  ButtonR.Transparent     = 1;
  ButtonR.Caption         = ButtonR_Caption;
  ButtonR.TextAlign       = _taCenter;
  ButtonR.FontName        = Tahoma23x29_Regular;
  ButtonR.PressColEnabled = 1;
  ButtonR.Font_Color      = 0xF79E;
  ButtonR.Gradient        = 0;
  ButtonR.Gradient_Orientation = 0;
  ButtonR.Gradient_Start_Color = 0x632C;
  ButtonR.Gradient_End_Color = 0x6304;
  ButtonR.Color           = 0x4229;
  ButtonR.Press_Color     = 0xE267;
  ButtonR.Corner_Radius   = 5;
  ButtonR.OnUpPtr         = 0;
  ButtonR.OnDownPtr       = 0;
  ButtonR.OnClickPtr      = SaveR;
  ButtonR.OnPressPtr      = 0;

  ButtonT.OwnerScreen     = &Screen1;
  ButtonT.Order           = 8;
  ButtonT.Left            = 320;
  ButtonT.Top             = 160;
  ButtonT.Width           = 80;
  ButtonT.Height          = 80;
  ButtonT.Pen_Width       = 0;
  ButtonT.Pen_Color       = 0x0000;
  ButtonT.Visible         = 1;
  ButtonT.Active          = 1;
  ButtonT.Transparent     = 1;
  ButtonT.Caption         = ButtonT_Caption;
  ButtonT.TextAlign       = _taCenter;
  ButtonT.FontName        = Tahoma23x29_Regular;
  ButtonT.PressColEnabled = 1;
  ButtonT.Font_Color      = 0xF79E;
  ButtonT.Gradient        = 0;
  ButtonT.Gradient_Orientation = 0;
  ButtonT.Gradient_Start_Color = 0x632C;
  ButtonT.Gradient_End_Color = 0x6304;
  ButtonT.Color           = 0x4229;
  ButtonT.Press_Color     = 0xE267;
  ButtonT.Corner_Radius   = 5;
  ButtonT.OnUpPtr         = 0;
  ButtonT.OnDownPtr       = 0;
  ButtonT.OnClickPtr      = SaveT;
  ButtonT.OnPressPtr      = 0;

  ButtonY.OwnerScreen     = &Screen1;
  ButtonY.Order           = 9;
  ButtonY.Left            = 400;
  ButtonY.Top             = 160;
  ButtonY.Width           = 80;
  ButtonY.Height          = 80;
  ButtonY.Pen_Width       = 0;
  ButtonY.Pen_Color       = 0x0000;
  ButtonY.Visible         = 1;
  ButtonY.Active          = 1;
  ButtonY.Transparent     = 1;
  ButtonY.Caption         = ButtonY_Caption;
  ButtonY.TextAlign       = _taCenter;
  ButtonY.FontName        = Tahoma23x29_Regular;
  ButtonY.PressColEnabled = 1;
  ButtonY.Font_Color      = 0xF79E;
  ButtonY.Gradient        = 0;
  ButtonY.Gradient_Orientation = 0;
  ButtonY.Gradient_Start_Color = 0x632C;
  ButtonY.Gradient_End_Color = 0x6304;
  ButtonY.Color           = 0x4229;
  ButtonY.Press_Color     = 0xE267;
  ButtonY.Corner_Radius   = 5;
  ButtonY.OnUpPtr         = 0;
  ButtonY.OnDownPtr       = 0;
  ButtonY.OnClickPtr      = SaveY;
  ButtonY.OnPressPtr      = 0;

  ButtonU.OwnerScreen     = &Screen1;
  ButtonU.Order           = 10;
  ButtonU.Left            = 480;
  ButtonU.Top             = 160;
  ButtonU.Width           = 80;
  ButtonU.Height          = 80;
  ButtonU.Pen_Width       = 0;
  ButtonU.Pen_Color       = 0x0000;
  ButtonU.Visible         = 1;
  ButtonU.Active          = 1;
  ButtonU.Transparent     = 1;
  ButtonU.Caption         = ButtonU_Caption;
  ButtonU.TextAlign       = _taCenter;
  ButtonU.FontName        = Tahoma23x29_Regular;
  ButtonU.PressColEnabled = 1;
  ButtonU.Font_Color      = 0xF79E;
  ButtonU.Gradient        = 0;
  ButtonU.Gradient_Orientation = 0;
  ButtonU.Gradient_Start_Color = 0x632C;
  ButtonU.Gradient_End_Color = 0x6304;
  ButtonU.Color           = 0x4229;
  ButtonU.Press_Color     = 0xE267;
  ButtonU.Corner_Radius   = 5;
  ButtonU.OnUpPtr         = 0;
  ButtonU.OnDownPtr       = 0;
  ButtonU.OnClickPtr      = SaveU;
  ButtonU.OnPressPtr      = 0;

  ButtonI.OwnerScreen     = &Screen1;
  ButtonI.Order           = 11;
  ButtonI.Left            = 560;
  ButtonI.Top             = 160;
  ButtonI.Width           = 80;
  ButtonI.Height          = 80;
  ButtonI.Pen_Width       = 0;
  ButtonI.Pen_Color       = 0x0000;
  ButtonI.Visible         = 1;
  ButtonI.Active          = 1;
  ButtonI.Transparent     = 1;
  ButtonI.Caption         = ButtonI_Caption;
  ButtonI.TextAlign       = _taCenter;
  ButtonI.FontName        = Tahoma23x29_Regular;
  ButtonI.PressColEnabled = 1;
  ButtonI.Font_Color      = 0xF79E;
  ButtonI.Gradient        = 0;
  ButtonI.Gradient_Orientation = 0;
  ButtonI.Gradient_Start_Color = 0x632C;
  ButtonI.Gradient_End_Color = 0x6304;
  ButtonI.Color           = 0x4229;
  ButtonI.Press_Color     = 0xE267;
  ButtonI.Corner_Radius   = 5;
  ButtonI.OnUpPtr         = 0;
  ButtonI.OnDownPtr       = 0;
  ButtonI.OnClickPtr      = SaveI;
  ButtonI.OnPressPtr      = 0;

  ButtonP.OwnerScreen     = &Screen1;
  ButtonP.Order           = 12;
  ButtonP.Left            = 720;
  ButtonP.Top             = 160;
  ButtonP.Width           = 80;
  ButtonP.Height          = 80;
  ButtonP.Pen_Width       = 0;
  ButtonP.Pen_Color       = 0x0000;
  ButtonP.Visible         = 1;
  ButtonP.Active          = 1;
  ButtonP.Transparent     = 1;
  ButtonP.Caption         = ButtonP_Caption;
  ButtonP.TextAlign       = _taCenter;
  ButtonP.FontName        = Tahoma23x29_Regular;
  ButtonP.PressColEnabled = 1;
  ButtonP.Font_Color      = 0xF79E;
  ButtonP.Gradient        = 0;
  ButtonP.Gradient_Orientation = 0;
  ButtonP.Gradient_Start_Color = 0x632C;
  ButtonP.Gradient_End_Color = 0x6304;
  ButtonP.Color           = 0x4229;
  ButtonP.Press_Color     = 0xE267;
  ButtonP.Corner_Radius   = 5;
  ButtonP.OnUpPtr         = 0;
  ButtonP.OnDownPtr       = 0;
  ButtonP.OnClickPtr      = SaveP;
  ButtonP.OnPressPtr      = 0;

  ButtonO.OwnerScreen     = &Screen1;
  ButtonO.Order           = 13;
  ButtonO.Left            = 640;
  ButtonO.Top             = 160;
  ButtonO.Width           = 80;
  ButtonO.Height          = 80;
  ButtonO.Pen_Width       = 0;
  ButtonO.Pen_Color       = 0x0000;
  ButtonO.Visible         = 1;
  ButtonO.Active          = 1;
  ButtonO.Transparent     = 1;
  ButtonO.Caption         = ButtonO_Caption;
  ButtonO.TextAlign       = _taCenter;
  ButtonO.FontName        = Tahoma23x29_Regular;
  ButtonO.PressColEnabled = 1;
  ButtonO.Font_Color      = 0xF79E;
  ButtonO.Gradient        = 0;
  ButtonO.Gradient_Orientation = 0;
  ButtonO.Gradient_Start_Color = 0x632C;
  ButtonO.Gradient_End_Color = 0x6304;
  ButtonO.Color           = 0x4229;
  ButtonO.Press_Color     = 0xE267;
  ButtonO.Corner_Radius   = 5;
  ButtonO.OnUpPtr         = 0;
  ButtonO.OnDownPtr       = 0;
  ButtonO.OnClickPtr      = SaveO;
  ButtonO.OnPressPtr      = 0;

  ButtonX.OwnerScreen     = &Screen1;
  ButtonX.Order           = 14;
  ButtonX.Left            = 160;
  ButtonX.Top             = 320;
  ButtonX.Width           = 80;
  ButtonX.Height          = 80;
  ButtonX.Pen_Width       = 0;
  ButtonX.Pen_Color       = 0x0000;
  ButtonX.Visible         = 1;
  ButtonX.Active          = 1;
  ButtonX.Transparent     = 1;
  ButtonX.Caption         = ButtonX_Caption;
  ButtonX.TextAlign       = _taCenter;
  ButtonX.FontName        = Tahoma23x29_Regular;
  ButtonX.PressColEnabled = 1;
  ButtonX.Font_Color      = 0xF79E;
  ButtonX.Gradient        = 0;
  ButtonX.Gradient_Orientation = 0;
  ButtonX.Gradient_Start_Color = 0x632C;
  ButtonX.Gradient_End_Color = 0x6304;
  ButtonX.Color           = 0x4229;
  ButtonX.Press_Color     = 0xE267;
  ButtonX.Corner_Radius   = 5;
  ButtonX.OnUpPtr         = 0;
  ButtonX.OnDownPtr       = 0;
  ButtonX.OnClickPtr      = SaveX;
  ButtonX.OnPressPtr      = 0;

  ButtonC.OwnerScreen     = &Screen1;
  ButtonC.Order           = 15;
  ButtonC.Left            = 240;
  ButtonC.Top             = 320;
  ButtonC.Width           = 80;
  ButtonC.Height          = 80;
  ButtonC.Pen_Width       = 0;
  ButtonC.Pen_Color       = 0x0000;
  ButtonC.Visible         = 1;
  ButtonC.Active          = 1;
  ButtonC.Transparent     = 1;
  ButtonC.Caption         = ButtonC_Caption;
  ButtonC.TextAlign       = _taCenter;
  ButtonC.FontName        = Tahoma23x29_Regular;
  ButtonC.PressColEnabled = 1;
  ButtonC.Font_Color      = 0xF79E;
  ButtonC.Gradient        = 0;
  ButtonC.Gradient_Orientation = 0;
  ButtonC.Gradient_Start_Color = 0x632C;
  ButtonC.Gradient_End_Color = 0x6304;
  ButtonC.Color           = 0x4229;
  ButtonC.Press_Color     = 0xE267;
  ButtonC.Corner_Radius   = 5;
  ButtonC.OnUpPtr         = 0;
  ButtonC.OnDownPtr       = 0;
  ButtonC.OnClickPtr      = SaveC;
  ButtonC.OnPressPtr      = 0;

  ButtonZ.OwnerScreen     = &Screen1;
  ButtonZ.Order           = 16;
  ButtonZ.Left            = 80;
  ButtonZ.Top             = 320;
  ButtonZ.Width           = 80;
  ButtonZ.Height          = 80;
  ButtonZ.Pen_Width       = 0;
  ButtonZ.Pen_Color       = 0x0000;
  ButtonZ.Visible         = 1;
  ButtonZ.Active          = 1;
  ButtonZ.Transparent     = 1;
  ButtonZ.Caption         = ButtonZ_Caption;
  ButtonZ.TextAlign       = _taCenter;
  ButtonZ.FontName        = Tahoma23x29_Regular;
  ButtonZ.PressColEnabled = 1;
  ButtonZ.Font_Color      = 0xF79E;
  ButtonZ.Gradient        = 0;
  ButtonZ.Gradient_Orientation = 0;
  ButtonZ.Gradient_Start_Color = 0x632C;
  ButtonZ.Gradient_End_Color = 0x6304;
  ButtonZ.Color           = 0x4229;
  ButtonZ.Press_Color     = 0xE267;
  ButtonZ.Corner_Radius   = 5;
  ButtonZ.OnUpPtr         = 0;
  ButtonZ.OnDownPtr       = 0;
  ButtonZ.OnClickPtr      = SaveZ;
  ButtonZ.OnPressPtr      = 0;

  ButtonV.OwnerScreen     = &Screen1;
  ButtonV.Order           = 17;
  ButtonV.Left            = 320;
  ButtonV.Top             = 320;
  ButtonV.Width           = 80;
  ButtonV.Height          = 80;
  ButtonV.Pen_Width       = 0;
  ButtonV.Pen_Color       = 0x0000;
  ButtonV.Visible         = 1;
  ButtonV.Active          = 1;
  ButtonV.Transparent     = 1;
  ButtonV.Caption         = ButtonV_Caption;
  ButtonV.TextAlign       = _taCenter;
  ButtonV.FontName        = Tahoma23x29_Regular;
  ButtonV.PressColEnabled = 1;
  ButtonV.Font_Color      = 0xF79E;
  ButtonV.Gradient        = 0;
  ButtonV.Gradient_Orientation = 0;
  ButtonV.Gradient_Start_Color = 0x632C;
  ButtonV.Gradient_End_Color = 0x6304;
  ButtonV.Color           = 0x4229;
  ButtonV.Press_Color     = 0xE267;
  ButtonV.Corner_Radius   = 5;
  ButtonV.OnUpPtr         = 0;
  ButtonV.OnDownPtr       = 0;
  ButtonV.OnClickPtr      = SaveV;
  ButtonV.OnPressPtr      = 0;

  ButtonB.OwnerScreen     = &Screen1;
  ButtonB.Order           = 18;
  ButtonB.Left            = 400;
  ButtonB.Top             = 320;
  ButtonB.Width           = 80;
  ButtonB.Height          = 80;
  ButtonB.Pen_Width       = 0;
  ButtonB.Pen_Color       = 0x0000;
  ButtonB.Visible         = 1;
  ButtonB.Active          = 1;
  ButtonB.Transparent     = 1;
  ButtonB.Caption         = ButtonB_Caption;
  ButtonB.TextAlign       = _taCenter;
  ButtonB.FontName        = Tahoma23x29_Regular;
  ButtonB.PressColEnabled = 1;
  ButtonB.Font_Color      = 0xF79E;
  ButtonB.Gradient        = 0;
  ButtonB.Gradient_Orientation = 0;
  ButtonB.Gradient_Start_Color = 0x632C;
  ButtonB.Gradient_End_Color = 0x6304;
  ButtonB.Color           = 0x4229;
  ButtonB.Press_Color     = 0xE267;
  ButtonB.Corner_Radius   = 5;
  ButtonB.OnUpPtr         = 0;
  ButtonB.OnDownPtr       = 0;
  ButtonB.OnClickPtr      = SaveB;
  ButtonB.OnPressPtr      = 0;

  ButtonN.OwnerScreen     = &Screen1;
  ButtonN.Order           = 19;
  ButtonN.Left            = 480;
  ButtonN.Top             = 320;
  ButtonN.Width           = 80;
  ButtonN.Height          = 80;
  ButtonN.Pen_Width       = 0;
  ButtonN.Pen_Color       = 0x0000;
  ButtonN.Visible         = 1;
  ButtonN.Active          = 1;
  ButtonN.Transparent     = 1;
  ButtonN.Caption         = ButtonN_Caption;
  ButtonN.TextAlign       = _taCenter;
  ButtonN.FontName        = Tahoma23x29_Regular;
  ButtonN.PressColEnabled = 1;
  ButtonN.Font_Color      = 0xF79E;
  ButtonN.Gradient        = 0;
  ButtonN.Gradient_Orientation = 0;
  ButtonN.Gradient_Start_Color = 0x632C;
  ButtonN.Gradient_End_Color = 0x6304;
  ButtonN.Color           = 0x4229;
  ButtonN.Press_Color     = 0xE267;
  ButtonN.Corner_Radius   = 5;
  ButtonN.OnUpPtr         = 0;
  ButtonN.OnDownPtr       = 0;
  ButtonN.OnClickPtr      = SaveN;
  ButtonN.OnPressPtr      = 0;

  ButtonM.OwnerScreen     = &Screen1;
  ButtonM.Order           = 20;
  ButtonM.Left            = 560;
  ButtonM.Top             = 320;
  ButtonM.Width           = 80;
  ButtonM.Height          = 80;
  ButtonM.Pen_Width       = 0;
  ButtonM.Pen_Color       = 0x0000;
  ButtonM.Visible         = 1;
  ButtonM.Active          = 1;
  ButtonM.Transparent     = 1;
  ButtonM.Caption         = ButtonM_Caption;
  ButtonM.TextAlign       = _taCenter;
  ButtonM.FontName        = Tahoma23x29_Regular;
  ButtonM.PressColEnabled = 1;
  ButtonM.Font_Color      = 0xF79E;
  ButtonM.Gradient        = 0;
  ButtonM.Gradient_Orientation = 0;
  ButtonM.Gradient_Start_Color = 0x632C;
  ButtonM.Gradient_End_Color = 0x6304;
  ButtonM.Color           = 0x4229;
  ButtonM.Press_Color     = 0xE267;
  ButtonM.Corner_Radius   = 5;
  ButtonM.OnUpPtr         = 0;
  ButtonM.OnDownPtr       = 0;
  ButtonM.OnClickPtr      = SaveM;
  ButtonM.OnPressPtr      = 0;

  ButtonS.OwnerScreen     = &Screen1;
  ButtonS.Order           = 21;
  ButtonS.Left            = 80;
  ButtonS.Top             = 240;
  ButtonS.Width           = 80;
  ButtonS.Height          = 80;
  ButtonS.Pen_Width       = 0;
  ButtonS.Pen_Color       = 0x0000;
  ButtonS.Visible         = 1;
  ButtonS.Active          = 1;
  ButtonS.Transparent     = 1;
  ButtonS.Caption         = ButtonS_Caption;
  ButtonS.TextAlign       = _taCenter;
  ButtonS.FontName        = Tahoma23x29_Regular;
  ButtonS.PressColEnabled = 1;
  ButtonS.Font_Color      = 0xF79E;
  ButtonS.Gradient        = 0;
  ButtonS.Gradient_Orientation = 0;
  ButtonS.Gradient_Start_Color = 0x632C;
  ButtonS.Gradient_End_Color = 0x6304;
  ButtonS.Color           = 0x4229;
  ButtonS.Press_Color     = 0xE267;
  ButtonS.Corner_Radius   = 5;
  ButtonS.OnUpPtr         = 0;
  ButtonS.OnDownPtr       = 0;
  ButtonS.OnClickPtr      = SaveS;
  ButtonS.OnPressPtr      = 0;

  ButtonD.OwnerScreen     = &Screen1;
  ButtonD.Order           = 22;
  ButtonD.Left            = 160;
  ButtonD.Top             = 240;
  ButtonD.Width           = 80;
  ButtonD.Height          = 80;
  ButtonD.Pen_Width       = 0;
  ButtonD.Pen_Color       = 0x0000;
  ButtonD.Visible         = 1;
  ButtonD.Active          = 1;
  ButtonD.Transparent     = 1;
  ButtonD.Caption         = ButtonD_Caption;
  ButtonD.TextAlign       = _taCenter;
  ButtonD.FontName        = Tahoma23x29_Regular;
  ButtonD.PressColEnabled = 1;
  ButtonD.Font_Color      = 0xF79E;
  ButtonD.Gradient        = 0;
  ButtonD.Gradient_Orientation = 0;
  ButtonD.Gradient_Start_Color = 0x632C;
  ButtonD.Gradient_End_Color = 0x6304;
  ButtonD.Color           = 0x4229;
  ButtonD.Press_Color     = 0xE267;
  ButtonD.Corner_Radius   = 5;
  ButtonD.OnUpPtr         = 0;
  ButtonD.OnDownPtr       = 0;
  ButtonD.OnClickPtr      = SaveD;
  ButtonD.OnPressPtr      = 0;

  ButtonA.OwnerScreen     = &Screen1;
  ButtonA.Order           = 23;
  ButtonA.Left            = 0;
  ButtonA.Top             = 240;
  ButtonA.Width           = 80;
  ButtonA.Height          = 80;
  ButtonA.Pen_Width       = 0;
  ButtonA.Pen_Color       = 0x0000;
  ButtonA.Visible         = 1;
  ButtonA.Active          = 1;
  ButtonA.Transparent     = 1;
  ButtonA.Caption         = ButtonA_Caption;
  ButtonA.TextAlign       = _taCenter;
  ButtonA.FontName        = Tahoma23x29_Regular;
  ButtonA.PressColEnabled = 1;
  ButtonA.Font_Color      = 0xF79E;
  ButtonA.Gradient        = 0;
  ButtonA.Gradient_Orientation = 0;
  ButtonA.Gradient_Start_Color = 0x632C;
  ButtonA.Gradient_End_Color = 0x6304;
  ButtonA.Color           = 0x4229;
  ButtonA.Press_Color     = 0xE267;
  ButtonA.Corner_Radius   = 5;
  ButtonA.OnUpPtr         = 0;
  ButtonA.OnDownPtr       = 0;
  ButtonA.OnClickPtr      = SaveA;
  ButtonA.OnPressPtr      = 0;

  ButtonF.OwnerScreen     = &Screen1;
  ButtonF.Order           = 24;
  ButtonF.Left            = 240;
  ButtonF.Top             = 240;
  ButtonF.Width           = 80;
  ButtonF.Height          = 80;
  ButtonF.Pen_Width       = 0;
  ButtonF.Pen_Color       = 0x0000;
  ButtonF.Visible         = 1;
  ButtonF.Active          = 1;
  ButtonF.Transparent     = 1;
  ButtonF.Caption         = ButtonF_Caption;
  ButtonF.TextAlign       = _taCenter;
  ButtonF.FontName        = Tahoma23x29_Regular;
  ButtonF.PressColEnabled = 1;
  ButtonF.Font_Color      = 0xF79E;
  ButtonF.Gradient        = 0;
  ButtonF.Gradient_Orientation = 0;
  ButtonF.Gradient_Start_Color = 0x632C;
  ButtonF.Gradient_End_Color = 0x6304;
  ButtonF.Color           = 0x4229;
  ButtonF.Press_Color     = 0xE267;
  ButtonF.Corner_Radius   = 5;
  ButtonF.OnUpPtr         = 0;
  ButtonF.OnDownPtr       = 0;
  ButtonF.OnClickPtr      = SaveF;
  ButtonF.OnPressPtr      = 0;

  ButtonG.OwnerScreen     = &Screen1;
  ButtonG.Order           = 25;
  ButtonG.Left            = 320;
  ButtonG.Top             = 240;
  ButtonG.Width           = 80;
  ButtonG.Height          = 80;
  ButtonG.Pen_Width       = 0;
  ButtonG.Pen_Color       = 0x0000;
  ButtonG.Visible         = 1;
  ButtonG.Active          = 1;
  ButtonG.Transparent     = 1;
  ButtonG.Caption         = ButtonG_Caption;
  ButtonG.TextAlign       = _taCenter;
  ButtonG.FontName        = Tahoma23x29_Regular;
  ButtonG.PressColEnabled = 1;
  ButtonG.Font_Color      = 0xF79E;
  ButtonG.Gradient        = 0;
  ButtonG.Gradient_Orientation = 0;
  ButtonG.Gradient_Start_Color = 0x632C;
  ButtonG.Gradient_End_Color = 0x6304;
  ButtonG.Color           = 0x4229;
  ButtonG.Press_Color     = 0xE267;
  ButtonG.Corner_Radius   = 5;
  ButtonG.OnUpPtr         = 0;
  ButtonG.OnDownPtr       = 0;
  ButtonG.OnClickPtr      = SaveG;
  ButtonG.OnPressPtr      = 0;

  ButtonH.OwnerScreen     = &Screen1;
  ButtonH.Order           = 26;
  ButtonH.Left            = 400;
  ButtonH.Top             = 240;
  ButtonH.Width           = 80;
  ButtonH.Height          = 80;
  ButtonH.Pen_Width       = 0;
  ButtonH.Pen_Color       = 0x0000;
  ButtonH.Visible         = 1;
  ButtonH.Active          = 1;
  ButtonH.Transparent     = 1;
  ButtonH.Caption         = ButtonH_Caption;
  ButtonH.TextAlign       = _taCenter;
  ButtonH.FontName        = Tahoma23x29_Regular;
  ButtonH.PressColEnabled = 1;
  ButtonH.Font_Color      = 0xF79E;
  ButtonH.Gradient        = 0;
  ButtonH.Gradient_Orientation = 0;
  ButtonH.Gradient_Start_Color = 0x632C;
  ButtonH.Gradient_End_Color = 0x6304;
  ButtonH.Color           = 0x4229;
  ButtonH.Press_Color     = 0xE267;
  ButtonH.Corner_Radius   = 5;
  ButtonH.OnUpPtr         = 0;
  ButtonH.OnDownPtr       = 0;
  ButtonH.OnClickPtr      = SaveH;
  ButtonH.OnPressPtr      = 0;

  ButtonJ.OwnerScreen     = &Screen1;
  ButtonJ.Order           = 27;
  ButtonJ.Left            = 480;
  ButtonJ.Top             = 240;
  ButtonJ.Width           = 80;
  ButtonJ.Height          = 80;
  ButtonJ.Pen_Width       = 0;
  ButtonJ.Pen_Color       = 0x0000;
  ButtonJ.Visible         = 1;
  ButtonJ.Active          = 1;
  ButtonJ.Transparent     = 1;
  ButtonJ.Caption         = ButtonJ_Caption;
  ButtonJ.TextAlign       = _taCenter;
  ButtonJ.FontName        = Tahoma23x29_Regular;
  ButtonJ.PressColEnabled = 1;
  ButtonJ.Font_Color      = 0xF79E;
  ButtonJ.Gradient        = 0;
  ButtonJ.Gradient_Orientation = 0;
  ButtonJ.Gradient_Start_Color = 0x632C;
  ButtonJ.Gradient_End_Color = 0x6304;
  ButtonJ.Color           = 0x4229;
  ButtonJ.Press_Color     = 0xE267;
  ButtonJ.Corner_Radius   = 5;
  ButtonJ.OnUpPtr         = 0;
  ButtonJ.OnDownPtr       = 0;
  ButtonJ.OnClickPtr      = SaveJ;
  ButtonJ.OnPressPtr      = 0;

  ButtonK.OwnerScreen     = &Screen1;
  ButtonK.Order           = 28;
  ButtonK.Left            = 560;
  ButtonK.Top             = 240;
  ButtonK.Width           = 80;
  ButtonK.Height          = 80;
  ButtonK.Pen_Width       = 0;
  ButtonK.Pen_Color       = 0x0000;
  ButtonK.Visible         = 1;
  ButtonK.Active          = 1;
  ButtonK.Transparent     = 1;
  ButtonK.Caption         = ButtonK_Caption;
  ButtonK.TextAlign       = _taCenter;
  ButtonK.FontName        = Tahoma23x29_Regular;
  ButtonK.PressColEnabled = 1;
  ButtonK.Font_Color      = 0xF79E;
  ButtonK.Gradient        = 0;
  ButtonK.Gradient_Orientation = 0;
  ButtonK.Gradient_Start_Color = 0x632C;
  ButtonK.Gradient_End_Color = 0x6304;
  ButtonK.Color           = 0x4229;
  ButtonK.Press_Color     = 0xE267;
  ButtonK.Corner_Radius   = 5;
  ButtonK.OnUpPtr         = 0;
  ButtonK.OnDownPtr       = 0;
  ButtonK.OnClickPtr      = SaveK;
  ButtonK.OnPressPtr      = 0;

  ButtonL.OwnerScreen     = &Screen1;
  ButtonL.Order           = 29;
  ButtonL.Left            = 0;
  ButtonL.Top             = 320;
  ButtonL.Width           = 80;
  ButtonL.Height          = 80;
  ButtonL.Pen_Width       = 0;
  ButtonL.Pen_Color       = 0x0000;
  ButtonL.Visible         = 1;
  ButtonL.Active          = 1;
  ButtonL.Transparent     = 1;
  ButtonL.Caption         = ButtonL_Caption;
  ButtonL.TextAlign       = _taCenter;
  ButtonL.FontName        = Tahoma23x29_Regular;
  ButtonL.PressColEnabled = 1;
  ButtonL.Font_Color      = 0xF79E;
  ButtonL.Gradient        = 0;
  ButtonL.Gradient_Orientation = 0;
  ButtonL.Gradient_Start_Color = 0x632C;
  ButtonL.Gradient_End_Color = 0x6304;
  ButtonL.Color           = 0x4229;
  ButtonL.Press_Color     = 0xE267;
  ButtonL.Corner_Radius   = 5;
  ButtonL.OnUpPtr         = 0;
  ButtonL.OnDownPtr       = 0;
  ButtonL.OnClickPtr      = SaveL;
  ButtonL.OnPressPtr      = 0;

  ButtonBCK.OwnerScreen     = &Screen1;
  ButtonBCK.Order           = 30;
  ButtonBCK.Left            = 640;
  ButtonBCK.Top             = 240;
  ButtonBCK.Width           = 160;
  ButtonBCK.Height          = 80;
  ButtonBCK.Pen_Width       = 0;
  ButtonBCK.Pen_Color       = 0x0000;
  ButtonBCK.Visible         = 1;
  ButtonBCK.Active          = 1;
  ButtonBCK.Transparent     = 1;
  ButtonBCK.Caption         = ButtonBCK_Caption;
  ButtonBCK.TextAlign       = _taCenter;
  ButtonBCK.FontName        = Tahoma23x29_Regular;
  ButtonBCK.PressColEnabled = 1;
  ButtonBCK.Font_Color      = 0xF79E;
  ButtonBCK.Gradient        = 0;
  ButtonBCK.Gradient_Orientation = 0;
  ButtonBCK.Gradient_Start_Color = 0x632C;
  ButtonBCK.Gradient_End_Color = 0x6304;
  ButtonBCK.Color           = 0x39E8;
  ButtonBCK.Press_Color     = 0xE267;
  ButtonBCK.Corner_Radius   = 5;
  ButtonBCK.OnUpPtr         = 0;
  ButtonBCK.OnDownPtr       = 0;
  ButtonBCK.OnClickPtr      = SaveBCK;
  ButtonBCK.OnPressPtr      = 0;

  ButtonCR.OwnerScreen     = &Screen1;
  ButtonCR.Order           = 31;
  ButtonCR.Left            = 640;
  ButtonCR.Top             = 320;
  ButtonCR.Width           = 160;
  ButtonCR.Height          = 160;
  ButtonCR.Pen_Width       = 0;
  ButtonCR.Pen_Color       = 0x0000;
  ButtonCR.Visible         = 1;
  ButtonCR.Active          = 1;
  ButtonCR.Transparent     = 1;
  ButtonCR.Caption         = ButtonCR_Caption;
  ButtonCR.TextAlign       = _taCenter;
  ButtonCR.FontName        = Tahoma23x29_Regular;
  ButtonCR.PressColEnabled = 1;
  ButtonCR.Font_Color      = 0xF79E;
  ButtonCR.Gradient        = 0;
  ButtonCR.Gradient_Orientation = 0;
  ButtonCR.Gradient_Start_Color = 0x632C;
  ButtonCR.Gradient_End_Color = 0x6304;
  ButtonCR.Color           = 0x39E8;
  ButtonCR.Press_Color     = 0xE267;
  ButtonCR.Corner_Radius   = 5;
  ButtonCR.OnUpPtr         = 0;
  ButtonCR.OnDownPtr       = 0;
  ButtonCR.OnClickPtr      = SaveCR;
  ButtonCR.OnPressPtr      = 0;

  Box27.OwnerScreen     = &Screen1;
  Box27.Order           = 32;
  Box27.Left            = 5;
  Box27.Top             = 5;
  Box27.Width           = 150;
  Box27.Height          = 53;
  Box27.Pen_Width       = 1;
  Box27.Pen_Color       = 0x0000;
  Box27.Visible         = 0;
  Box27.Active          = 1;
  Box27.Transparent     = 1;
  Box27.Gradient        = 0;
  Box27.Gradient_Orientation = 0;
  Box27.Gradient_Start_Color = 0xFFFF;
  Box27.Gradient_End_Color = 0xC618;
  Box27.Color           = 0xC618;
  Box27.PressColEnabled = 1;
  Box27.Press_Color     = 0xE71C;
  Box27.OnUpPtr         = 0;
  Box27.OnDownPtr       = 0;
  Box27.OnClickPtr      = WiFiBackButton;
  Box27.OnPressPtr      = 0;

  Image28.OwnerScreen     = &Screen1;
  Image28.Order           = 33;
  Image28.Left            = 9;
  Image28.Top             = 17;
  Image28.Width           = 33;
  Image28.Height          = 33;
  Image28.Picture_Type    = 0;
  Image28.Picture_Ratio   = 1;
  Image28.Picture_Name    = icon_back_accel_bmp_1;
  Image28.Visible         = 1;
  Image28.Active          = 1;
  Image28.OnUpPtr         = 0;
  Image28.OnDownPtr       = 0;
  Image28.OnClickPtr      = WiFiBackButton;
  Image28.OnPressPtr      = 0;

  Label49.OwnerScreen     = &Screen1;
  Label49.Order           = 34;
  Label49.Left            = 47;
  Label49.Top             = 14;
  Label49.Width           = 51;
  Label49.Height          = 40;
  Label49.Visible         = 1;
  Label49.Active          = 1;
  Label49.Caption         = Label49_Caption;
  Label49.FontName        = Open_Sans_Light24x37_Regular;
  Label49.Font_Color      = 0xFFFF;
  Label49.OnUpPtr         = 0;
  Label49.OnDownPtr       = 0;
  Label49.OnClickPtr      = WiFiBackButton;
  Label49.OnPressPtr      = 0;

  ipLabel.OwnerScreen     = &Screen1;
  ipLabel.Order           = 35;
  ipLabel.Left            = 476;
  ipLabel.Top             = 17;
  ipLabel.Width           = 361;
  ipLabel.Height          = 27;
  ipLabel.Visible         = 1;
  ipLabel.Active          = 0;
  ipLabel.Caption         = ipLabel_Caption;
  ipLabel.FontName        = Tahoma20x24_Regular;
  ipLabel.Font_Color      = 0xF79E;
  ipLabel.OnUpPtr         = 0;
  ipLabel.OnDownPtr       = 0;
  ipLabel.OnClickPtr      = 0;
  ipLabel.OnPressPtr      = 0;

  ButtonSPC.OwnerScreen     = &Screen1;
  ButtonSPC.Order           = 36;
  ButtonSPC.Left            = 80;
  ButtonSPC.Top             = 400;
  ButtonSPC.Width           = 560;
  ButtonSPC.Height          = 80;
  ButtonSPC.Pen_Width       = 0;
  ButtonSPC.Pen_Color       = 0x0000;
  ButtonSPC.Visible         = 1;
  ButtonSPC.Active          = 1;
  ButtonSPC.Transparent     = 1;
  ButtonSPC.Caption         = ButtonSPC_Caption;
  ButtonSPC.TextAlign       = _taCenter;
  ButtonSPC.FontName        = Tahoma23x29_Regular;
  ButtonSPC.PressColEnabled = 1;
  ButtonSPC.Font_Color      = 0xF79E;
  ButtonSPC.Gradient        = 0;
  ButtonSPC.Gradient_Orientation = 0;
  ButtonSPC.Gradient_Start_Color = 0x632C;
  ButtonSPC.Gradient_End_Color = 0x6304;
  ButtonSPC.Color           = 0x39E8;
  ButtonSPC.Press_Color     = 0xE267;
  ButtonSPC.Corner_Radius   = 5;
  ButtonSPC.OnUpPtr         = 0;
  ButtonSPC.OnDownPtr       = 0;
  ButtonSPC.OnClickPtr      = SaveSPC;
  ButtonSPC.OnPressPtr      = 0;

  ButtonCLRSCR.OwnerScreen     = &Screen1;
  ButtonCLRSCR.Order           = 37;
  ButtonCLRSCR.Left            = 0;
  ButtonCLRSCR.Top             = 400;
  ButtonCLRSCR.Width           = 80;
  ButtonCLRSCR.Height          = 80;
  ButtonCLRSCR.Pen_Width       = 0;
  ButtonCLRSCR.Pen_Color       = 0x0000;
  ButtonCLRSCR.Visible         = 1;
  ButtonCLRSCR.Active          = 1;
  ButtonCLRSCR.Transparent     = 1;
  ButtonCLRSCR.Caption         = ButtonCLRSCR_Caption;
  ButtonCLRSCR.TextAlign       = _taCenter;
  ButtonCLRSCR.FontName        = Tahoma23x29_Regular;
  ButtonCLRSCR.PressColEnabled = 1;
  ButtonCLRSCR.Font_Color      = 0xF79E;
  ButtonCLRSCR.Gradient        = 0;
  ButtonCLRSCR.Gradient_Orientation = 0;
  ButtonCLRSCR.Gradient_Start_Color = 0x632C;
  ButtonCLRSCR.Gradient_End_Color = 0x6304;
  ButtonCLRSCR.Color           = 0x4229;
  ButtonCLRSCR.Press_Color     = 0xE267;
  ButtonCLRSCR.Corner_Radius   = 5;
  ButtonCLRSCR.OnUpPtr         = 0;
  ButtonCLRSCR.OnDownPtr       = 0;
  ButtonCLRSCR.OnClickPtr      = ClrScr;
  ButtonCLRSCR.OnPressPtr      = 0;
}

static char IsInsideObject (unsigned int X, unsigned int Y, unsigned int Left, unsigned int Top, unsigned int Width, unsigned int Height) { // static
  if ( (Left<= X) && (Left+ Width - 1 >= X) &&
       (Top <= Y)  && (Top + Height - 1 >= Y) )
    return 1;
  else
    return 0;
}


#define GetButton(index)              CurrentScreen->Buttons[index]
#define GetRoundButton(index)         CurrentScreen->Buttons_Round[index]
#define GetCRoundButton(index)        CurrentScreen->CButtons_Round[index]
#define GetLabel(index)               CurrentScreen->Labels[index]
#define GetImage(index)               CurrentScreen->Images[index]
#define GetCircle(index)              CurrentScreen->Circles[index]
#define GetBox(index)                 CurrentScreen->Boxes[index]
#define GetBox_Round(index)           CurrentScreen->Boxes_Round[index]
#define GetCheckBox(index)            CurrentScreen->CheckBoxes[index]
#define GetRadioButton(index)         CurrentScreen->RadioButtons[index]


void DrawButton(TButton *Abutton) {
  if (Abutton->Visible == 1) {
    if (object_pressed == 1) {
      object_pressed = 0;
      TFT_Set_Brush(Abutton->Transparent, Abutton->Press_Color, Abutton->Gradient, Abutton->Gradient_Orientation, Abutton->Gradient_End_Color, Abutton->Gradient_Start_Color);
    }
    else {
      TFT_Set_Brush(Abutton->Transparent, Abutton->Color, Abutton->Gradient, Abutton->Gradient_Orientation, Abutton->Gradient_Start_Color, Abutton->Gradient_End_Color);
    }
    TFT_Set_Pen(Abutton->Pen_Color, Abutton->Pen_Width);
    TFT_Rectangle(Abutton->Left, Abutton->Top, Abutton->Left + Abutton->Width - 1, Abutton->Top + Abutton->Height - 1);
    TFT_Set_Font(Abutton->FontName, Abutton->Font_Color, FO_HORIZONTAL);
    TFT_Write_Text_Return_Pos(Abutton->Caption, Abutton->Left, Abutton->Top);
    if (Abutton->TextAlign == _taLeft)
      TFT_Write_Text(Abutton->Caption, Abutton->Left + 4, (Abutton->Top + ((Abutton->Height - caption_height) / 2)));
    else if (Abutton->TextAlign == _taCenter)
      TFT_Write_Text(Abutton->Caption, (Abutton->Left + (Abutton->Width - caption_length) / 2), (Abutton->Top + ((Abutton->Height - caption_height) / 2)));
    else if (Abutton->TextAlign == _taRight)
      TFT_Write_Text(Abutton->Caption, Abutton->Left + (Abutton->Width - caption_length - 4), (Abutton->Top + (Abutton->Height - caption_height) / 2));
  }
}

void DrawRoundButton(TButton_Round *Around_button) {
    if (Around_button->Visible == 1) {
      if (object_pressed == 1) {
        object_pressed = 0;
        TFT_Set_Brush(Around_button->Transparent, Around_button->Press_Color, Around_button->Gradient, Around_button->Gradient_Orientation,
                      Around_button->Gradient_End_Color, Around_button->Gradient_Start_Color);
      }
      else {
        TFT_Set_Brush(Around_button->Transparent, Around_button->Color, Around_button->Gradient, Around_button->Gradient_Orientation,
                      Around_button->Gradient_Start_Color, Around_button->Gradient_End_Color);
      }
      TFT_Set_Pen(Around_button->Pen_Color, Around_button->Pen_Width);
      TFT_Rectangle_Round_Edges(Around_button->Left + 1, Around_button->Top + 1,
        Around_button->Left + Around_button->Width - 2,
        Around_button->Top + Around_button->Height - 2, Around_button->Corner_Radius);
      TFT_Set_Font(Around_button->FontName, Around_button->Font_Color, FO_HORIZONTAL);
      TFT_Write_Text_Return_Pos(Around_button->Caption, Around_button->Left, Around_button->Top);
      if (Around_button->TextAlign == _taLeft)
        TFT_Write_Text(Around_button->Caption, Around_button->Left + 4, (Around_button->Top + ((Around_button->Height - caption_height) / 2)));
      else if (Around_button->TextAlign == _taCenter)
        TFT_Write_Text(Around_button->Caption, (Around_button->Left + (Around_button->Width - caption_length) / 2), (Around_button->Top + ((Around_button->Height - caption_height) / 2)));
      else if (Around_button->TextAlign == _taRight)
        TFT_Write_Text(Around_button->Caption, Around_button->Left + (Around_button->Width - caption_length - 4), (Around_button->Top + (Around_button->Height - caption_height) / 2));
    }
}

void DrawCRoundButton(TCButton_Round *Around_button) {
    if (Around_button->Visible == 1) {
      if (object_pressed == 1) {
        object_pressed = 0;
        TFT_Set_Brush(Around_button->Transparent, Around_button->Press_Color, Around_button->Gradient, Around_button->Gradient_Orientation,
                      Around_button->Gradient_End_Color, Around_button->Gradient_Start_Color);
      }
      else {
        TFT_Set_Brush(Around_button->Transparent, Around_button->Color, Around_button->Gradient, Around_button->Gradient_Orientation,
                      Around_button->Gradient_Start_Color, Around_button->Gradient_End_Color);
      }
      TFT_Set_Pen(Around_button->Pen_Color, Around_button->Pen_Width);
      TFT_Rectangle_Round_Edges(Around_button->Left + 1, Around_button->Top + 1,
        Around_button->Left + Around_button->Width - 2,
        Around_button->Top + Around_button->Height - 2, Around_button->Corner_Radius);
      TFT_Set_Font(Around_button->FontName, Around_button->Font_Color, FO_HORIZONTAL);
      TFT_Write_Text_Return_Pos(Around_button->Caption, Around_button->Left, Around_button->Top);
      if (Around_button->TextAlign == _taLeft)
        TFT_Write_Text(Around_button->Caption, Around_button->Left + 4, (Around_button->Top + ((Around_button->Height - caption_height) / 2)));
      else if (Around_button->TextAlign == _taCenter)
        TFT_Write_Text(Around_button->Caption, (Around_button->Left + (Around_button->Width - caption_length) / 2), (Around_button->Top + ((Around_button->Height - caption_height) / 2)));
      else if (Around_button->TextAlign == _taRight)
        TFT_Write_Text(Around_button->Caption, Around_button->Left + (Around_button->Width - caption_length - 4), (Around_button->Top + (Around_button->Height - caption_height) / 2));
    }
}

void DrawLabel(TLabel *ALabel) {
  if (ALabel->Visible == 1) {
    TFT_Set_Font(ALabel->FontName, ALabel->Font_Color, FO_HORIZONTAL);
    TFT_Write_Text(ALabel->Caption, ALabel->Left, ALabel->Top);
  }
}

void DrawImage(TImage *AImage) {
  if (AImage->Visible) {
    TFT_Image(AImage->Left, AImage->Top, AImage->Picture_Name, AImage->Picture_Ratio);
  }
}

void DrawCircle(TCircle *ACircle) {
  if (ACircle->Visible == 1) {
    if (object_pressed == 1) {
      object_pressed = 0;
      TFT_Set_Brush(ACircle->Transparent, ACircle->Press_Color, ACircle->Gradient, ACircle->Gradient_Orientation,
                    ACircle->Gradient_End_Color, ACircle->Gradient_Start_Color);
    }
    else {
      TFT_Set_Brush(ACircle->Transparent, ACircle->Color, ACircle->Gradient, ACircle->Gradient_Orientation,
                    ACircle->Gradient_Start_Color, ACircle->Gradient_End_Color);
    }
    TFT_Set_Pen(ACircle->Pen_Color, ACircle->Pen_Width);
    TFT_Circle(ACircle->Left + ACircle->Radius,
               ACircle->Top + ACircle->Radius,
               ACircle->Radius);
  }
}

void DrawBox(TBox *ABox) {
  if (ABox->Visible == 1) {
    if (object_pressed == 1) {
      object_pressed = 0;
      TFT_Set_Brush(ABox->Transparent, ABox->Press_Color, ABox->Gradient, ABox->Gradient_Orientation, ABox->Gradient_End_Color, ABox->Gradient_Start_Color);
    }
    else {
      TFT_Set_Brush(ABox->Transparent, ABox->Color, ABox->Gradient, ABox->Gradient_Orientation, ABox->Gradient_Start_Color, ABox->Gradient_End_Color);
    }
    TFT_Set_Pen(ABox->Pen_Color, ABox->Pen_Width);
    TFT_Rectangle(ABox->Left, ABox->Top, ABox->Left + ABox->Width - 1, ABox->Top + ABox->Height - 1);
  }
}

void DrawRoundBox(TBox_Round *Around_box) {
    if (Around_box->Visible == 1) {
      if (object_pressed == 1) {
        object_pressed = 0;
        TFT_Set_Brush(Around_box->Transparent, Around_box->Press_Color, Around_box->Gradient, Around_box->Gradient_Orientation,
                      Around_box->Gradient_End_Color, Around_box->Gradient_Start_Color);
      }
      else {
        TFT_Set_Brush(Around_box->Transparent, Around_box->Color, Around_box->Gradient, Around_box->Gradient_Orientation,
                      Around_box->Gradient_Start_Color, Around_box->Gradient_End_Color);
      }
      TFT_Set_Pen(Around_box->Pen_Color, Around_box->Pen_Width);
      TFT_Rectangle_Round_Edges(Around_box->Left + 1, Around_box->Top + 1,
        Around_box->Left + Around_box->Width - 2,
        Around_box->Top + Around_box->Height - 2, Around_box->Corner_Radius);
    }
}

void DrawCheckBox(TCheckBox *ACheckBox) {
  if (ACheckBox->Visible == 1) {
    if (object_pressed == 1) {
      object_pressed = 0;
      TFT_Set_Brush(ACheckBox->Transparent, ACheckBox->Press_Color, ACheckBox->Gradient, ACheckBox->Gradient_Orientation, ACheckBox->Gradient_End_Color, ACheckBox->Gradient_Start_Color);
    }
    else {
      TFT_Set_Brush(ACheckBox->Transparent, ACheckBox->Color, ACheckBox->Gradient, ACheckBox->Gradient_Orientation, ACheckBox->Gradient_Start_Color, ACheckBox->Gradient_End_Color);
    }
    TFT_Set_Pen(ACheckBox->Pen_Color, ACheckBox->Pen_Width);
    TFT_Set_Font(ACheckBox->FontName, ACheckBox->Font_Color, FO_HORIZONTAL);
    if (ACheckBox->TextAlign == _taLeft) {
      if (ACheckBox->Rounded == 1)
        TFT_Rectangle_Round_Edges(ACheckBox->Left, ACheckBox->Top, ACheckBox->Left + ACheckBox->Height, ACheckBox->Top + ACheckBox->Height - 1, ACheckBox->Corner_Radius);
      else
        TFT_Rectangle(ACheckBox->Left, ACheckBox->Top, ACheckBox->Left + ACheckBox->Height, ACheckBox->Top + ACheckBox->Height - 1);
      if (ACheckBox->Checked == 1) {
        TFT_Set_Pen(ACheckBox->Pen_Color, ACheckBox->Height / 8);
        TFT_Line(ACheckBox->Left  + ACheckBox->Height / 5 + 1,
                               ACheckBox->Top   + ACheckBox->Height / 2 + 1,
                               ACheckBox->Left  + ACheckBox->Height / 2 - 1,
                               ACheckBox->Top   + ACheckBox->Height - ACheckBox->Height / 5 - 1);
        TFT_Line(ACheckBox->Left  + ACheckBox->Height / 2 - ACheckBox->Pen_Width + 1,
                               ACheckBox->Top   + ACheckBox->Height -  ACheckBox->Height / 5 - 1,
                               ACheckBox->Left  + ACheckBox->Height - ACheckBox->Height / 5 - 1,
                               ACheckBox->Top   + ACheckBox->Height / 5 + 1);
      }
      TFT_Write_Text_Return_Pos(ACheckBox->Caption, ACheckBox->Left + ACheckBox->Width / 4 + 3, ACheckBox->Top);
      TFT_Write_Text(ACheckBox->Caption, ACheckBox->Left + ACheckBox->Height + 3, (ACheckBox->Top + ((ACheckBox->Height - caption_height) / 2)));
    }
    else if (ACheckBox->TextAlign == _taRight) {
      if (ACheckBox->Rounded == 1)
        TFT_Rectangle_Round_Edges(ACheckBox->Left + ACheckBox->Width - ACheckBox->Height  , ACheckBox->Top, ACheckBox->Left + ACheckBox->Width, ACheckBox->Top + ACheckBox->Height - 1, ACheckBox->Corner_Radius);
      else
        TFT_Rectangle(ACheckBox->Left + ACheckBox->Width - ACheckBox->Height  , ACheckBox->Top, ACheckBox->Left + ACheckBox->Width, ACheckBox->Top + ACheckBox->Height - 1);
      if (ACheckBox->Checked == 1) {
        TFT_Set_Pen(ACheckBox->Pen_Color, ACheckBox->Height / 8);
        TFT_Line(ACheckBox->Left  + ACheckBox->Width - ACheckBox->Height + ACheckBox->Height / 5 + 1,
                               ACheckBox->Top +  ACheckBox->Height / 2 + 1,
                               ACheckBox->Left + ACheckBox->Width  - ACheckBox->Height /2 - 1,
                               ACheckBox->Top   + ACheckBox->Height - ACheckBox->Height / 5 - 1);
        TFT_Line(ACheckBox->Left + ACheckBox->Width  - ACheckBox->Height /2 + 1,
                               ACheckBox->Top   + ACheckBox->Height -  ACheckBox->Height / 5 - 1,
                               ACheckBox->Left + ACheckBox->Width  - ACheckBox->Height / 5 - 1,
                               ACheckBox->Top   + ACheckBox->Height / 5 + 1);
      }
      TFT_Write_Text_Return_Pos(ACheckBox->Caption, ACheckBox->Left + 3, ACheckBox->Top);
      TFT_Write_Text(ACheckBox->Caption, ACheckBox->Left + 3, ACheckBox->Top + (ACheckBox->Height - caption_height) / 2);
    }
  }
}

void DrawRadioButton(TRadioButton *ARadioButton) {
  int circleOffset = 0;
  if (ARadioButton->Visible == 1) {
    circleOffset = ARadioButton->Height / 5;
    TFT_Set_Pen(ARadioButton->Pen_Color, ARadioButton->Pen_Width);
    TFT_Set_Font(ARadioButton->FontName, ARadioButton->Font_Color, FO_HORIZONTAL);
    if (ARadioButton->TextAlign == _taLeft) {
      TFT_Set_Brush(ARadioButton->Transparent,ARadioButton->Background_Color,0,0,0,0);
      TFT_Circle(ARadioButton->Left + ARadioButton->Height / 2, ARadioButton->Top + ARadioButton->Height / 2, ARadioButton->Height / 2);
      if (ARadioButton->Checked == 1) {
        if (object_pressed == 1) {
          object_pressed = 0;
          TFT_Set_Brush(ARadioButton->Transparent, ARadioButton->Press_Color, ARadioButton->Gradient, ARadioButton->Gradient_Orientation, ARadioButton->Gradient_End_Color, ARadioButton->Gradient_Start_Color);
        } else
          TFT_Set_Brush(ARadioButton->Transparent, ARadioButton->Color, ARadioButton->Gradient, ARadioButton->Gradient_Orientation, ARadioButton->Gradient_Start_Color, ARadioButton->Gradient_End_Color);
        TFT_Circle(ARadioButton->Left + ARadioButton->Height / 2 , ARadioButton->Top + ARadioButton->Height / 2, ARadioButton->Height / 2 - circleOffset);
      }
      TFT_Write_Text_Return_Pos(ARadioButton->Caption, ARadioButton->Left + ARadioButton->Height + 4, ARadioButton->Top);
      TFT_Write_Text(ARadioButton->Caption, ARadioButton->Left + ARadioButton->Height + 4, (ARadioButton->Top + ((ARadioButton->Height - caption_height) / 2)));
    } else {
      TFT_Set_Brush(ARadioButton->Transparent,ARadioButton->Background_Color,0,0,0,0);
      TFT_Circle(ARadioButton->Left  + ARadioButton->Width - ARadioButton->Height / 2, ARadioButton->Top + ARadioButton->Height / 2, ARadioButton->Height / 2);
      if (ARadioButton->Checked == 1) {
        if (object_pressed == 1) {
          object_pressed = 0;
          TFT_Set_Brush(ARadioButton->Transparent, ARadioButton->Press_Color, ARadioButton->Gradient, ARadioButton->Gradient_Orientation, ARadioButton->Gradient_End_Color, ARadioButton->Gradient_Start_Color);
        } else
          TFT_Set_Brush(ARadioButton->Transparent, ARadioButton->Color, ARadioButton->Gradient, ARadioButton->Gradient_Orientation, ARadioButton->Gradient_Start_Color, ARadioButton->Gradient_End_Color);
        TFT_Circle(ARadioButton->Left  + ARadioButton->Width - ARadioButton->Height / 2, ARadioButton->Top + ARadioButton->Height / 2, ARadioButton->Height / 2 - circleOffset);
      }
      TFT_Write_Text_Return_Pos(ARadioButton->Caption, ARadioButton->Left + 3, ARadioButton->Top);
      TFT_Write_Text(ARadioButton->Caption, ARadioButton->Left + 3, ARadioButton->Top + (ARadioButton->Height - caption_height) / 2);
    }
  }
}

void DrawScreen(TScreen *aScreen) {
 unsigned int order;
  unsigned short button_idx;
  TButton *local_button;
  unsigned short round_button_idx;
  TButton_Round *local_round_button;
  unsigned short round_cbutton_idx;
  TCButton_Round *local_round_cbutton;
  unsigned short label_idx;
  TLabel *local_label;
  unsigned short image_idx;
  TImage *local_image;
  unsigned short circle_idx;
  TCircle *local_circle;
  unsigned short box_idx;
  TBox *local_box;
  unsigned short round_box_idx;
  TBox_Round *local_round_box;
  unsigned short checkbox_idx;
  TCheckBox *local_checkbox;
  unsigned short radio_button_idx;
  TRadioButton *local_radio_button;
  char save_bled, save_bled_direction;

  object_pressed = 0;
  order = 0;
  button_idx = 0;
  round_button_idx = 0;
  round_cbutton_idx = 0;
  label_idx = 0;
  image_idx = 0;
  circle_idx = 0;
  box_idx = 0;
  round_box_idx = 0;
  checkbox_idx = 0;
  radio_button_idx = 0;
  CurrentScreen = aScreen;

  if ((display_width != CurrentScreen->Width) || (display_height != CurrentScreen->Height)) {
    save_bled = TFT_BLED;
    TFT_BLED           = 0;
    TFT_Set_Active(Set_Index, Write_Command, Write_Data);
    TFT_Init_SSD1963_7Inch_800x480(CurrentScreen->Width, CurrentScreen->Height);
    STMPE610_SetSize(CurrentScreen->Width, CurrentScreen->Height);
    TFT_Fill_Screen(CurrentScreen->Color);
    TFT_Set_DBC_SSD1963(255);
    display_width = CurrentScreen->Width;
    display_height = CurrentScreen->Height;
    TFT_BLED           = save_bled;
  }
  else
    TFT_Fill_Screen(CurrentScreen->Color);


  while (order < CurrentScreen->ObjectsCount) {
    if (button_idx < CurrentScreen->ButtonsCount) {
      local_button = GetButton(button_idx);
      if (order == local_button->Order) {
        button_idx++;
        order++;
        DrawButton(local_button);
      }
    }

    if (round_button_idx < CurrentScreen->Buttons_RoundCount) {
      local_round_button = GetRoundButton(round_button_idx);
      if (order == local_round_button->Order) {
        round_button_idx++;
        order++;
        DrawRoundButton(local_round_button);
      }
    }

    if (round_cbutton_idx < CurrentScreen->CButtons_RoundCount) {
      local_round_cbutton = GetCRoundButton(round_cbutton_idx);
      if (order == local_round_cbutton->Order) {
        round_cbutton_idx++;
        order++;
        DrawCRoundButton(local_round_cbutton);
      }
    }

    if (label_idx < CurrentScreen->LabelsCount) {
      local_label = GetLabel(label_idx);
      if (order == local_label->Order) {
        label_idx++;
        order++;
        DrawLabel(local_label);
      }
    }

    if (circle_idx < CurrentScreen->CirclesCount) {
      local_circle = GetCircle(circle_idx);
      if (order == local_circle->Order) {
        circle_idx++;
        order++;
        DrawCircle(local_circle);
      }
    }

    if (box_idx < CurrentScreen->BoxesCount) {
      local_box = GetBox(box_idx);
      if (order == local_box->Order) {
        box_idx++;
        order++;
        DrawBox(local_box);
      }
    }

    if (round_box_idx < CurrentScreen->Boxes_RoundCount) {
      local_round_box = GetBox_Round(round_box_idx);
      if (order == local_round_box->Order) {
        round_box_idx++;
        order++;
        DrawRoundBox(local_round_box);
      }
    }

    if (image_idx < CurrentScreen->ImagesCount) {
      local_image = GetImage(image_idx);
      if (order == local_image->Order) {
        image_idx++;
        order++;
        DrawImage(local_image);
      }
    }

    if (checkbox_idx < CurrentScreen->CheckBoxesCount) {
      local_checkbox = GetCheckBox(checkbox_idx);
      if (order == local_checkbox->Order) {
        checkbox_idx++;
        order++;
        DrawCheckBox(local_checkbox);
      }
    }

    if (radio_button_idx < CurrentScreen->RadioButtonsCount) {
      local_radio_button = GetRadioButton(radio_button_idx);
      if (order == local_radio_button->Order) {
        radio_button_idx++;
        order++;
        DrawRadioButton(local_radio_button);
      }
    }

  }
}

void Get_Object(unsigned int X, unsigned int Y) {
  button_order        = -1;
  round_button_order  = -1;
  round_cbutton_order = -1;
  label_order         = -1;
  image_order         = -1;
  circle_order        = -1;
  box_order           = -1;
  box_round_order     = -1;
  checkbox_order      = -1;
  radio_button_order  = -1;
  //  Buttons
  for ( _object_count = 0 ; _object_count < CurrentScreen->ButtonsCount ; _object_count++ ) {
    local_button = GetButton(_object_count);
    if (local_button->Active == 1) {
      if (IsInsideObject(X, Y, local_button->Left, local_button->Top,
                         local_button->Width, local_button->Height) == 1) {
        button_order = local_button->Order;
        exec_button = local_button;
      }
    }
  }

  //  Buttons with Round Edges
  for ( _object_count = 0 ; _object_count < CurrentScreen->Buttons_RoundCount ; _object_count++ ) {
    local_round_button = GetRoundButton(_object_count);
    if (local_round_button->Active == 1) {
      if (IsInsideObject(X, Y, local_round_button->Left, local_round_button->Top,
                         local_round_button->Width, local_round_button->Height) == 1) {
        round_button_order = local_round_button->Order;
        exec_round_button = local_round_button;
      }
    }
  }

  //  CButtons with Round Edges
  for ( _object_count = 0 ; _object_count < CurrentScreen->CButtons_RoundCount ; _object_count++ ) {
    local_round_cbutton = GetCRoundButton(_object_count);
    if (local_round_cbutton->Active == 1) {
      if (IsInsideObject(X, Y, local_round_cbutton->Left, local_round_cbutton->Top,
                         local_round_cbutton->Width, local_round_cbutton->Height) == 1) {
        round_cbutton_order = local_round_cbutton->Order;
        exec_round_cbutton = local_round_cbutton;
      }
    }
  }

  //  Labels
  for ( _object_count = 0 ; _object_count < CurrentScreen->LabelsCount ; _object_count++ ) {
    local_label = GetLabel(_object_count);
    if (local_label->Active == 1) {
      if (IsInsideObject(X, Y, local_label->Left, local_label->Top,
                         local_label->Width, local_label->Height) == 1) {
        label_order = local_label->Order;
        exec_label = local_label;
      }
    }
  }

  //  Images
  for ( _object_count = 0 ; _object_count < CurrentScreen->ImagesCount ; _object_count++ ) {
    local_image = GetImage(_object_count);
    if (local_image->Active == 1) {
      if (IsInsideObject(X, Y, local_image->Left, local_image->Top,
                         local_image->Width, local_image->Height) == 1) {
        image_order = local_image->Order;
        exec_image = local_image;
      }
    }
  }

  //  Circles
  for ( _object_count = 0 ; _object_count < CurrentScreen->CirclesCount ; _object_count++ ) {
    local_circle = GetCircle(_object_count);
    if (local_circle->Active == 1) {
      if (IsInsideObject(X, Y, local_circle->Left, local_circle->Top,
                        (local_circle->Radius * 2), (local_circle->Radius * 2)) == 1) {
        circle_order = local_circle->Order;
        exec_circle = local_circle;
      }
    }
  }

  //  Boxes
  for ( _object_count = 0 ; _object_count < CurrentScreen->BoxesCount ; _object_count++ ) {
    local_box = GetBox(_object_count);
    if (local_box->Active == 1) {
      if (IsInsideObject(X, Y, local_box->Left, local_box->Top,
                         local_box->Width, local_box->Height) == 1) {
        box_order = local_box->Order;
        exec_box = local_box;
      }
    }
  }

  //  Boxes with Round Edges
  for ( _object_count = 0 ; _object_count < CurrentScreen->Boxes_RoundCount ; _object_count++ ) {
    local_round_box = GetBox_Round(_object_count);
    if (local_round_box->Active == 1) {
      if (IsInsideObject(X, Y, local_round_box->Left, local_round_box->Top,
                         local_round_box->Width, local_round_box->Height) == 1) {
        box_round_order = local_round_box->Order;
        exec_round_box = local_round_box;
      }
    }
  }

  // CheckBoxes
  for ( _object_count = 0 ; _object_count < CurrentScreen->CheckBoxesCount ; _object_count++ ) {
    local_checkbox = GetCheckBox(_object_count);
    if (local_checkbox->Active == 1) {
      if (IsInsideObject(X, Y, local_checkbox->Left, local_checkbox->Top,
                         local_checkbox->Width, local_checkbox->Height) == 1) {
        checkbox_order = local_checkbox->Order;
        exec_checkbox = local_checkbox;
      }
    }
  }

  // RadioButtons
  for ( _object_count = 0 ; _object_count < CurrentScreen->RadioButtonsCount ; _object_count++ ) {
    local_radio_button = GetRadioButton(_object_count);
    if (local_radio_button->Active == 1) {
      if (IsInsideObject(X, Y, local_radio_button->Left, local_radio_button->Top,
                         local_radio_button->Width, local_radio_button->Height) == 1) {
        radio_button_order = local_radio_button->Order;
        exec_radio_button = local_radio_button;
      }
    }
  }

  _object_count = -1;
  if (button_order >  _object_count )
    _object_count = button_order;
  if (round_button_order >  _object_count )
    _object_count = round_button_order;
  if (round_cbutton_order >  _object_count )
    _object_count = round_cbutton_order;
  if (label_order >  _object_count )
    _object_count = label_order;
  if (image_order >  _object_count )
    _object_count = image_order;
  if (circle_order >  _object_count )
    _object_count = circle_order;
  if (box_order >  _object_count )
    _object_count = box_order;
  if (box_round_order >  _object_count )
    _object_count = box_round_order;
  if (checkbox_order >  _object_count )
    _object_count = checkbox_order;
  if (radio_button_order >  _object_count )
    _object_count = radio_button_order;
}


void Process_TP_Press(unsigned int X, unsigned int Y) {
  exec_button         = 0;
  exec_round_button   = 0;
  exec_round_cbutton  = 0;
  exec_label          = 0;
  exec_image          = 0;
  exec_circle         = 0;
  exec_box            = 0;
  exec_round_box      = 0;
  exec_checkbox       = 0;
  exec_radio_button   = 0;

  Get_Object(X, Y);

  if (_object_count != -1) {
    if (_object_count == button_order) {
      if (exec_button->Active == 1) {
        if (exec_button->OnPressPtr != 0) {
          exec_button->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == round_button_order) {
      if (exec_round_button->Active == 1) {
        if (exec_round_button->OnPressPtr != 0) {
          exec_round_button->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == round_cbutton_order) {
      if (exec_round_cbutton->Active == 1) {
        if (exec_round_cbutton->OnPressPtr != 0) {
          exec_round_cbutton->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == label_order) {
      if (exec_label->Active == 1) {
        if (exec_label->OnPressPtr != 0) {
          exec_label->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == image_order) {
      if (exec_image->Active == 1) {
        if (exec_image->OnPressPtr != 0) {
          exec_image->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == circle_order) {
      if (exec_circle->Active == 1) {
        if (exec_circle->OnPressPtr != 0) {
          exec_circle->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == box_order) {
      if (exec_box->Active == 1) {
        if (exec_box->OnPressPtr != 0) {
          exec_box->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == box_round_order) {
      if (exec_round_box->Active == 1) {
        if (exec_round_box->OnPressPtr != 0) {
          exec_round_box->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == checkbox_order) {
      if (exec_checkbox->Active == 1) {
        if (exec_checkbox->OnPressPtr != 0) {
          exec_checkbox->OnPressPtr();
          return;
        }
      }
    }

    if (_object_count == radio_button_order) {
      if (exec_radio_button->Active == 1) {
        if (exec_radio_button->OnPressPtr != 0) {
          exec_radio_button->OnPressPtr();
          return;
        }
      }
    }

  }
}

void Process_TP_Up(unsigned int X, unsigned int Y) {

  switch (PressedObjectType) {
    // Button
    case 0: {
      if (PressedObject != 0) {
        exec_button = (TButton*)PressedObject;
        if ((exec_button->PressColEnabled == 1) && (exec_button->OwnerScreen == CurrentScreen)) {
          DrawButton(exec_button);
        }
        break;
      }
      break;
    }
    // Round Button
    case 1: {
      if (PressedObject != 0) {
        exec_round_button = (TButton_Round*)PressedObject;
        if ((exec_round_button->PressColEnabled == 1) && (exec_round_button->OwnerScreen == CurrentScreen)) {
          DrawRoundButton(exec_round_button);
        }
        break;
      }
      break;
    }
    // Round CButton
    case 9: {
      if (PressedObject != 0) {
        exec_round_cbutton = (TCButton_Round*)PressedObject;
        if ((exec_round_cbutton->PressColEnabled == 1) && (exec_round_cbutton->OwnerScreen == CurrentScreen)) {
          DrawCRoundButton(exec_round_cbutton);
        }
        break;
      }
      break;
    }
    // Circle
    case 4: {
      if (PressedObject != 0) {
        exec_circle = (TCircle*)PressedObject;
        if ((exec_circle->PressColEnabled == 1) && (exec_circle->OwnerScreen == CurrentScreen)) {
          DrawCircle(exec_circle);
        }
        break;
      }
      break;
    }
    // Box
    case 6: {
      if (PressedObject != 0) {
        exec_box = (TBox*)PressedObject;
        if ((exec_box->PressColEnabled == 1) && (exec_box->OwnerScreen == CurrentScreen)) {
          DrawBox(exec_box);
        }
        break;
      }
      break;
    }
    // Round Box
    case 7: {
      if (PressedObject != 0) {
        exec_round_box = (TBox_Round*)PressedObject;
        if ((exec_round_box->PressColEnabled == 1) && (exec_round_box->OwnerScreen == CurrentScreen)) {
          DrawRoundBox(exec_round_box);
        }
        break;
      }
      break;
    }
    // Check Box
    case 16: {
      if (PressedObject != 0) {
        exec_checkbox = (TCheckBox*)PressedObject;
        break;
      }
      break;
    }
    // Radio Button
    case 17: {
      if (PressedObject != 0) {
        exec_radio_button = (TRadioButton*)PressedObject;
        if ((exec_radio_button->PressColEnabled == 1) && (exec_radio_button->OwnerScreen == CurrentScreen)) {
          DrawRadioButton(exec_radio_button);
        }
        break;
      }
      break;
    }
  }

  exec_label          = 0;
  exec_image          = 0;

  Get_Object(X, Y);


  if (_object_count != -1) {
  // Buttons
    if (_object_count == button_order) {
      if (exec_button->Active == 1) {
        if (exec_button->OnUpPtr != 0)
          exec_button->OnUpPtr();
        if (PressedObject == (TPointer)exec_button)
          if (exec_button->OnClickPtr != 0)
            exec_button->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Buttons with Round Edges
    if (_object_count == round_button_order) {
      if (exec_round_button->Active == 1) {
        if (exec_round_button->OnUpPtr != 0)
          exec_round_button->OnUpPtr();
        if (PressedObject == (TPointer)exec_round_button)
          if (exec_round_button->OnClickPtr != 0)
            exec_round_button->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // CButtons with Round Edges
    if (_object_count == round_cbutton_order) {
      if (exec_round_cbutton->Active == 1) {
        if (exec_round_cbutton->OnUpPtr != 0)
          exec_round_cbutton->OnUpPtr();
        if (PressedObject == (TPointer)exec_round_cbutton)
          if (exec_round_cbutton->OnClickPtr != 0)
            exec_round_cbutton->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Labels
    if (_object_count == label_order) {
      if (exec_label->Active == 1) {
        if (exec_label->OnUpPtr != 0)
          exec_label->OnUpPtr();
        if (PressedObject == (TPointer)exec_label)
          if (exec_label->OnClickPtr != 0)
            exec_label->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Images
    if (_object_count == image_order) {
      if (exec_image->Active == 1) {
        if (exec_image->OnUpPtr != 0)
          exec_image->OnUpPtr();
        if (PressedObject == (TPointer)exec_image)
          if (exec_image->OnClickPtr != 0)
            exec_image->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Circles
    if (_object_count == circle_order) {
      if (exec_circle->Active == 1) {
        if (exec_circle->OnUpPtr != 0)
          exec_circle->OnUpPtr();
        if (PressedObject == (TPointer)exec_circle)
          if (exec_circle->OnClickPtr != 0)
            exec_circle->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Boxes
    if (_object_count == box_order) {
      if (exec_box->Active == 1) {
        if (exec_box->OnUpPtr != 0)
          exec_box->OnUpPtr();
        if (PressedObject == (TPointer)exec_box)
          if (exec_box->OnClickPtr != 0)
            exec_box->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // Boxes with Round Edges
    if (_object_count == box_round_order) {
      if (exec_round_box->Active == 1) {
        if (exec_round_box->OnUpPtr != 0)
          exec_round_box->OnUpPtr();
        if (PressedObject == (TPointer)exec_round_box)
          if (exec_round_box->OnClickPtr != 0)
            exec_round_box->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // CheckBoxes
    if (_object_count == checkbox_order) {
      if (exec_checkbox->Active == 1) {
        if (exec_checkbox->OnUpPtr != 0)
          exec_checkbox->OnUpPtr();
        if (PressedObject == (TPointer)exec_checkbox) {
          if (exec_checkbox->Checked == 1)
            exec_checkbox->Checked = 0;
          else
            exec_checkbox->Checked = 1;
          DrawCheckBox(exec_checkbox);
          if (exec_checkbox->OnClickPtr != 0)
            exec_checkbox->OnClickPtr();
        }
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  // RadioButtons
    if (_object_count == radio_button_order) {
      if (exec_radio_button->Active == 1) {
        if (exec_radio_button->OnUpPtr != 0)
          exec_radio_button->OnUpPtr();
        if (PressedObject == (TPointer)exec_radio_button)
          if (exec_radio_button->OnClickPtr != 0)
            exec_radio_button->OnClickPtr();
        PressedObject = 0;
        PressedObjectType = -1;
        return;
      }
    }

  }
  PressedObject = 0;
  PressedObjectType = -1;
}

void Process_TP_Down(unsigned int X, unsigned int Y) {

  object_pressed      = 0;
  exec_button         = 0;
  exec_round_button   = 0;
  exec_round_cbutton  = 0;
  exec_label          = 0;
  exec_image          = 0;
  exec_circle         = 0;
  exec_box            = 0;
  exec_round_box      = 0;
  exec_checkbox       = 0;
  exec_radio_button   = 0;

  Get_Object(X, Y);

  if (_object_count != -1) {
    if (_object_count == button_order) {
      if (exec_button->Active == 1) {
        if (exec_button->PressColEnabled == 1) {
          object_pressed = 1;
          DrawButton(exec_button);
        }
        PressedObject = (TPointer)exec_button;
        PressedObjectType = 0;
        if (exec_button->OnDownPtr != 0) {
          exec_button->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == round_button_order) {
      if (exec_round_button->Active == 1) {
        if (exec_round_button->PressColEnabled == 1) {
          object_pressed = 1;
          DrawRoundButton(exec_round_button);
        }
        PressedObject = (TPointer)exec_round_button;
        PressedObjectType = 1;
        if (exec_round_button->OnDownPtr != 0) {
          exec_round_button->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == round_cbutton_order) {
      if (exec_round_cbutton->Active == 1) {
        if (exec_round_cbutton->PressColEnabled == 1) {
          object_pressed = 1;
          DrawCRoundButton(exec_round_cbutton);
        }
        PressedObject = (TPointer)exec_round_cbutton;
        PressedObjectType = 9;
        if (exec_round_cbutton->OnDownPtr != 0) {
          exec_round_cbutton->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == label_order) {
      if (exec_label->Active == 1) {
        PressedObject = (TPointer)exec_label;
        PressedObjectType = 2;
        if (exec_label->OnDownPtr != 0) {
          exec_label->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == image_order) {
      if (exec_image->Active == 1) {
        PressedObject = (TPointer)exec_image;
        PressedObjectType = 3;
        if (exec_image->OnDownPtr != 0) {
          exec_image->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == circle_order) {
      if (exec_circle->Active == 1) {
        if (exec_circle->PressColEnabled == 1) {
          object_pressed = 1;
          DrawCircle(exec_circle);
        }
        PressedObject = (TPointer)exec_circle;
        PressedObjectType = 4;
        if (exec_circle->OnDownPtr != 0) {
          exec_circle->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == box_order) {
      if (exec_box->Active == 1) {
        if (exec_box->PressColEnabled == 1) {
          object_pressed = 1;
          DrawBox(exec_box);
        }
        PressedObject = (TPointer)exec_box;
        PressedObjectType = 6;
        if (exec_box->OnDownPtr != 0) {
          exec_box->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == box_round_order) {
      if (exec_round_box->Active == 1) {
        if (exec_round_box->PressColEnabled == 1) {
          object_pressed = 1;
          DrawRoundBox(exec_round_box);
        }
        PressedObject = (TPointer)exec_round_box;
        PressedObjectType = 7;
        if (exec_round_box->OnDownPtr != 0) {
          exec_round_box->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == checkbox_order) {
      if (exec_checkbox->Active == 1) {
        if (exec_checkbox->PressColEnabled == 1) {
          object_pressed = 1;
          DrawCheckBox(exec_checkbox);
        }
        PressedObject = (TPointer)exec_checkbox;
        PressedObjectType = 16;
        if (exec_checkbox->OnDownPtr != 0) {
          exec_checkbox->OnDownPtr();
          return;
        }
      }
    }

    if (_object_count == radio_button_order) {
      if (exec_radio_button->Active == 1) {
        if (exec_radio_button->PressColEnabled == 1) {
          object_pressed = 1;
          DrawRadioButton(exec_radio_button);
        }
        PressedObject = (TPointer)exec_radio_button;
        PressedObjectType = 17;
        if (exec_radio_button->OnDownPtr != 0) {
          exec_radio_button->OnDownPtr();
          return;
        }
      }
    }

  }
}

void Check_TP() {
  if (STMPE610_PressDetect()) {
    if (STMPE610_GetLastCoordinates(&Xcoord, &Ycoord) == 0) {
    // After a PRESS is detected read X-Y and convert it to Display dimensions space
      Process_TP_Press(Xcoord, Ycoord);
      if (PenDown == 0) {
        PenDown = 1;
        Process_TP_Down(Xcoord, Ycoord);
      }
    }
  }
  else if (PenDown == 1) {
    PenDown = 0;
    Process_TP_Up(Xcoord, Ycoord);
  }
}

void Init_MCU() {
  // Place your code here

  // If bus is busy wait SDA high before initializing I2C module
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_6);
  GPIO_Digital_Input(&GPIOB_BASE, _GPIO_PINMASK_7);
  GPIOB_ODR.B6 = 1;
  while (GPIOB_IDR.B7 == 0) {
    GPIOB_ODR.B6 = 0;
    Delay_us(10);
    GPIOB_ODR.B6 = 1;
    Delay_us(10);
  }
  I2C1_Init_Advanced(400000, &_GPIO_MODULE_I2C1_PB67);

  TFT_Set_Default_Mode();
  GPIO_Digital_Output(&GPIOG_BASE, 0x00FF);
  GPIO_Digital_Output(&GPIOE_BASE, 0xFF00);
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_4);
  GPIOB_ODR.B4 = 0;
  TFT_Set_Default_Mode();
  TFT_Rotate_180(1);
  TFT_Set_MM_Plus();
  STMPE610_SetDefaultMode();
  STMPE610_Rotate180(STMPE610_ROTATE_180);
}

char STMPE610_Config()  {
  STMPE610_SetI2CAddress(STMPE610_I2C_ADDR1);
  if (STMPE610_IsOperational() != 0){
    return STMPE610_IO_NOT_OPERATIONAL;
  }

  STMPE610_Reset();
  STMPE610_Module(STMPE610_MODULE_TS | STMPE610_MODULE_ADC, STMPE610_ENABLE);
  STMPE610_AlternateFunction(STMPE610_GPIO_PIN1, STMPE610_ENABLE);
  STMPE610_SetGPIOPin(STMPE610_GPIO_PIN1, 0);   // IN1 to "0" -> I2C communication
  STMPE610_SetSize(800,480);
  STMPE610_Module(STMPE610_MODULE_TS | STMPE610_MODULE_ADC, STMPE610_ENABLE);
  STMPE610_EnableInterrupt(STMPE610_IE_TOUCH_DET | STMPE610_IE_FIFO_TH | STMPE610_IE_FIFO_0FLOW, STMPE610_ENABLE);
  STMPE610_ConfigureInterrupt(STMPE610_INT_POLARITY_ACTIVE_HIGH | STMPE610_INT_TYPE_EDGE | STMPE610_INT_ENABLE_ALL);
  STMPE610_SetADC(STMPE610_ADC_CTRL1_SAMPLETIME_44 | STMPE610_ADC_CTRL1_ADC_12BIT | STMPE610_ADC_CTRL1_INT_REFERENCE);
  Delay_10ms(); Delay_10ms();
  STMPE610_SetADCClock(STMPE610_ADC_CTRL2_3250_kHZ);
  STMPE610_AlternateFunction(STMPE610_GPIO_PIN4 | STMPE610_GPIO_PIN5 | STMPE610_GPIO_PIN6 | STMPE610_GPIO_PIN7, STMPE610_DISABLE);
  STMPE610_ConfigureTSC(STMPE610_TSC_CFG_AVE_CTRL_4S, STMPE610_TSC_CFG_TOUCH_DET_DELAY_500uS, STMPE610_TSC_CFG_TOUCH_SETTLING_500uS);
  STMPE610_SetFIFOThreshold(1);
  STMPE610_ResetFIFO();
  STMPE610_TSIDrive(STMPE610_TSC_I_DRIVE_20mA);
  STMPE610_TSControl(STMPE610_TSC_CTRL_TRACK0 | STMPE610_TSC_CTRL_ACQU_XYZ | STMPE610_TSC_CTRL_ENABLE);
  STMPE610_ZDataFraction(STMPE610_FRACP4_WHOLP4);
  STMPE610_SetTouchPressureThreshold(70);
  STMPE610_ClearInterrupts();
  STMPE610_WriteReg(STMPE610_INT_CTRL_REG, 0x01);
  return STMPE610_OK;
}


void Start_TP() {
  Init_MCU();

  InitializeTouchPanel();
  if (STMPE610_Config() == STMPE610_OK) {
  } else {
    while(1);
  }


  Delay_ms(1000);
  TFT_Fill_Screen(0);
  Calibrate();
  TFT_Fill_Screen(0);

  InitializeObjects();
  display_width = Home.Width;
  display_height = Home.Height;
  DrawScreen(&Home);
}